#!/usr/bin/env python
# -*- coding: utf-8 -*-

############################################################################################################
#
#   IMPORTS
#
#===========================================================================================================
import logging
import libxml2
import urllib,string,re,sys,os,logging, logging.config,time
from types import *
import feedparser
import caractersHandling as _carac

# debugging to file
log = logging.getLogger("div")


############################################################################################################
#
#   CLASSES
#
#===========================================================================================================
class ServiceError(Exception):
	def __init__(self, *args):
		Exception.__init__(self, *args)

class HttpError(ServiceError):
	def __init__(self, url):
		ServiceError.__init__(self, url)
		self.url=url
		
class MalformedResponseError(ServiceError):
	def __init__(self, response):
		ServiceError.__init__(self, response)
		self.response=response
		
class XMLError(ServiceError):
	def __init__(self, xml):
		ServiceError.__init__(self, xml)
		self.xml = xml
		
class NoResultError(ServiceError):
	def __init__(self, res):
		ServiceError.__init__(self, res)
		self.res = res
		 
# ----------------------------------------------------------------------------
		
class AnnotationServiceQuery:
	annotationServiceURL= 'http://search.biocase.org/annotation/'
	
	svn_version={'current':'current','history':'history','all':'all'}
	
	def __init__(self):
		self.response=None
		self.relationList = None
		
		
	
	def sendQuery(self, uddi=None, format=None, instID=None, collID=None, unitID=None, excl=False, method='modified'):
		params={}
		
		if instID is not None:
			params['instid']=instID.replace('/','-')
		if collID is not None:
			params['collid']=collID.replace('/','-')
		if unitID is not None:
			params['unitid']=unitID.replace('/','-')
		if excl:
			params['excl']=True
		if format is not None:
			params['format']=format	  
			
		params = urllib.urlencode(params)
		base = "%s%s/%s?" %(AnnotationServiceQuery.annotationServiceURL,method,uddi)
#		log.info("Exclusion du format: %s ; %s%s" %(excl,base,params))
		#log.info("add annotation %s %s"%(base,params))
		
		try:
			f = urllib.urlopen(base,params)
			self.response = f.read()
			#log.info("response from annofeed %s"%str(self.response))
			d = feedparser.parse(self.response)
			
			annotationTable=[]
			annotationDico={}
			for entry in d.entries:
				try:
					prop=[]
					id = entry.id
					prop.append(entry.updated.split('T')[0])
					prop.append(entry.subtitle)
					prop.append(entry.content[0].value)
					prop.append(escape(_carac.encodeCaracters(decoded=entry.tags[0].scheme)))
					#log.info("entry.link[0] %s" %str(entry.links[0]))
					try:
						prop.append(escape(_carac.encodeCaracters(decoded=entry.links[0].href)))
					except:
						prop.append(escape(_carac.encodeCaracters(decoded=entry.links[0].get('href'))))
					prop.append(entry.author_detail.name)
					annotationTable.append(prop)
					annotationDico[id]=prop
				except:
					pass
			annotationTable.sort(lambda x,y:cmp(y[0],x[0]) )
			return (annotationDico,annotationTable)
		except Exception,e :
			log.info("HTTP ERROR: Mapping service URL COULD NOT BE OPENED %s" % e)
#			raise HttpError(AnnotationServiceQuery.annotationServiceURL)
		return ({},[])

	
	def getOriginalURL(self,url):
		url = url.replace("modified","original")
		tmp = url.split('/')
		name = tmp[len(tmp)-1]
		tmp.pop(len(tmp)-1)
		
		name = '_'.join(name.split("_")[:-1])+".xml"
		tmp.append(name)
		return "/".join(tmp)

	def getRawContent(self,url):
		url = url.replace(" ","%20").replace("\"","")
#		log.info("get rawcontent: %s"%url)
		content = ""
		try:
		   # f = urllib.urlopen(AnnotationServiceQuery.annotationServiceURL,params)
			f=urllib.urlopen(url)
			content = f.read()
			try:
				content=unicode(content, 'utf-8')
				#log.info("full xml %s"%unicode(content, 'utf-8'))
			except:
				try:
					content = unicode(content,"ascii")
				except:
					try:
						content = unicode(content,"ISO-8859-1")
					except:
						try:
							content = unicode(content,"utf-8")
						except:
							try:
								content = unicode(content,"koi8-r")
							except:
								try:
									content = unicode(content,"ansi")
								except Exception,e:
									log.info("CODING PROBLEM UTF/ISO ansi : %s" %e)

		except Exception,e:
			log.info("exception occured in rawcontent %s"%e)
#		log.info("content: %s"%str(content))
		return content

	def getContent(self,url):
		url = url.replace(" ","%20").replace("\"","")
		content = ""
		try:
		   # f = urllib.urlopen(AnnotationServiceQuery.annotationServiceURL,params)
			f=urllib.urlopen(url)
			content = f.read()
			try:
				#log.info("full xml %s"%unicode(content, 'utf-8'))
				content = unicode(content, 'utf-8')
			except:
				try:
					content = unicode(content,"ascii")
				except:
					try:
						content = unicode(content,"ISO-8859-1")
					except:
						try:
							content = unicode(content,"utf-8")
						except:
							try:
								content = unicode(content,"koi8-r")
							except:
								try:
									content = unicode(content,"ansi")
								except Exception,e:
									log.info("CODING PROBLEM UTF/ISO ansi : %s" %e)

		except:
			pass
#		content=content.replace('<a ','tagahref').replace('</a>','tagafin').replace('<br>','newLine')
		content=content.replace('<br>', '<br/>')
		if "</DarwinRecordSet>" in content:
			content=content[0:content.index("</DarwinRecordSet>")]
			content=content.replace("<","<dwcore:").replace("<dwcore:/","</dwcore:").replace("<dwcore:?xml","<?xml")
			content=content.replace("dwcore:DarwinRecord","DarwinRecord")
			content=content.replace("<DarwinRecord>", '<DarwinRecord xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:dwcore="http://rs.tdwg.org/dwc/dwcore/" xmlns:dwgeo="http://rs.tdwg.org/dwc/geospatial/" xmlns:dwcur="http://rs.tdwg.org/dwc/curatorial/">')
		nbRec=0
		for line in content.splitlines():
			if '</record>' in line:
				nbRec+=1
		if nbRec>1:
			tmpC=''
			cursor=0
			for line in content.splitlines():
				if cursor ==1:
					tmpC+='<RecordSet>\n'
				tmpC+=line+'\n'
				cursor+=1
			tmpC+='</RecordSet>'
			content=tmpC
			cursor=None
			tmpC=None
		try:
			self.doc = libxml2.parseDoc(content)
		except Exception,e:
			self.doc = None
			log.info("ERROR: NO WELL FORMED XML RESPONSE FOUND: %s" %e)
#			raise MalformedResponseError(url+' *** '+str(self.response))
			log.info("MalformedResponse Annotation %s %s"%(str(url),str(self.response)))
		return self.doc



def escape(chaine):
	tmp=chaine.replace(" ","%20") 
	tmp=chaine.replace(":","%3A")  
	tmp=chaine.replace("/","%2F") 
	return tmp	  
