
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import inspect as _i
import os.path as _p
import os
from cgi import escape
from types import DictType, ListType

import logging, ConfigParser
# get a global logger instance
log = logging.getLogger("div")

INT_PROPS =['recLimit','expire','error_maxbytes','error_backupcount','debug_maxbytes','debug_backupcount','request_maxbytes','request_backupcount','PORT']
BOOL_PROPS=['debug','pickle','prettyprint','forTaxonomist']

def isTrue(arg):
	'''Boolean expression evaluation extended by '0' and 'false' (case insensitive) evaluating to False 
	instead of True done by bool function which is used for all other evaluations.'''
	try:
		arg =str(arg)
		arg = arg.strip()
		arg = arg.lower()
		if arg in ('0', 'false'):
			return False
		else:
			return bool(arg)
	except:
		return bool(arg)
	   
libPath = None

############################################################################################################
#
#   Singleton metaclass. Exists in biocase.tools also but avoided here so no biocase namespace is required
#
#===========================================================================================================
class Singleton(type):
	def __init__(cls,name,bases,dic):
		super(Singleton,cls).__init__(name,bases,dic)
		cls.__instance=None
	def __call__(cls,*args,**kw):
		if cls.__instance is None:
			cls.__instance=super(Singleton,cls).__call__(*args,**kw)
		return cls.__instance
	   
############################################################################################################
#
#   CONFIGURATION SECTION CLASS
#
#===========================================================================================================
class ConfigurationSection( object ):
	#-------------------------------------------------------------------------------------------------------
	def __init__(self):
		self.__name__	 = None
		self.__filename__ = None

	#-------------------------------------------------------------------------------------------------------ä
	def __setOption__(self, optionName, value):
		if optionName in INT_PROPS:
			try:
				value=int(value)
			except:
				# Configuration option is no integer! Default to 0
				value=0
		elif optionName in BOOL_PROPS:
			value=isTrue(value)
		setattr(self, optionName, value )

	#-------------------------------------------------------------------------------------------------------
	def __save__( self ):
		if self.__filename__ is None:
			return False
		options = {}
		# get entries (flatten lists)
		for name in dir( self ):
			if name.startswith( '__' ): continue
			attr = getattr( self, name )
			if type(attr) == ListType:
				for i,e in enumerate(attr):
					options["%s_%i"%(name,i+1)] = e
			elif name in INT_PROPS:
				options[name]=unicode(attr)
			elif name in BOOL_PROPS:
				options[name]=unicode(attr)
			else:
				options[name]=unicode(attr)
		# write options
		fp = file(self.__filename__)
		pre  = ""
		post = ""
		tmp = ""
		inSect = False
		# read existing ini and ignore this sections
		for line in fp.readlines():
			if not inSect:
				tmp = tmp + line
				if line.strip() == "[%s]"%self.__name__:
					# found this objects section.
					inSect = True
					pre = tmp
					tmp = ""					
			else:
				if line.strip().startswith("["):
					# other section starting
					inSect = False
					tmp = "\n" + line
				else:
					# options. ignore them
					pass
		post = tmp
		fp.close()			
		
		fpw = file(self.__filename__, 'w')
		fpw.write(pre)
		# create new string for options
		names = sorted(options.keys())
		for name in names:
			fpw.write("%s  =  %s\n" % (name.encode('utf-8'), options[name].encode('utf-8')))
		fpw.write(post)
		fpw.close()

############################################################################################################
#
#   GLOBAL CONFIGURATION BASE CLASS. might be replaced by another class when using getCfg()
#
#===========================================================================================================
class Cfg( object ):
	__metaclass__ = Singleton

	def __init__(self):
		# always read the lib configs
		
		self.ns2prefix={}
		# set home locators. Needed to find default configuration files
		self._setHomeLocator()
		# always read the lib configs
		self._readConfigFiles()

	#-------------------------------------------------------------------------------------------------------
	def _setHomeLocator(self, bpsPath=None):
		if bpsPath is None or not os.path.isdir(bpsPath):
			from adjustpath import bpsPath as homeLocator
			#print "adjustpath bpsPath = %s"%homeLocator
			if homeLocator is None or not os.path.isdir(homeLocator):
				homeLocator = _p.join( _p.dirname( _i.getfile( lambda:None )), os.pardir, os.pardir)
		else: 
			homeLocator = bpsPath
		Cfg.homeLocator			 = _p.normpath(homeLocator)
		#print "Cfg.homeLocator = %s\n"%Cfg.homeLocator
		Cfg.libLocator				 = _p.join( Cfg.homeLocator, 'lib')
		Cfg.webappLocator			 = _p.join( Cfg.homeLocator,'webapp')
		Cfg.staticLocator			 = _p.join(Cfg.webappLocator,'static')
		Cfg.uploadLocator			 = _p.join( Cfg.webappLocator,'static','files')
		Cfg.sessionLocator			 = _p.join(Cfg.homeLocator,'sessions')
		Cfg.logLocator				 = _p.join( Cfg.homeLocator,'log')
		Cfg.configurationLocator	 = _p.join(Cfg.homeLocator,'config')
		Cfg.propertiesLocator		 = _p.join(Cfg.libLocator,'requestHandler')
		Cfg.settingsLocator			 = _p.join(Cfg.propertiesLocator,'settings.txt')
		
		Cfg.unitLevelPropertiesLocator  = _p.join(Cfg.propertiesLocator,'units')
		Cfg.queriesUnitLevelLocator	 = str(_p.join(Cfg.unitLevelPropertiesLocator,'%s_queries.txt'))	
		Cfg.straight_queriesUnitLevelLocator	 =str( _p.join(Cfg.unitLevelPropertiesLocator,'%s_straight_queries.txt'))
		
		Cfg.metadataLevelPropertiesLocator  = _p.join(Cfg.propertiesLocator,'metadata')
		Cfg.queriesMetadataLevelLocator	 = _p.join(Cfg.metadataLevelPropertiesLocator,'queries.txt')
		Cfg.straight_queriesMetadataLevelLocator	 = _p.join(Cfg.metadataLevelPropertiesLocator,'straight_queries.txt')
		
		Cfg.biocaseLocator			  = _p.join(Cfg.libLocator,'biocase')

		
	 #-------------------------------------------------------------------------------------------------------
	def __addCfgFile__( self, configFilename, readonly=False ):
		'''Read a configParser file and add its entries to this object'''
		# read configparser file
		cfg = ConfigParser.ConfigParser()
		cfg.optionxform = str
		cfg.read(configFilename)
		for sectname in cfg.sections():
			# add section to cfg object
			section = ConfigurationSection()
			section.__name__ = sectname
			setattr(self, sectname, section)
			if readonly:
				section.__filename__ = None
			else:
				section.__filename__ = configFilename
			lists = {}
			for opt,val in cfg.items(sectname):
				if len(opt) > 1 and opt[-2] == '_':
					# process as list
					idx = int(opt[-1])
					opt = opt[:-2]
					if not lists.has_key(opt):
						lists[opt]={}
					lists[opt][idx] = val 
				else:
					# set option in this section
					section.__setOption__(opt, val)
			# add lists to section
			for opt, valList in lists.items():
				ids = valList.keys()
				ids.sort()
				l = []
				for i in ids:
					l.append(valList[i])
				section.__setOption__(opt, l)

	#-------------------------------------------------------------------------------------------------------
	def getWebappURL(self):
		return "%s%s/" % (self.server.host, self.server.webroot)
	#-------------------------------------------------------------------------------------------------------
	def _getSections(self):
		sections = []
		for name in dir( self ):
			attr = getattr( self, name )
			if isinstance(attr, ConfigurationSection):
				sections.append( attr )
		return sections

	#-------------------------------------------------------------------------------------------------------ä
	def _setOption(self, sectionName, optionName, value):
		if sectionName in dir(self):
			sect = getattr(self, sectionName)
			if isinstance(sect, ConfigurationSection):
				sect.__setOption__(optionName, value)
	#-------------------------------------------------------------------------------------------------------
	def __save__( self ):
		for sect in self._getSections():
			sect.__save__()

	#-------------------------------------------------------------------------------------------------------
	def reloadConfigFiles(self, additionalConfigFiles=[], bpsPath=None):
		'''reload config file(s)'''
		# remove existing sections
		for sec in self._getSections():
			delattr( self, sec.__name__ )
		# reset home locator
		self._setHomeLocator(bpsPath)
		# load sections again
		self._readConfigFiles(additionalConfigFiles)
		
	#-------------------------------------------------------------------------------------------------------
	def _readConfigFiles(self, filenames=[] ):
		# always read the lib, namespace & server configs
		self.__addCfgFile__(_p.join( self.libLocator, 'biocase','configuration.ini' ), readonly=True)
		self.__addCfgFile__(_p.join( self.configurationLocator,'config.ini' ), readonly=False)
		self.__addCfgFile__(_p.join( self.webappLocator, 'configfile.cfg' ), readonly=True)
		self.__addCfgFile__(_p.join( self.configurationLocator,'admin.ini' ), readonly=False)
		self.__addCfgFile__(_p.join( self.libLocator,'requestHandler', 'settings.txt' ), readonly=False)
		# postprocess namespaces. Create dictionary!
		if hasattr(self, "namespaces"):
			for name in dir(self.namespaces):
				if not name.startswith("_"):
					self.ns2prefix[getattr(self.namespaces,name)]=name
		for fn in filenames:
			self.__addCfgFile__(configFilename, readonly=False)
		
cfgObj = Cfg()

def getConfigObj():
	return cfgObj


############################################################################################################
#
#===========================================================================================================
if __name__ == '__main__':
	import sys
	sys.setrecursionlimit( 20 )
	print cfgObj
	cfgObj.__save__()


	
