#!/usr/bin/env python
# -*- coding: utf-8 -*-


# EXPERIMENTAL
# timestamp: 20120914T

import urllib
import simplejson as json
import threading

#TODO: catch/throw more errors

class Service(object):
	# TODO?: rename uri to baseUri
	def __init__(self, uri):
		self.uri = uri

	def _parse(self, data):
		return data

	def query(self, url):
			#TODO: timeout
			f = urllib.urlopen(self.uri+url)
			raw = f.read()
			parsed = self._parse(raw)
			return parsed;


class ServiceJSON(Service):
	# overwrite parser
	def _parse(self, data):
		return json.loads(data)


########################################
### specific service implementations
########################################

################
### Tropicos
################

class ServiceTropicos(ServiceJSON):
	
	def __init__(self, uri="http://services.tropicos.org", apikey="1dab7d38-164c-4b84-9d72-6c0635588cab"):
		super(ServiceJSON,self).__init__(uri)
		self.apikey = apikey
	
	# searches for an exact name and counts the results
	def search(self, name):
		# generate URL
		options = {'name':name, 'type':'exact', 'apikey':self.apikey, 'format':'json'}
		url = "/Name/Search?"
		url += urllib.urlencode(options)
		# query
		result = self.query(url)
		# interpret result
		if "Error" in result[0]:
			count = 0
		else:
			count = result[0]["TotalRows"]
		return count;
	
	def createQueryUri(self, name):
		uri = "http://tropicos.org/NameSearch.aspx?exact=true&"
		uri += urllib.urlencode({"name":name})
		return uri


###########
### BHL
###########

class ServiceBHL(ServiceJSON):

	def __init__(self, uri="http://www.biodiversitylibrary.org", apikey="86b74dd4-fa1d-40b2-a010-ece79fa37fb5"):
		super(ServiceJSON,self).__init__(uri)
		self.apikey = apikey
	
	# searches for an exact name and counts the results
	def search(self, name):
		# generate url
		options = {'op':'NameSearch', 'name':name, 'apikey':self.apikey, 'format':'json'}
		url = "/api2/httpquery.ashx?"
		url += urllib.urlencode(options)
		# query
		result = self.query(url)
		# interpret result
		count = 0
		for elem in result["Result"]:
			# we don't want similar names
			if elem["NameBankID"] != None and elem["NameConfirmed"]==name:
				count += 1
		return count
	
	def createQueryUri(self, name):
		uri = "http://biodiversitylibrary.org/search.aspx?"
		uri += urllib.urlencode({"SearchTerm":name})
		return uri


############
### ipni
############

class ServiceIPNI(Service):
	def __init__(self, uri="http://ipni.org"):
		super(ServiceIPNI,self).__init__(uri)
		
	def search(self, name):
		# generate url
		options = {'find_wholeName':name, 'output_format':'delimited-minimal'}
		url = "/ipni/simplePlantNameSearch.do?"
		url += urllib.urlencode(options)
		# query
		result = self.query(url)
		# interpret result
		# count lines simply
		count = result.count("\n");
		if count > 0:
			# first line contains column titles
			lineCount = count - 1
		else:
			lineCount = 0
		return lineCount

	def createQueryUri(self, name):
		options = {'find_wholeName':name, 'output_format':'normal'}
		uri = self.uri
		uri += "/ipni/simplePlantNameSearch.do?"
		uri += urllib.urlencode(options)
		return uri


################
### Euro+Med
################

class ServiceEpM(Service):
	
	def __init__(self, uri="http://search.biocase.org"):
		super(ServiceEpM,self).__init__(uri)
	
	def search(self, name):
		# generate url
		options = {"term":name, "method":"getNamesLike", "thesaurus":"Euro+Med Plantbase"}
		url = "/toqe/toqe.py?"
		url += urllib.urlencode(options)
		# query
		result = self.query(url)
		# interpret result
		# TODO: real parsing
		if 'success="true"' in result:
			count = 1
		else:
			count = 0
		return count

	def createQueryUri(self, name):
		options = {'name':name}
		uri = "http://ww2.bgbm.org"
		uri += "/EuroPlusMed/results.asp?"
		uri += urllib.urlencode(options)
		return uri


##################################

# dictonary of services
list = {
	"tropicos": ServiceTropicos,
	"bhl": ServiceBHL,
	"ipni": ServiceIPNI,
	"epm": ServiceEpM
	}

##################################


class ForeignServiceSearchThread(threading.Thread):
	def __init__(self, serviceObject, name):
		super(ForeignServiceSearchThread, self).__init__()
		self.serviceObject = serviceObject
		self.searchName = name
	
	def run(self):
		self.result = self.serviceObject.search(self.searchName)


class ForeignServiceManager(object):
	def __init__(self, serviceClasses):
		self.serviceClasses = serviceClasses
	
	def search(self, name):
		services = {}
		results = {}
		# start threads
		for key in self.serviceClasses.keys():
			ServiceClass = self.serviceClasses[key]
			thread = ForeignServiceSearchThread(ServiceClass(), name)
			thread.start()
			services[key] = thread
		# wait for the threads and generate result dict
		for key in services.keys():
			thread = services[key]
			thread.join()
			uri = thread.serviceObject.createQueryUri(name)
			result = {"count":thread.result, "uri":uri}
			results[key] = result
		return results
