#!/usr/bin/env python
# -*- coding: utf-8 -*-

############################################################################################################
#
#   IMPORTS
#
#===========================================================================================================
import logging
import libxml2
import urllib,string
from types import *

# debugging to file
log = logging.getLogger("div")


############################################################################################################
#
#   CLASSES
#
#===========================================================================================================
class ServiceError(Exception):
    def __init__(self, *args):
        Exception.__init__(self, *args)

class HttpError(ServiceError):
    def __init__(self, url):
        ServiceError.__init__(self, url)
        self.url=url
        
class MalformedResponseError(ServiceError):
    def __init__(self, response):
        ServiceError.__init__(self, response)
        self.response=response
        
class XMLError(ServiceError):
    def __init__(self, xml):
        ServiceError.__init__(self, xml)
        self.xml = xml
        
class NoResultError(ServiceError):
    def __init__(self, res):
        ServiceError.__init__(self, res)
        self.res = res
         
# ----------------------------------------------------------------------------
class SimpleXMLGenerator:
    

    
    def __init__(self):
        log.info("Mapping Service")
        
    
    def _addFeature(self,unitData=None,feature=None,featureID=0):
        if unitData is None:
            return None
        taxonName = unitData[0]
        Xcoord = unitData[14]
        Ycoord = unitData[15]
        resourceName = unitData[8][0]
        if Xcoord is not None and Ycoord is not None:
            if feature is None:
                feature = ""
            feature+=''' <feature fid="%i">
                             <taxonName>%s</taxonName>
                             <point srs="%s">%s %s</point>
                             <resourceName>%s</resourceName>
                         </feature>
                         ''' % (featureID,taxonName,MappingServiceQuery.srs,Xcoord,Ycoord,resourceName)
        return feature
        
    
    def getSimpleXML(self,selection=None):
        fid=0
        feature=""
        if selection is not None:
            for unitData in selection:
                feature = self._addFeature(unitData,feature,fid)
                fid+=1
        return u'''<?xml version="1.0" encoding="UTF-8"?>
                        <FeatureCollection>
                        %s
                        </FeatureCollection>
                        ''' %feature
                
class MappingServiceQuery:
    mappingServiceURL = "http://synthesys.csic.es/DPS/dps.php?"
    srs = "4326"    
    
    def __init__(self):
        self.response=None
        self.SG = SimpleXMLGenerator()
        
    def getRecordsMap(self,selection):
        simpleXML = self.SG.getSimpleXML(selection=selection)
        return self.sendQuery(simpleXML)

    def sendQuery(self,simpleXML):
        params = {'format': 'simple_xml','xml':simpleXML.encode('utf-8')}
        params = urllib.urlencode(params)
        
        log.info("params sent to Madrid: %s" %params)
        return "%s%s" %(MappingServiceQuery.mappingServiceURL,params)
#        try:
#            f = urllib.urlopen(MappingServiceQuery.mappingServiceURL, params)
#            self.response = f.read()
#            try:
#                log.info("FULL WRAPPER RESPONSE %s"%unicode(self.response, 'utf-8'))
#            except:
#                try:
#                    self.response = unicode(self.response,"ascii")
#                except:
#                    try:
#                        self.response = unicode(self.response,"ISO-8859-1")
#                    except:
#                        try:
#                            self.response = unicode(self.response,"utf-16")
#                        except Exception,e:
#                            try:
#                                self.response = unicode(self.response,"koi8-r")
#                            except Exception,e:
#                                try:
#                                    self.response = unicode(self.response,"ansi")
#                                except Exception,e:
#                                    log.info("CODING PROBLEM UTF/ISO ansi : %s" %e)
#        except Exception,e :
#            log.info("HTTP ERROR: Mapping service URL COULD NOT BE OPENED %s" % e)
#            raise HttpError(MappingServiceQuery.mappingServiceURL)
#        # parse the xml into xmllib2 DOM:
#        try:
#            self.doc = libxml2.parseDoc(self.response)
#        except:
#            self.doc = None
#            log.info("ERROR: NO WELL FORMED XML MAPPING RESPONSE FOUND")
#            raise MalformedResponseError(self.response)
#        
#        log.info("ANALYZING RESPONSE DOC")
#        root = self.doc.getRootElement()
#        log.info("  DOC ROOT %s"%root.name)
#        if root.ns() is not None:
#            try:
#                log.info("  PROTOCOL NS found: %s" % unicode(root.ns()).replace('"','').replace("'",''))
#            except:
#                self._type = None
#        else:
#            log.info("ROOT ATTRIBUTES: %s" % root.get_properties())
#        for header in root.children:
#            if header.type == 'element' and header.name=='header':
#                log.info("  Header section found.")
#                self.headerDOM = header
#                break
#        # try to get main sections
#        elem = header
#        while elem is not None:
#            if elem.type == "element":
#                log.info("element: %s" %elem.name)
##                if elem.name == 'content':
##                    log.info("  Content section found.")
##                    self.contentDOM = elem
##                # try to get diagnostics
##                elif elem.name == 'diagnostics':
##                    log.info("  Diagnostics section found.")
##                    self.diagnosticsDOM = elem
#            elem = elem.next
#        self.nbRecords = int( self.contentDOM.prop('featureCount') )
#
#        
#    # ------------------------------------------------------------------------------------
#    def getContent(self, asDoc=True):
#        noContent =' no content found '
#        domerror = 'problem with DOM '
#        resError = ' no result '
#        if self.nbRecords == 0:
#            log.info("No map")
#            raise NoResultError(resError)
#        
#        if self.contentDOM is None or self.contentDOM.children is None:
#            log.info("COULDN'T GET CONTENT DOM NODE.")
#            raise XMLError(domerror)
#        
#        contentDOM = self.contentDOM.copyNodeList()
#        n = contentDOM.children
#        while n is not None:
#            nextnode = n.next
#            if n.type == 'element':
#                log.info("  Content payload element %s found." % n.name)
#            else:
#                log.info("  Non payload element %s (type %s) ignored."%(n.name, n.type))
#                n.freeNode()
#                n.unlinkNode()
#            n = nextnode
#        # check how many payload elements content has...
#        #log.info("  ContentDOM.lsCountNode() = %i" % contentDOM.lsCountNode())
#        if contentDOM.lsCountNode() < 1:
#            #log.info("NO CONTENT FOUND.")
#            raise XMLError(noContent)
#        if contentDOM.lsCountNode() == 1:
#            payload = contentDOM.children
#        else:
#            # more than one child element node of content. create artificial recordset node for this digir style
#            payload = contentDOM
#            payload.setName('RecordSet')
#            payload.setNs( contentDOM.children.ns() )
#        
#        # create new doc with these nodes:
#        if asDoc:
#            doc = libxml2.newDoc("1.0")
#            doc.setRootElement(payload)
#        else:
#            doc = payload
#        if doc is None:
#            raise XMLError(noContent)
#        log.info("CONTENT FOUND: %s" % unicode(doc))
#        return doc
#        
