#!/usr/bin/env python
# -*- coding: utf-8 -*-
import MySQLdb,sys,logging, logging.config,os,psycopg,pymssql
from threading import BoundedSemaphore, Thread

import page,biocase

from requestHandler.props import *


# use logging
log = logging.getLogger( "query" )

#get the configuration singleton
cfgObj	 = biocase.configuration.getConfigObj()

#thread semaphore : only one thread can connect the DB, the others have to wait
semaphoreConnection = BoundedSemaphore(35)

#------------------------------------------------------------------------------
#
# This class realize the connection to the DB
# A semaphore is used for thread safety (multithreading)
#
#------------------------------------------------------------------------------
class DBconnection(object):
#	_instance = None	
#	
#	#singleton
#	def __new__( cls, *args, **kwargs ):
#		if not cls._instance:
#			cls._instance = super( DBconnection, cls ).__new__( 
#								   cls, *args, **kwargs )
#			self = cls._instance
#			self._propsFile = props(cfgObj.settingsLocator)
#		return cls._instance  
	

	def __init__(self):
		self._propsFile = props(cfgObj.settingsLocator)
		self.utf=False
		self.uni=False

	 
	
	#set the database for the queries; cache = Synthesys Cache or GBIF De bota cache ...
	def setDatabase(self,db):
		''' 
		configure the parameters for the connection
		@param db : the database that has to be used
		* units for the units cache db in mysql
		* registry for the metadata db in postgresql
		'''
		semaphoreConnection.acquire()
		self.cursor =None
		self.db=db
		if db == 'units':  
			self.utf=True
			try:
				dbName = self._propsFile.getProperty("cache","DB")
			except:
				self._propsFile = props(cfgObj.settingsLocator)  
				dbName = self._propsFile.getProperty("cache","DB")
			user = self._propsFile.getProperty("cache","USER")
			passwd = self._propsFile.getProperty("cache","PASSWORD")
			host = self._propsFile.getProperty("cache","HOST")
			try:
				port = int(self._propsFile.getProperty("cache","PORT"))
			except:
				port=""
			driver = self._propsFile.getProperty("cache","DRIVER")
			
			if(driver == 'MySQLdb'):

				try:
					self.connection = MySQLdb.connect(db=dbName, user=user, passwd=passwd, host=host,port=port)

				except Exception, err:
					log.info('Error with connection: db cache %s: '%err)
					log.info('db= %s, user=%s, passwd=%s, host=%s, port=%s  '%(dbName, user, passwd,host,port))
					self.close()
				else:
					self.cursor = self.connection.cursor()
			if(driver == 'pymssql'):
				self.utf=False
				self.uni=True
				try:
					if port != "":
						host=str(host)+':'+str(port)
					
					self.connection =pymssql.connect(host=host,user=user,password=passwd,database=dbName)
				except Exception, err:
					log.info('Error with connection db cache pymssql: \n  %s: '%err)
					log.info('db= %s, user=%s, passwd=%s, host=%s,  '%(dbName, user, passwd,host))
					self.close()
				else:
					self.cursor = self.connection.cursor()	
		else:
			self.utf=False
			if db == 'registry' or db == 'corm_slave':
				if  db == 'registry':
					dbName = self._propsFile.getProperty("corm_v2","DB")
					user = self._propsFile.getProperty("corm_v2","USER")
					passwd = self._propsFile.getProperty("corm_v2","PASSWORD")
					host = self._propsFile.getProperty("corm_v2","HOST")
					driver = self._propsFile.getProperty("corm_v2","DRIVER")
				else:
					dbName = self._propsFile.getProperty("corm_slave","DB")
					user = self._propsFile.getProperty("corm_slave","USER")
					passwd = self._propsFile.getProperty("corm_slave","PASSWORD")
					host = self._propsFile.getProperty("corm_slave","HOST")
					driver = self._propsFile.getProperty("corm_slave","DRIVER")
				if(driver == 'Postgresql'):
					try:
						self.connection = psycopg.connect('host=%s dbname=%s user=%s' %(host, dbName, user))
					except Exception, err:
						log.info('Error with connection db corm: \n  %s: '%err)
						log.info('db= %s, user=%s, passwd=%s, host=%s  '%(dbName, user, passwd,host))
						self.close()
					else:
						self.cursor = self.connection.cursor()	
			else:
				if 'thesaurus' in db:
					name = db.split('thesaurus')[1]
					dbName = self._propsFile.getProperty(name,"DB")
					user = self._propsFile.getProperty(name,"USER")
					passwd = self._propsFile.getProperty(name,"PASSWORD")
					host = self._propsFile.getProperty(name,"HOST")
					port = int(self._propsFile.getProperty(name,"PORT"))
					driver = self._propsFile.getProperty(name,"DRIVER")
					if(driver == 'MySQLdb'):		
						try:
							self.connection = MySQLdb.connect(db=dbName, user=user, passwd=passwd, host=host,port=port)
		
						except Exception, err:
							log.info('Error with connection using Mysqldb: db cache %s: '%err)
							log.info('db= %s, user=%s, passwd=%s, host=%s, port=%s  '%(dbName, user, passwd,host,port))
							self.close()
						else:
							self.cursor = self.connection.cursor()
					if (driver == 'pymssql'):
						try:
							host=str(host)+":"+str(port)
							self.connection =pymssql.connect(host=host, user=user, password=passwd, database=dbName)
						except Exception, err:
							log.info('Error with connection using pymssql: db cache %s: '%err)
							log.info('db= %s, user=%s, passwd=%s, host=%s, port=%s  '%(dbName, user, passwd,host,port))
							self.close()
						else:
							self.cursor = self.connection.cursor()
		return self.cursor


	def executeQuery(self,query):
		'''
		execute the query 
		auto replace the '*' by '%' for the MySQL format
		@param query : the query to execute, with common wildcards   
		@return cursor : return the current cursor (can be used to test if not null)
		'''
		if self.utf:
			try:
				self.cursor.execute("SET CHARACTER SET 'utf8'")
			except Exception,e:
				log.info("problem utf8 mysql setcharacter %s "%e)
				pass
			try:
				self.cursor.execute("SET NAMES 'utf8';")
			except Exception,e:
				log.info("problem utf8 mysql setnames %s "%e)
				pass
		
		if cfgObj.admin.unitsDatabase == 'mysql':
			try:
				tmp=[query]	
				if 'from' in query and 'FROM' in query:
					a=query.find('from')
					b=query.find('FROM')
					if a<b:
						tmp=query.split('from',1)
					else:
						tmp=query.split('FROM',1)
				elif 'from' in query:
					tmp=query.split('from',1)
				elif 'FROM' in query:
					tmp=query.split('FROM',1)
				queryt=[]
				queryt.append(tmp[0])
				queryt.append(tmp[1])
				query = " from ".join(queryt)
				query =query.replace("~$par$~",'(').replace("~$parf$~",")")
				if 'IN BOOLEAN MODE' in query:
					query=query.replace("%'  IN BOOLEAN MODE","*' IN BOOLEAN MODE")
				
				if 'group_concat' in query.lower() and 'group by' not in query.lower():
					query+=' group by bioRecordKey'
				#log.info("executeQuery: %s" %query)
				self.cursor.execute(query)
				return self.cursor
			except Exception,e:
				log.info("Error %s in query %s "%(e,query))
				self.close()
				return None
		else:
			try:
				tmp=[query]	
				if 'from' in query and 'FROM' in query:
					a=query.find('from')
					b=query.find('FROM')
					if a<b:
						tmp=query.split('from',1)
					else:
						tmp=query.split('FROM',1)
				elif 'from' in query:
					tmp=query.split('from',1)
				elif 'FROM' in query:
					tmp=query.split('FROM',1)
				queryt=[]
				queryt.append(tmp[0])
				queryt.append(tmp[1])
				query = " FROM ".join(queryt)
				query =query.replace("~$par$~",'(').replace("~$parf$~",")")
				if 'IN BOOLEAN MODE' in query:
					query=query.replace("%'  IN BOOLEAN MODE","*' IN BOOLEAN MODE")
				
				if 'group_concat' in query.lower() and 'group by' not in query.lower():
					query+=' group by bioRecordKey'
				
				if self.uni:
					try:
						if 'group by' in query.lower():
							tmpg= [query.lower().split('group by')[1]]
							groups=[elt.strip() for elt in tmpg]
							select=query.split('SELECT')[1].split('FROM')[0].replace(')','').replace('CAST(','').replace('AS TEXT','').replace('dbo.fn_getURLs(','').replace('ORDER BY','').replace('DESC','').replace('ASC','')
							select=select.replace('distinct','').replace('COUNT(','').replace('(','').split(',')
							for se in select :
								se=se.strip()							
								if se not in groups and se.lower() not in groups and se !="''" and "COUNT(%s)"%se not in query and "COUNT(distinct %s)"%se not in query:
									groups.append(se)
							if "bioRecordKey" in groups:
								while "bioRecordKey" in groups:
									groups.remove("bioRecordKey")
								groups.append("bioRecordKey")
								groups.reverse()
							tmp = query.lower().split('group by')[0]+' GROUP BY '+ ' ,'.join(groups)
						else:
							tmp=query.lower()
						tmp=tmp.replace("\\'","''").replace(" n'"," N'").replace("\tn'"," N'")
						try:
							tmp=unicode(tmp,'utf-8')
							tmp=tmp.encode('latin-1')						
						except Exception,e:
							log.info("MSSQL exception %s"%e)
						#log.info("query to execute: %s" %tmp)
						self.cursor.execute(tmp)
					except Exception,e:
						log.info("PROBLEME %s %s"%(tmp,e))
				else:
					#log.info("query to execute: %s" %query)
					self.cursor.execute(query)
				return self.cursor
			except Exception,e:
				log.info("Error %s in query %s "%(e,query))
				self.close()
				return None


	
	def close(self):
		'''
		commit and close the connection
		release the thread
		'''
		try:
			self.connection.commit()
			self.connection.close()
		except Exception,e:
			log.debug("dbConnection.py unexisting connection : %s" %e)
		semaphoreConnection.release()
