#!/usr/bin/env python
# -*- coding: utf-8 -*-
import MySQLdb,sys,logging, logging.config,os,string,time
import cherrypy

import page
from requestHandler.props import *
from requestHandler.dbConnection import DBconnection
from search.queryReminder import QueryReminder
from types import ListType

import caractersHandling as _carac
import htmlentitydefs
# use logging
log = logging.getLogger("query")
log2 = logging.getLogger("queriesLog")
#page to get configuration elements
myPage = page.Page()
#----------------------------------------------------------------
#
#This class build the queries for the databases
#It adds JOIN, WHERE, AND conditions in function of the parameters sent
#
#----------------------------------------------------------------
class U_QueryManager:	

	def __init__(self,properties=None,cfgObj=None):
		'''
		init : set the current properties file
		@param properties : the properties file with the queries details (column names...)
		'''
		self.propertiesFile = properties
		self.cfgObj = cfgObj
		#max time to log slow queries
		try:
			self.max = float(self.cfgObj.slowQueries.max)
		except Exception,e:
			log.info("PB with max time for queries %s --" %(e))
			self.max=7.0
		self.freeText=False
		
		
	def loadProperties(self,straightSearch=False):
		#load some properties
		_cfgObj = self.cfgObj
		
		if straightSearch:
			propertiesFile = props(_cfgObj.straight_queriesUnitLevelLocator %_cfgObj.admin.unitsDatabase)
		else:
			propertiesFile = props(_cfgObj.queriesUnitLevelLocator %_cfgObj.admin.unitsDatabase)
	
		self.prop =  propertiesFile.getProperty
		self.opAnd = self.prop("mysql"," and ")
		self.opIn = self.prop("mysql","in")
		self.opEq = self.prop("mysql","equals")
		self.opInf = self.prop("mysql","lessthan")
		self.opSup = self.prop("mysql","greaterthan")
		self.opLike = self.prop("mysql","like")
		self.opOr = self.prop("mysql","or") 
		
	def buildSelectSQL(self,freeText=False): 
		'''
		main method to build the SQL query
		@param select :  the name of the column we are looking for
		*default : taxon <=> taxonName
		@param params: the parameters to use as options in the query
		*is used to know if the query has to contain some specific fields (like country,common name...
		@param taxonList: the tklist of taxonKeys
		LEFT JOIN go here faster than INNER JOIN : to keep the same effect, we add "is not null" statement for the selected columns
		'''
		
		querymn = cherrypy.session.get('u_qmg',{})
		taxonKeyList = querymn.get('taxonKeyList',[])
		if taxonKeyList is None or str(taxonKeyList).replace("(", "").replace(")","").replace(" ","") =="":
			taxonKeyList = []
		straightSearch = querymn.get('straightSearch',False)
		params = cherrypy.session.get('queryparams',[])
		select =  cherrypy.session.get('select','taxon')
		refineTaxon = querymn.get('refineTaxon',False)

		qrm = QueryReminder()
			  
		#load some properties
		self.loadProperties(straightSearch=straightSearch)
		
		query = []
		self.freeText = freeText
		
		if not straightSearch:
			
			where = []
			whereand = []

			if 'unitKey' in params or 'unitID' in params or 'collection' in params or 'institution' in params or 'locality' in params or  'collector' in params or 'collNumber' in params or 'fieldNumber' in params or 'country' in params or 'multimedia' in params or 'dateSup' in params or 'dateEq' in params or 'dateInf' in params or  'coordinates' in params or (('type' in params  or 'recordBasis' in params ) and not qrm.getType() =="any" ):
				extension = "bioRecord"
			else:
				extension = ""				
			

			if select=='genus' or select =='family':
				query.append(self.prop("select",select))
				query.append(" \t ")
				query.append(self.prop("from",select)) 
				query.append(" \t ")
				query.append(self.prop("where",select))
				query.append(" \t ")
				if self.cfgObj.admin.unitsDatabase == "mysql":
					query.append(self.prop("and","taxonKey"))
					query.append(" ")
				query.append(self.buildSimpleCondition(taxonKeyList,'taxon.taxonKey'))  
				
			
			if select=='commonName':
				query.append(self.prop("select",select))
				query.append(" \t ")
				query.append(self.prop("from",select)) 
				query.append(" \t ")
				query.append(self.prop("where",select))
				query.append(" \t ")
				query.append(self.prop("and","taxonKey"))
				query.append(" ")
				query.append(self.buildSimpleCondition(taxonKeyList,'commonNameTaxonKey'))	
				if "commonName" in params:
					tklist = self.replaceNotSpecified(qrm.getCommon())
					query.append(" \t ")
					if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
						query.append(self.prop("andGroup",select))  
					else:
						query.append(self.prop("and",select))
					query.append(" ")
					query.append(self.buildSimpleCondition(tklist,'vernacularName'))	
					if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
						query.append(" ) ")
					else:
						query.append(" ")

						
			if select=='collection' or select =='institution' or select=='collector':
				query.append(self.prop("select",select))			
				query.append(" \t ")
				query.append(self.prop("from",select)) 
				query.append(" \t ")
				if extension != "":
					query = self.addJoinTable(select = select,params = params, query=query)
					query.append(" ")
				#query.append(self.prop("leftJoin",select))
				#query.append(" \t ")
				query.append(self.prop("where",select))
				query.append(" ")
				query.append(self.buildSimpleCondition(taxonKeyList,'bioRecordTaxonKey')) 
				if extension != "":
					query = self.addAnd(params = params,query=query)
					query.append(" ")
					
			if select=='country':
				query.append(self.prop("select",select))			
				query.append(" \t ")
#				query.append(self.prop("from",select+extension))
				query.append(self.prop("from",select))
				query.append(" \t ")
				tax = qrm.getTaxon()
				if tax is not None:
					if len(tax)==0:
						tax = None
				fam = qrm.getFamily()
				if fam is not None:
					if len(fam)==0:
						fam = None
				gen = qrm.getGenus()
				if gen is not None:
					if len(gen)==0:
						gen = None
				if extension != "" or ( tax is None and (fam is not None or gen is not None )):
					query = self.addJoinTable(select = select,params = params, query=query)
					query.append(" ")
				query.append(self.prop("leftJoin",select))
				query.append(" \t ")
				query.append(self.prop("where",select))
				query.append(" ")
				query.append(self.buildSimpleCondition(taxonKeyList,'bioRecordTaxonKey')) 
				query = self.addAnd(params = params,query=query)
				query.append(" ")

				
			if select=='higherTaxon':
				query.append(self.prop("select",select))			
				query.append(" \t ")
				query.append(self.prop("from",select))
				query.append(" \t ")
				query.append(self.prop("where",select))
				query.append(" ")
				query.append(self.buildSimpleCondition(taxonKeyList,'higherTaxon.taxonKey'))  
				query.append(" ")  
				if "higherTaxon" in params:
					tklist = self.replaceNotSpecified(qrm.getHigher())
					query.append(" \t ")
					if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
						query.append(self.prop("andGroup",select))  
					else:
						query.append(self.prop("and",select))
					query.append(" ")
					query.append(self.buildSimpleCondition(tklist,'higherTaxonName')) 
					if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
						query.append(" ) ")
					else:
						query.append(" ")
				
						
			if select=='recordBasis':
				query.append(self.prop("select",select))			
				query.append(" \t ")
				query.append(self.prop("from",select+extension))
				query.append(" \t ")
				if extension != "":
					query = self.addJoinTable(select = select,params = params, query=query)
					query.append(" ")
				query.append(self.prop("where",select))
				query.append(" ")
				query.append(self.buildSimpleCondition(taxonKeyList,'bioRecordTaxonKey' ) )		 
				if extension != "":
					query = self.addAnd(params = params,query=query)
					query.append(" ")
				query.append(" ")
				query.append(self.prop("groupBy",select))
				query.append(" ")
		else:
			where = []
			whereand = []
			fromT=[]
			withBiorecord = False
			
			if 'unitKey' in params or 'unitID' in params or 'collection' in params or 'institution' in params or 'locality' in params or  'collector' in params or 'collNumber' in params or 'fieldNumber' in params or'country' in params or 'multimedia' in params or 'dateSup' in params or 'dateEq' in params or 'dateInf' in params or  'coordinates' in params or (('type' in params  or 'recordBasis' in params ) and not qrm.getType() =="any") :
				recordBase = "bioRecord"
				taxonKey = "bioRecordTaxonKey"
				where.append(" \t ") 
				where.append(self.prop("where","taxonKeys"))
				where.append(" \t ") 
				withBiorecord = True
			else:
				recordBase = "taxon"
				taxonKey= "taxon.taxonKey"
				withBiorecord=False
				self.freeText=False
				
			#add select statement
			query.append(self.prop("select",select))
			query.append(" \t FROM ")
			
			if 'commonName' in params:
				whereand.append(self.prop("and",('commonName%s' %recordBase)))
				whereand.append(" \t ")
				tklist = self.replaceNotSpecified(qrm.getCommon())
				if tklist is None:
					whereand.append(self.prop("and","commonName"))
					whereand.append(" \t ")					
					whereand.append('vernacularName is null')
				else:
					if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
						fromT.append(['f',self.prop("from",'vernacular')]) #with a like so not priority
						whereand.append(self.prop("andGroup",'commonName'))  
					else:
						fromT.append(['c',self.prop("from",'vernacular')])#with a = so  priority
						whereand.append(self.prop("and",'commonName'))
					whereand.append(" \t ")				
					whereand.append(self.buildSimpleCondition(tklist,'vernacularName'))
					if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
						whereand.append(self.prop("orNull","vernacularName"))
						whereand.append(" )\t ")
					else:
						whereand.append(" \t ")
				
				
			#if len(taxonKeyList)>0 or ('collector' in params and 'taxonName' not in params and 'family' not in params and 'commonName' not in params and 'genus' not in params and 'taxon' not in params) :
			if 'country' in params:
				fromT.append(['b',self.prop("from",recordBase+'3')])
			else:
				if len(taxonKeyList)>0 or 'collector' in params or 'locality' in params or 'fieldNumber' in params or 'collNumber' in params or 'unitID' in params:
					fromT.append(['b',self.prop("from",recordBase+'1')])
				else:
					fromT.append(['d',self.prop("from",recordBase+'2')])
			
			if 'collection' in params or 'institution' in params or 'collector' in params: 
				# improve the join query : respect the order!
				query.append(" \t ")	
				added=False
				if 'collection' in params:
					tklist = self.replaceNotSpecified(qrm.getCollection())
					if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
						whereand.append(self.prop("andGroup",'collection'))  
						added=True
					else:
						whereand.append(self.prop("and","collection"))
						added=True
					whereand.append(" \t ")					
					whereand.append(self.buildSimpleCondition(tklist,'collection_code'))
					if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
						whereand.append(" )\t ")
					else:
						whereand.append(" \t ")
				
				if 'institution' in params:
					tklist = self.replaceNotSpecified(qrm.getInstitution())
					if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
						whereand.append(self.prop("andGroup",'institution'))  
					else:
						whereand.append(self.prop("and","institution"))
					whereand.append(" \t ")					
					whereand.append(self.buildSimpleCondition(tklist,'institution_code'))
					if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
						whereand.append(" )\t ")
					else:
						whereand.append(" \t ")
						
				if 'collector' in params:
					whereand.append(" \t ")
					tklist = self.replaceNotSpecified(qrm.getCollector())
					if tklist is None:
						whereand.append(" \t ")
						whereand.append(self.prop("andNull","collector"))	
						whereand.append(" \t ")
					else:	
						if self.cfgObj.admin.unitsDatabase == "mssql":
							if querymn.get("advancedSearch",False): #FULL TEXT SEARCH
								if "," in tklist and "(" not in tklist:
									tklist= "(" + tklist
								if "," in tklist and ")" not in tklist:
									tklist += ")"
									
								phrase=False
								if type(tklist)!=ListType:
									table = tklist.replace("'","").strip()
									if table[0] == '"':
										phrase=True
									else:
										table = tklist.replace("(","").replace(")","").replace("'","").split(" ")
								else:
									table = tklist
								whereand.append(" AND (")
								first=True
								tmpPlus=[]
								tmpMoins=[]
								tmpOu=[]
								self.freeText=True
								if not phrase:
									for coll in table:
										if coll[0] !="-" and len(coll)>0:
											if '"' not in coll:
												tmpPlus.append('"%s"'%coll)
											else:
												tmpPlus.append(coll)
										else:
											if coll[0] =="-"  and len(coll)>0 :
												if '"' not in coll:
													tmpMoins.append('"%s"'%coll[1:])
												else:
													tmpMoins.append(coll[1:])
#											else:
#												tmpOu.append(coll)
									if len(tmpPlus)>0:
										whereand.append(self.prop("and","collectorFT")%' AND '.join(tmpPlus).replace('%','*'))
										first=False
									if len(tmpMoins)>0:
										if not first:
											whereand.append(" AND NOT ")
											first=False
										whereand.append(self.prop("and","collectorFT")%' AND '.join(tmpMoins).replace('%','*'))
									if len(tmpOu)>0:
										if not first:
											whereand.append(" AND ")
											first=False
										whereand.append(self.prop("and","collectorFT")%' OR '.join(tmpOu))
									
								else:
									if table[0] == '"' and len(table)>0:
										if not first:
											whereand.append(" AND ")
										whereand.append(self.prop("and","collectorFT")%table)
										first=False
								whereand.append(" )")
							else:
								if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
									whereand.append(self.prop("andGroup",'collector'))  
								else:
									whereand.append(self.prop("and","collector"))
								whereand.append(" \t ")					
								whereand.append(self.buildSimpleCondition(tklist,'biorecord.collector'))
								if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
									whereand.append(self.prop("orNull","collector"))
									whereand.append(" )\t ")
								else:
									whereand.append(" \t ")
						else:
							if querymn.get("advancedSearch",False): #FULL TEXT SEARCH
								if "," in tklist and "(" not in tklist:
									tklist= "(" + tklist
								if "," in tklist and ")" not in tklist:
									tklist += ")"
									
								if type(tklist)!=type([]):
									table = tklist.replace("(","").replace(")","").replace("'","").split(",")
								else:
									table = tklist
								tmp=[]
								for elt in table:
									if elt[0]!="-":
										elt="+"+elt
									tmp.append(elt)
								table=tmp
								coll=" ".join(table)
								whereand.append(self.prop("and","collectorFT"))
								whereand.append(" ('%s'  IN BOOLEAN MODE ) "%coll)	
							else:
								if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
									whereand.append(self.prop("andGroup",'collector'))  
								else:
									whereand.append(self.prop("and","collector"))
								whereand.append(" \t ")					
								whereand.append(self.buildSimpleCondition(tklist,'collector'))
								if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
									whereand.append(self.prop("orNull","collector"))
									whereand.append(" )\t ")
								else:
									whereand.append(" \t ")


							
			if 'multimedia' in params:
				fromT.append(['d',self.prop("from",'multimedia')])
				query.append(" \t ")
				whereand.append(self.prop("and","multimedia"))
				whereand.append(" \t ")
										  
			
			if 'collNumber' in params:
				tklist=self.replaceNotSpecified(qrm.getCollNumber())
				if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
						whereand.append(self.prop("andGroup",'collNumber'))  
				else:
					whereand.append(self.prop("and","collNumber"))
				whereand.append(" \t ")					
				whereand.append(self.buildSimpleCondition(tklist,'collNumber'))
				if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
					whereand.append(" )\t ")
				else:
					whereand.append(" \t ")
					
			if 'fieldNumber' in params:
				tklist=self.replaceNotSpecified(qrm.getFieldNumber())
				if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
						whereand.append(self.prop("andGroup",'fieldNumber'))  
				else:
					whereand.append(self.prop("and","fieldNumber"))
				whereand.append(" \t ")					
				whereand.append(self.buildSimpleCondition(tklist,'fieldNumber'))
				if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
					whereand.append(" )\t ")
				else:
					whereand.append(" \t ")
			
			if 'unitKey' in params:
				whereand.append(" \t ")
				lista = qrm.getUnit()
				if ("," in lista and ("*" in lista or "%" in lista)) or 'null' in lista:
					whereand.append(self.prop("andGroup",'bioRecordKey'))  
				else:
					whereand.append(self.prop("and","bioRecordKey"))
				whereand.append(" \t ")				 
				tklist = replaceReservedCaracters(lista)
				whereand.append(" \t ")
				whereand.append(self.buildSimpleCondition(tklist,'bioRecordKey'))
				if ("," in lista and ("*" in lista or "%" in lista)) or 'null' in lista:
					whereand.append(" )\t ")
				else:
					whereand.append(" \t ")
					
			if 'unitID' in params:
				whereand.append(" \t ")
				lista = qrm.getUnitID()
				if ("," in lista and ("*" in lista or "%" in lista)) or 'null' in lista:
					whereand.append(self.prop("andGroup",'bioRecordId'))  
				else:
					whereand.append(self.prop("and","bioRecordId"))
				whereand.append(" \t ")				 
				tklist = replaceReservedCaracters(lista)
				whereand.append(" \t ")
				whereand.append(self.buildSimpleCondition(tklist,'bioRecordId'))
				if ("," in lista and ("*" in lista or "%" in lista)) or 'null' in lista:
					whereand.append(" )\t ")
				else:
					whereand.append(" \t ")
			
#			if 'taxon' in params and refineTaxon:
#				query.append(" \t ")
#				tklist = self.replaceNotSpecified(qrm.getTaxon())
#				if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
#					whereand.append(self.prop("andGroup",'taxonName'))  
#				else:
#					whereand.append(self.prop("and","taxonName"))
#				whereand.append(" \t ")
#				whereand.append(self.buildSimpleCondition(tklist,'taxonName'))
#				if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
#					whereand.append(" )\t ")
#				else:
#					whereand.append(" \t ")
#				

			if 'locality' in params:
				tklist = self.replaceNotSpecified(qrm.getLocality())
				if tklist is None:
					whereand.append(" \t ")
					whereand.append(self.prop("andNull","locality"))	
					whereand.append(" \t ")
				else:
					if self.cfgObj.admin.unitsDatabase == "mssql":
						if querymn.get("advancedSearch",False): #FULL TEXT SEARCH
							if "," in tklist and "(" not in tklist:
								tklist= "(" + tklist
							if "," in tklist and ")" not in tklist:
								tklist += ")"
							phrase=False
							if type(tklist)!=ListType:
								table = tklist.replace("'","").strip()
								if table[0] == '"':
									phrase=True
								else:
									table = tklist.replace("(","").replace(")","").replace("'","").split(" ")
							else:
								table = tklist
							whereand.append(" AND (")
							first=True
							tmpPlus=[]
							tmpMoins=[]
							tmpOu=[]
							self.freeText=True
							if not phrase:
								for coll in table:
									if coll[0] !="-" and len(coll)>0:
										if '"' not in coll:
											tmpPlus.append('"%s"'%coll)
										else:
											tmpPlus.append(coll)
									else:
										if coll[0] =="-"  and len(coll)>0 :
											if '"' not in coll:
												tmpMoins.append('"%s"'%coll[1:])
											else:
												tmpMoins.append(coll[1:])
	#										else:
	#											tmpOu.append(coll)
								if len(tmpPlus)>0:
									whereand.append(self.prop("and","localityFT")%' AND '.join(tmpPlus).replace('%','*'))
									first=False
								if len(tmpMoins)>0:
									if not first:
										whereand.append(" AND NOT ")
										first=False
									whereand.append(self.prop("and","localityFT")%' AND '.join(tmpMoins).replace('%','*'))
								if len(tmpOu)>0:
									if not first:
										whereand.append(" AND ")
										first=False
									whereand.append(self.prop("and","localityFT")%' OR '.join(tmpOu))
							else:
								if not first:
									whereand.append(" AND ")
								whereand.append(self.prop("and","localityFT")%table)
								first=False
								
							whereand.append(" )")
#						else:
#							if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
#								whereand.append(self.prop("andGroup",'locality'))  
#							else:
#								whereand.append(self.prop("and","locality"))
#							whereand.append(" \t ")				
#							whereand.append(self.buildSimpleCondition(tklist,'biorecord.localityText'))
#							if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
#								whereand.append(self.prop("orNull","locality"))
#								whereand.append(" )\t ")
#							else:
#								whereand.append(" \t ")
					else:
						if querymn.get("advancedSearch",False): #FULL TEXT SEARCH
							if "," in tklist and "(" not in tklist:
								tklist= "(" + tklist
							if "," in tklist and ")" not in tklist:
								tklist += ")"
								
							if type(tklist)!=type([]):
								table = tklist.replace("(","").replace(")","").replace("'","").split(",")
							else:
								table = tklist
							tmp=[]
							for elt in table:
								if elt[0]!="-":
									elt="+"+elt
								tmp.append(elt)
							table=tmp
							coll=" ".join(table)
							whereand.append(self.prop("and","localityFT"))
							whereand.append(" ('%s'  IN BOOLEAN MODE  ) "%coll)	
#						else:
#							if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
#								whereand.append(self.prop("andGroup",'locality'))  
#							else:
#								whereand.append(self.prop("and","locality"))
#							whereand.append(" \t ")				
#							whereand.append(self.buildSimpleCondition(tklist,'localityText'))
#							if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
#								whereand.append(self.prop("orNull","locality"))
#								whereand.append(" )\t ")
#							else:
#								whereand.append(" \t ")

							
			if 'higherTaxon' in params:
				query.append(" \t ")
				whereand.append(self.prop("and",('higherTaxon%s'%recordBase)))
				whereand.append(" \t ")
				tklist = self.replaceNotSpecified(qrm.getHigher())
				if tklist is None:
					whereand.append(" \t ")
					whereand.append(self.prop("andNull","higherTaxon"))	
					whereand.append(" \t ")
				else:
					if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
						fromT.append(['f',self.prop("from",'higherTaxon')])
						whereand.append(self.prop("andGroup",'higherTaxon'))  
					else:
						fromT.append(['c',self.prop("from",'higherTaxon')])
						whereand.append(self.prop("and",'higherTaxon'))
					whereand.append(" \t ")				
					whereand.append(self.buildSimpleCondition(tklist,'higherTaxon.higherTaxonName'))
					if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
						whereand.append(self.prop("orNull","higherTaxon"))
						whereand.append(" )\t ")
					else:
						whereand.append(" \t ")
					
			if 'dateInf' in params or 'dateSup' in params:
				whereand.append(" \t ")
				dateInf=qrm.getDateInf()
				dateSup=qrm.getDateSup()
				if dateInf is None:
					dateInf=0
				if dateSup is None:
					dateSup=0
				if dateInf>dateSup:
					tmp=dateSup
					dateSup=dateInf
					dateInf=dateSup
				whereand.append(self.prop("and","dates")%(dateInf,dateSup))
				whereand.append(" \t ")				
				
			if 'coordinates' in params:	
				whereand.append(" \t ")	 
				coordinates = self.replaceNotSpecified(qrm.getCoordinates())
				if coordinates is None:
					whereand.append(" \t ")
					whereand.append(self.prop("andNull","coordinates"))	
					whereand.append(" \t ")
				else:
					whereand.append(self.prop("and","coordinates") %( coordinates[0],coordinates[1],coordinates[2],coordinates[3]))
					whereand.append(" \t ")
				
			if ('type' in params  or 'recordBasis' in params ) and not qrm.getType() =="any"  : 
				tklist = self.removeAbbreviation(qrm.getType())
				tklist = replaceReservedCaracters(tklist)
				querymn = cherrypy.session.get('u_qmg',{})
				if len(tklist)>0:  
					whereand.append(" \t ")
					whereand.append(self.prop("andGroup","recordBasis"))
					whereand.append(" \t ")					
					whereand.append(" \t ")
					whereand.append(self.buildSimpleCondition(tklist,'recordBasis'))
				if querymn.get('hasRecordBasis',False) == True and len(tklist)>0:
					whereand.append(" \t ")
					whereand.append(self.prop("orNull","recordBasis"))
				elif querymn.get('hasRecordBasis',False) == True :
					whereand.append(" \t ")
					whereand.append(self.prop("andNull","recordBasis"))					
				if len(tklist)>0:			  
					whereand.append(" )\t ") 
				else:
					whereand.append(" \t ")
				
			if 'family' in params and select not in ["taxon","genus"]:
				query.append(" \t ")
				whereand.append(self.prop("and",('family%s'%recordBase)))
				whereand.append(" \t ")
				tklist = self.replaceNotSpecified(qrm.getFamily())
				if tklist is None:
					whereand.append(" \t ")
					whereand.append(self.prop("andNull","family"))	
					whereand.append(" \t ")
				else:
					if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
						fromT.append(['f',self.prop("from",'family')])
						whereand.append(self.prop("andGroup",'family'))  
					else:
						fromT.append(['c',self.prop("from",'family')])
						whereand.append(self.prop("and",'family'))
					whereand.append(" \t ")				
					whereand.append(self.buildSimpleCondition(tklist,'family'))
					if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
						whereand.append(self.prop("orNull","family"))
						whereand.append(" )\t ")
					else:
						whereand.append(" \t ")
			else:
				if 'family' in params:
					query.append(" \t ")
					tklist = self.replaceNotSpecified(qrm.getFamily())
					if tklist is None:
						whereand.append(" \t ")
						whereand.append(self.prop("andNull","family"))
						whereand.append(" \t ")
					else:	
						if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
							whereand.append(self.prop("andGroup",'family'))  
						else:
							whereand.append(self.prop("and","family"))
						whereand.append(" \t ")
						query.append(" \t ")				
						whereand.append(self.buildSimpleCondition(tklist,'family'))
						query.append(" \t ")
						if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
							whereand.append(self.prop("orNull","family"))
							whereand.append(" )\t ")
						else:
							whereand.append(" \t ")	
				

			if 'genus' in params  and select not in ["taxon","genus"]:
				query.append(" \t ")
				whereand.append(self.prop("and",('genus%s'%recordBase)))
				whereand.append(" \t ")
				tklist = self.replaceNotSpecified(qrm.getGenus())
				if tklist is None:
					whereand.append(" \t ")
					whereand.append(self.prop("andNull","genus"))	
					whereand.append(" \t ")
				else:
					if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
						fromT.append(['f',self.prop("from",'genus')])
						whereand.append(self.prop("andGroup",'genus'))  
					else:
						fromT.append(['c',self.prop("from",'genus')])
						whereand.append(self.prop("and",'genus'))
					whereand.append(" \t ")				
					whereand.append(self.buildSimpleCondition(tklist,'genus'))
					if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
						whereand.append(self.prop("orNull","genus"))
						whereand.append(" )\t ")
					else:
						whereand.append(" \t ")
			else:
				if 'genus' in params:
					query.append(" \t ")
					tklist = self.replaceNotSpecified(qrm.getGenus())
					if tklist is None:
						whereand.append(" \t ")
						whereand.append(self.prop("andNull","genus"))
						whereand.append(" \t ")
					else:	
						if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
							whereand.append(self.prop("andGroup",'genus'))  
						else:
							whereand.append(self.prop("and","genus"))
						whereand.append(" \t ")
						whereand.append(self.buildSimpleCondition(tklist,'genus'))
						if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
							whereand.append(self.prop("orNull","genus"))
							whereand.append(" )\t ")
						else:
							whereand.append(" \t ")
						query.append(" \t ")  
				
			if 'country' in params:
				query.append(" \t ")
				whereand.append(" \t ")
				tklist = self.replaceNotSpecified(qrm.getCountry())
				if tklist is None:
					whereand.append(" \t ")
					whereand.append(self.prop("andNull","country"))
					whereand.append(" \t ")
				else:	
					if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
						whereand.append(self.prop("andGroup",'country'))  
					else:
						whereand.append(self.prop("and","country"))
					whereand.append(" \t ")				
					whereand.append(self.buildSimpleCondition(tklist,'countryName'))
					if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
						whereand.append(self.prop("orNull","country"))
						whereand.append(" )\t ")
					else:
						whereand.append(" \t ")
					query.append(" \t ")	
			
			if len(taxonKeyList)>0:	
				where.append(" \t ")
				if withBiorecord:
					where.append(self.prop("and",'taxonKey'+recordBase))
				else:
					where.append(self.prop("where",'taxonKey'+recordBase))
				where.append(" \t ")
				tklist = taxonKeyList
				where.append(self.buildSimpleCondition(tklist,taxonKey))
				where.append(" \t ")
			else:
				query.append(" \t ")
				if withBiorecord:
					tklist = self.replaceNotSpecified(qrm.getTaxon())
					if tklist is not None and len(tklist)>0:
						if "," in tklist and ("*" in tklist or "%" in tklist):
							whereand.append(self.prop("andGroup",'taxonName'))  
						else:
							whereand.append(self.prop("and",'taxonName'))
						whereand.append(" \t ")					
						whereand.append(self.buildSimpleCondition(tklist,'taxon.taxonName'))
						if ("," in tklist and ("*" in tklist or "%" in tklist)):
							whereand.append(" )\t ")
						else:
							whereand.append(" \t ")
				else:
					where.append(" \t ")
					tklist = self.replaceNotSpecified(qrm.getTaxon())
					if tklist is not None and len(tklist)>0:
						if "," in tklist and ("*" in tklist or "%" in tklist):
							where.append(self.prop("whereGroup",'taxonName'))  
						else:
							where.append(self.prop("where",'taxonName'))
						where.append(" \t ")					
						where.append(self.buildSimpleCondition(tklist,'taxon.taxonName'))
						if "," in tklist and ("*" in tklist or "%" in tklist):
							where.append(" )\t ")
						else:
							where.append(" \t ")	
			
			if self.freeText and ("collector" in params or "locality" in params) and self.cfgObj.admin.unitsDatabase == "mssql":
				fromT.append(['e',self.prop("from",'extension')])
				where.append(" \t ")
				where.append(self.prop("and",'bioRecord_ext'))	
							
			if 'taxon' in select:
				if 'bioRecord' not in recordBase:
					fromT.append(['e',self.prop("from",'bioRecord')])
					query.append(" ")
					whereand.append(" \t ")	
					if self.prop("and",'taxonKeyjoinBR') not in whereand:
						whereand.append(self.prop("and",'taxonKeyjoinBR'))
					whereand.append(" ")	
				whereand.append(" ")	
				whereand.append(self.prop("groupBy",'taxonName')) 
			
					
			query.append(" ")
			fromT.sort(lambda x,y:cmp(x[0],y[0]))
			if self.cfgObj.admin.unitsDatabase == "mysql":
				tmp=[elt[1] for elt in fromT]
			else:
				tmp=[elt[1].replace("tojoinFamily", self.prop("joinOn",'taxonKeyjoinBR')) for elt in fromT]

			query.append(", ".join(tmp))
			query.append(" ")
			query.append(" "+" ".join(where))
			query.append(" ")
			query.append(" "+" ".join(whereand))
			tmp=" ".join(query)
			found=False
			if "where" not in tmp.lower():
				tmp=[]
				for elt in query:
					if " and " not in elt.lower() or found:
						tmp.append(elt)
					else:
						if not found:
							pif=elt.replace(' and ',' where ',1)
							if pif == elt:
								pif=elt.replace(' AND ',' where ',1)
							tmp.append(pif)
							found=True
				return tmp
		return query				 
				
				
	def addJoinTable(self,select="",params=[],joinTaxon=True,query=[]):
		if joinTaxon:
			recordBase = "bioRecord"
		else:
			recordBase = "taxon"
			
		
		if select != 'country' and 'country' in params:
			query.append(" LEFT JOIN isoCountry  ON isoCountryCode = bioRecordCountryCode")

		if select !='multimedia' and 'multimedia' in params:
			if self.cfgObj.admin.unitsDatabase == "mysql":
				query.append(" JOIN imageRecord ")
			else:
				query.append(" JOIN imageRecord ON biorecordkey =  imagerecordbiorecordkey")
			
		if select !='genus' and select !='family' and select!='taxon'and ('family' in params or 'genus' in params) and joinTaxon:
			if self.cfgObj.admin.unitsDatabase == "mysql":
				query.append(" JOIN taxon  ")
			else:
				query.append(" JOIN taxon ON tojoinFamily")
			
		if select !='higherTaxon' and 'higherTaxon' in params:
			if self.cfgObj.admin.unitsDatabase == "mysql":
				query.append(" JOIN higherTaxon  ") 
			else:
				query.append(" JOIN higherTaxon ON tojoinHigher ") 
			
		if select !='commonName' and 'commonName' in params:
			if self.cfgObj.admin.unitsDatabase == "mysql":
				query.append(" JOIN vernacularName ") 
			else:
				query.append(" JOIN vernacularName ON tojoinCommon ") 
		
		if self.cfgObj.admin.unitsDatabase == "mssql":	
#			if (select !='collector' and 'collector' in params) or (select !='locality' and 'locality' in params) and self.freeText:
			if ('collector' in params or 'locality' in params):
				query.append(" JOIN biorecord_ext ON biorecordkey =  brkey")
			
		return query
			
	def addAnd(self,params=[],joinTaxon=True,query=[]):
		qrm = QueryReminder()	
		querymn = cherrypy.session.get('u_qmg')
		if  'unitKey' in params:			
			query.append(" \t ") 
			lista = qrm.getUnit() 
			if "," in lista and ("*" in lista or "%" in lista):
				query.append(self.prop("andGroup",'bioRecordKey'))  
			else:
				query.append(self.prop("and","bioRecordKey"))						
			tklist = replaceReservedCaracters(lista)
			query.append(" \t ")
			query.append(self.buildSimpleCondition(tklist,'bioRecordKey'))
			if "," in lista and ("*" in lista or "%" in lista):
				query.append(" )\t ")	
			else:
				query.append(" \t ")	
				
		if  'unitID' in params:			
			query.append(" \t ") 
			lista = qrm.getUnitID() 
			if "," in lista and ("*" in lista or "%" in lista):
				query.append(self.prop("andGroup",'bioRecordId'))  
			else:
				query.append(self.prop("and","bioRecordId"))						
			tklist = replaceReservedCaracters(lista)
			query.append(" \t ")
			query.append(self.buildSimpleCondition(tklist,'bioRecordId'))
			if "," in lista and ("*" in lista or "%" in lista):
				query.append(" )\t ")	
			else:
				query.append(" \t ")	 
			
		if 'collection' in params or 'institution' in params or 'collector' in params :
			query.append(" \t ")
			if 'collection' in params:
				query.append(" \t ")
				tklist = self.replaceNotSpecified(qrm.getCollection())
				if "," in tklist and ("*" in tklist or "%" in tklist):
					query.append(self.prop("andGroup",'collection'))  
				else:
					query.append(self.prop("and","collection"))
				query.append(" \t ")				
				query.append(self.buildSimpleCondition(tklist,'collection_code'))
				if "," in tklist and ("*" in tklist or "%" in tklist):
					query.append(" )\t ")	
				else:
					query.append(" \t ")  
			if 'institution' in params:
				query.append(" \t ")
				tklist = self.replaceNotSpecified(qrm.getInstitution())
				if "," in tklist and ("*" in tklist or "%" in tklist):
					query.append(self.prop("andGroup",'institution'))  
				else:
					query.append(self.prop("and","institution"))
				query.append(" \t ")				
				query.append(self.buildSimpleCondition(tklist,'institution_code'))
				if "," in tklist and ("*" in tklist or "%" in tklist):
					query.append(" )\t ")	
				else:
					query.append(" \t ")  
			if 'collector' in params:
				query.append(" \t ")
				tklist = self.replaceNotSpecified(qrm.getCollector())
#				log.info("collector in params %s" %tklist)
				if tklist is None:
					query.append(" \t ")
					query.append(self.prop("andNull","collector"))
				else:
					if self.cfgObj.admin.unitsDatabase == "mssql":
						if querymn.get("advancedSearch",False): #FULL TEXT SEARCH
							if "," in tklist and "(" not in tklist:
								tklist= "(" + tklist
							if "," in tklist and ")" not in tklist:
								tklist += ")"
								
							phrase=False
							if type(tklist)!=ListType:
								table = tklist.replace("'","").strip()
								if table[0] == '"':
									phrase=True
								else:
									table = tklist.replace("(","").replace(")","").replace("'","").split(" ")
							else:
								table = tklist
							query.append(" AND (")
							first=True
							self.freeText=True
							tmpPlus=[]
							tmpMoins=[]
							tmpOu=[]
							if not phrase:
								for coll in table:
									if coll[0] !="-" and len(coll)>0:
										if '"' not in coll:
											tmpPlus.append('"%s"'%coll)
										else:
											tmpPlus.append(coll)
									else:
										if coll[0] =="-"  and len(coll)>0 :
											if '"' not in coll:
												tmpMoins.append('"%s"'%coll[1:])
											else:
												tmpMoins.append(coll[1:])
#										else:
#											tmpOu.append(coll)
								if len(tmpPlus)>0:
									query.append(self.prop("and","collectorFT")%' AND '.join(tmpPlus).replace('%','*'))
									first=False
								if len(tmpMoins)>0:
									if not first:
										query.append(" AND NOT ")
										first=False
									query.append(self.prop("and","collectorFT")%' AND '.join(tmpMoins).replace('%','*'))
								if len(tmpOu)>0:
									if not first:
										query.append(" AND ")
										first=False
									query.append(self.prop("and","collectorFT")%' OR '.join(tmpOu))
										
							else:
								if table[0] == '"' and len(table)>0:
									if not first:
										query.append(" AND ")
									query.append(self.prop("and","collectorFT")%table)
									first=False
							query.append(" )")
						else:	
							if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
								query.append(self.prop("andGroup",'collector'))  
							else:
								query.append(self.prop("and","collector"))
							query.append(" \t ")				
							query.append(self.buildSimpleCondition(tklist,'biorecord.collector'))
							if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
								query.append(self.prop("orNull","collector"))
								query.append(" )\t ")	
							else:
								query.append(" \t ")  
					else:
						if querymn.get("advancedSearch",False): #FULL TEXT SEARCH
							if "," in tklist and "(" not in tklist:
								tklist= "(" + tklist
							if "," in tklist and ")" not in tklist:
								tklist += ")"
								
							if type(tklist)!=type([]):
								table = tklist.replace("(","").replace(")","").replace("'","").split(",")
							else:
								table = tklist
							tmp=[]
							for elt in table:
								if elt[0]!="-":
									elt="+"+elt
								tmp.append(elt)
							table=tmp
							coll=" ".join(table)
							query.append(self.prop("and","collectorFT"))
							query.append(" ('%s'  IN BOOLEAN MODE   ) "%coll)	
						else:	
							if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
								query.append(self.prop("andGroup",'collector'))  
							else:
								query.append(self.prop("and","collector"))
							query.append(" \t ")				
							query.append(self.buildSimpleCondition(tklist,'collector'))
							if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
								query.append(self.prop("orNull","collector"))
								query.append(" )\t ")	
							else:
								query.append(" \t ")   
		
		if 'collNumber' in params:
				query.append(" \t ")
				tklist = self.replaceNotSpecified(qrm.getCollNumber())
				if "," in tklist and ("*" in tklist or "%" in tklist):
					query.append(self.prop("andGroup",'collNumber'))  
				else:
					query.append(self.prop("and","collNumber"))
				query.append(" \t ")				
				query.append(self.buildSimpleCondition(tklist,'collNumber'))
				if "," in tklist and ("*" in tklist or "%" in tklist):
					query.append(" )\t ")	
				else:
					query.append(" \t ")  
		if 'fieldNumber' in params:
				query.append(" \t ")
				tklist = self.replaceNotSpecified(qrm.getFieldNumber())
				if "," in tklist and ("*" in tklist or "%" in tklist):
					query.append(self.prop("andGroup",'fieldNumber'))  
				else:
					query.append(self.prop("and","fieldNumber"))
				query.append(" \t ")				
				query.append(self.buildSimpleCondition(tklist,'fieldNumber'))
				if "," in tklist and ("*" in tklist or "%" in tklist):
					query.append(" )\t ")	
				else:
					query.append(" \t ")
					
		if  'locality' in params:
			query.append(" \t ")
			tklist = self.replaceNotSpecified(qrm.getLocality())
			if tklist is None:
				query.append(" \t ")
				query.append(self.prop("andNull","locality"))
			else:
				if self.cfgObj.admin.unitsDatabase == "mssql":
					if querymn.get("advancedSearch",False): #FULL TEXT SEARCH
						if "," in tklist and "(" not in tklist:
							tklist= "(" + tklist
						if "," in tklist and ")" not in tklist:
							tklist += ")"
							
						phrase=False
						if type(tklist)!=ListType:
							table = tklist.replace("'","").strip()
							if table[0] == '"':
								phrase=True
							else:
								table = tklist.replace("(","").replace(")","").replace("'","").split(" ")
						else:
							table = tklist
						query.append(" AND (")
						first=True
						self.freeText=True
						tmpPlus=[]
						tmpMoins=[]
						tmpOu=[]
						if not phrase:
							for coll in table:
								if coll[0] !="-" and len(coll)>0:
									if '"' not in coll:
										tmpPlus.append('"%s"'%coll)
									else:
										tmpPlus.append(coll)
								else:
									if coll[0] =="-"  and len(coll)>0 :
										if '"' not in coll:
											tmpMoins.append('"%s"'%coll[1:])
										else:
											tmpMoins.append(coll[1:])
	#									else:
	#										tmpOu.append(coll)
							if len(tmpPlus)>0:
								query.append(self.prop("and","localityFT")%' AND '.join(tmpPlus).replace('%','*'))
								first=False
							if len(tmpMoins)>0:
								if not first:
									query.append(" AND NOT ")
									first=False
								query.append(self.prop("and","localityFT")%' AND '.join(tmpMoins).replace('%','*'))
							if len(tmpOu)>0:
								if not first:
									query.append(" AND ")
									first=False
								query.append(self.prop("and","localityFT")%' OR '.join(tmpOu))
						else:
							if table[0] == '"' and len(table)>0:
								if not first:
									query.append(" AND ")
								query.append(self.prop("and","localityFT")%table)
								first=False
						query.append(" )")
#					else:	
#						if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
#							query.append(self.prop("andGroup",'locality'))  
#						else:
#							query.append(self.prop("and","locality"))
#						query.append(" \t ")			
#						query.append(self.buildSimpleCondition(tklist,'biorecord.localityText'))
#						if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
#							query.append(self.prop("orNull","locality"))
#							query.append(" )\t ")	
#						else:
#							query.append(" \t ")  
						
				else:
					if querymn.get("advancedSearch",False): #FULL TEXT SEARCH
						if "," in tklist and "(" not in tklist:
							tklist= "(" + tklist
						if "," in tklist and ")" not in tklist:
							tklist += ")"
							
						if type(tklist)!=type([]):
							table = tklist.replace("(","").replace(")","").replace("'","").split(",")
						else:
							table = tklist
						tmp=[]
						for elt in table:
							if elt[0]!="-":
								elt="+"+elt
							tmp.append(elt)
						table=tmp
						coll=" ".join(table)
						query.append(self.prop("and","localityFT"))
						query.append(" ('%s'  IN BOOLEAN MODE    ) "%coll)	
#					else:	
#						if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
#							query.append(self.prop("andGroup",'locality'))  
#						else:
#							query.append(self.prop("and","locality"))
#						query.append(" \t ")			
#						query.append(self.buildSimpleCondition(tklist,'localityText'))
#						if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
#							query.append(self.prop("orNull","locality"))
#							query.append(" )\t ")	
#						else:
#							query.append(" \t ")  

						
		if  'country' in params:
			query.append(" \t ")
			tklist = self.replaceNotSpecified(qrm.getCountry())
			if tklist is None:
				query.append(" \t ")
				query.append(self.prop("andNull","country"))
				query.append(" \t ")
			else:	
				if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
					query.append(self.prop("andGroup",'country'))  
				else:
					query.append(self.prop("and","country"))
				query.append(" \t ")			
				query.append(self.buildSimpleCondition(tklist,'countryName'))
				if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
					query.append(self.prop("orNull","country"))
					query.append(" )\t ")	
				else:
					query.append(" \t ")  
			
		if  'higherTaxon' in params:
#			if joinTaxon:
			query.append(" \t ")
			if self.cfgObj.admin.unitsDatabase == "mysql":
				query.append(self.prop("and","taxonKeyjoinHigher"))
			else:
				query=[' '.join(query).replace("tojoinHigher", self.prop("joinOn",'taxonKeyjoinHigher'))]
			query.append(" \t ")
			tklist = self.replaceNotSpecified(qrm.getHigher())
			if tklist is None:
				query.append(" \t ")
				query.append(self.prop("andNull","higherTaxon"))
				query.append(" \t ")
			else:
				query.append(" \t ")
				if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
					query.append(self.prop("andGroup",'higherTaxon'))  
				else:
					query.append(self.prop("and",'higherTaxon'))
				query.append(" \t ")			
				query.append(self.buildSimpleCondition(tklist,'higherTaxon.higherTaxonName'))
				if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
					query.append(self.prop("orNull","higherTaxon"))
					query.append(" )\t ")	
				else:
					query.append(" \t ")			
			
		if  'commonName' in params:
			query.append(" \t ")
			if self.cfgObj.admin.unitsDatabase == "mysql":
				query.append(self.prop("and",'commonNamebioRecord'))
			else:
				query=[' '.join(query).replace("tojoinCommon", self.prop("joinOn",'commonNamebioRecord'))]
			query.append(" \t ")
			tklist = self.replaceNotSpecified(qrm.getCommon())
			if tklist is None:
				query.append(" \t ")
				query.append(self.prop("andNull","commonName"))
				query.append(" \t ")
			else:
				query.append(" \t ")
				if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
					query.append(self.prop("andGroup",'commonName'))  
				else:
					query.append(self.prop("and",'commonName'))  
				query.append(" \t ")		  
				query.append(self.buildSimpleCondition(tklist,'vernacularName'))
				query.append(" \t ") 
				if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
					query.append(self.prop("orNull","commonName"))
					query.append(" )\t ")	
				else:
					query.append(" \t ")		
		
		if self.cfgObj.admin.unitsDatabase == "mysql":		
			if  'multimedia' in params:
				query.append(" \t ")
				query.append(self.prop("and","multimedia"))
				query.append(" \t ")	
			
		if 'dateInf' in params or 'dateSup' in params:
			query.append(" \t ")
			dateInf=qrm.getDateInf()
			dateSup=qrm.getDateSup()
			if dateInf is None:
				dateInf=0
			if dateSup is None:
				dateSup=0
			if dateInf>dateSup:
				tmp=dateSup
				dateSup=dateInf
				dateInf=dateSup
			query.append(self.prop("and","dates")%(dateInf,dateSup))
			query.append(" \t ")	
			
		if 'coordinates' in params:	
			query.append(" \t ")	 
			coordinates = self.replaceNotSpecified(qrm.getCoordinates())
			if coordinates is None:
				query.append(" \t ")
				query.append(self.prop("andNull","coordinates"))
				query.append(" \t ")
			else:
				query.append(self.prop("and","coordinates") %( coordinates[0],coordinates[1],coordinates[2],coordinates[3]))
				query.append(" \t ")
			
		
		if ('type' in params  or 'recordBasis' in params ) and not qrm.getType() =="any" :  
			tklist = self.removeAbbreviation(qrm.getType())
			tklist = tklist
			tklist = replaceReservedCaracters(tklist)
			querymn = cherrypy.session.get('u_qmg',{})
			if len(tklist)>0:  
				query.append(" \t ") 
				query.append(self.prop("andGroup","recordBasis"))
				query.append(" \t ")
				query.append(self.buildSimpleCondition(tklist,'recordBasis'))
			if querymn.get('hasRecordBasis',False) == True and len(tklist)>0:
				query.append(" \t ")
				query.append(self.prop("orNull","recordBasis"))
			elif querymn.get('hasRecordBasis',False) == True :
				query.append(" \t ")
				query.append(self.prop("andNull","recordBasis"))
			if len(tklist)>0:			  
				query.append(" )\t ") 
			else:
				query.append(" \t ") 
		
		
		if ('family' in params or 'genus' in params) and  joinTaxon:
			query.append(" \t ")
			if self.cfgObj.admin.unitsDatabase == "mysql":
				query.append(self.prop("and","taxonKeyjoinBR"))
			else:
				log.info("DOIT FAIRE LE REPLACE TOJOINFAMILY AVEC taxonKeyjoinBR")
				query=[" ".join(query).replace("tojoinFamily", self.prop("joinOn",'taxonKeyjoinBR'))]
			query.append(" \t ")
			
		if 'family' in params and joinTaxon:
			query.append(" \t ")
			tklist = self.replaceNotSpecified(qrm.getFamily())
			if tklist is None:
				query.append(" \t ")
				query.append(self.prop("andNull","family"))
				query.append(" \t ")
			else:
				if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
					query.append(self.prop("andGroup",'family'))  
				else:
					query.append(self.prop("and","family"))
				query.append(" \t ")			
				query.append(self.buildSimpleCondition(tklist,'family'))
				if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
					query.append(self.prop("orNull","family"))
					query.append(" )\t ")	
				else:
					query.append(" \t ")				  

		if 'genus' in params and joinTaxon:
			query.append(" \t ")
			tklist = self.replaceNotSpecified(qrm.getGenus())
			if tklist is None:
				query.append(" \t ")
				query.append(self.prop("andNull","genus"))
				query.append(" \t ")
			else:
				if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
					query.append(self.prop("andGroup",'genus'))  
				else:
					query.append(self.prop("and","genus"))
				query.append(" \t ")
				
				query.append(self.buildSimpleCondition(tklist,'genus'))
				if ("," in tklist and ("*" in tklist or "%" in tklist)) or 'null' in tklist:
					query.append(self.prop("orNull","genus"))
					query.append(" )\t ")	
				else:
					query.append(" \t ")	
		return query

		
#-------------------------------						  
	def replaceCaracters(self,word,isKey=False):
		'''
		@param tkliste : the tklist of names that have to be handled
		replace special caracters for the mySQL query
		set a boolean to specify if special caracters are present in the tklist or not(to know if 'LIKE' or '=' has to be used)
		@return Return the tklist with correct format 
		'''
		querymn =  cherrypy.session.get('u_qmg')
		
		if type(word) == ListType:
			word = "".join(word)
#		if "*" in word or "%" in word:
		if "*" in word or "%" in word:
			querymn['withLike'] = True
		else:
			querymn['withLike'] = False	
		word = word.replace("'",self.prop("escape","'"))
		word = word.replace("*",self.prop("escape","*"))
		if isKey:
			word=word.replace("'","")
			word=word.replace('"','')
		cherrypy.session['u_qmg'] = querymn
		return word
	

#-------------------------------						  
	def buildSimpleCondition(self,tklist,field):
		'''
		@param tklist : the tklist of names the query has to match
		@param field : the name of the column
		@return if tklist = ['Malus *','Abies alba'] and field = taxonName, it will append to the current query
		 taxonName LIKE 'Malus *' OR taxonName = 'Abies Alba'																	
		'''
		querymn =  cherrypy.session.get('u_qmg')
		self.loadProperties(straightSearch = querymn.get('straightSearch',False))
		querymn = cherrypy.session.get('u_qmg',{})
		
#		log.info("tklist: %s"%str(tklist))
		if "," in tklist and "(" not in tklist:
			tklist= "(" + tklist
		if "," in tklist and ")" not in tklist:
			tklist += ")"
			
		if type(tklist)!=type([]):
			table = tklist.replace("(","").replace(")","").split(",")
		else:
			table = tklist
#		log.info("tklist: %s"%type(tklist))
		condition=[]
		
		if self.cfgObj.admin.unitsDatabase == "mssql":
			tmp=[]
			umlaut=False
			for elt in table:
				if "[" in elt or "]" in elt:
					elt = elt.replace("[","@[").replace("]","@]")+" ESCAPE '@' "
					if type(tklist)!=type([]):
						tklist=tklist.replace(")","")+", %s )"%elt
					else:
						tklist.append(elt)
					tmp.append(elt)
				else:
					tmp.append(elt)
				if "ä" in elt or "Ä" in elt or "ü" in elt or "Ü" in elt or "ü" in elt or "Ü" in elt:
					umlaut=True
					try:
						elt=elt.replace("ä","&auml;").replace("Ä","&Auml;")
						elt=elt.replace("ü","&uuml;").replace("Ü","&Uuml;")
						elt=elt.replace("ö","&ouml;").replace("Ö","&Ouml;")
						if type(tklist)!=type([]):
							tklist=tklist.replace(")","")+", %s )"%elt
						else:
							tklist.append(elt)
						tmp.append(elt)
					except Exception,e:
						log.info("problem while handling umlaut %s"%e)
						pass
			table = tmp
			if type(tklist)!=type([]) and umlaut:
				if tklist[0] != "(" and tklist[1] != "(":
					tklist="( "+tklist
						
		if 'key'in field.lower():
			isKey=True
		else:
			isKey=False
		self.replaceCaracters(tklist)	  
		if "," in tklist and querymn.get('withLike',False) == True: #list with * at least one time
			condition.append(" \t ")
			if table[0] is not None:
				tmp = self.replaceCaracters(table[0],isKey)
				if querymn.get('withLike',False) == True:
					condition.append(self.opLike) 
				else:
					condition.append(self.opEq)
				condition.append(" \t ")
				if "'" not in tmp and '"' not in tmp and not isKey:
						condition.append(" '")	
						condition.append(tmp)
						condition.append("' ")
				else:
					condition.append(tmp)
			else:
				condition.append('null')
			condition.append(" \t ")
			
			i = 0
			for elt in table:
				if i != 0:
					condition.append(" \t ")
					condition.append(self.opOr)
					condition.append(" \t ")
					condition.append(field)
					condition.append(" \t ")
					if elt is not None:
						tmp = self.replaceCaracters(elt,isKey)
						if querymn.get('withLike',False) == True:
							condition.append(self.opLike) 
						else:
							condition.append(self.opEq)
						condition.append(" \t ")
						if "'" not in tmp and '"' not in tmp and not isKey:
							condition.append(" '")	
							condition.append(tmp)
							condition.append("' ")
						else:
							condition.append(tmp)
					else:
						condition.append('null')
					condition.append(" \t ")
					
				i=1
			
				
		elif querymn.get('withLike',False) == False and "," in tklist:#a tklist without *
			condition.append(" \t ")
			condition.append(self.opIn)
			condition.append(" \t ")
			if tklist is not None:
				tmp = self.replaceCaracters(tklist,isKey)
				if "'" not in tmp and '"' not in tmp and not isKey:
					condition.append(" '")	
					condition.append(tmp)
					condition.append("' ")
				else:
					condition.append(tmp)
			else:
				condition.append('null')
			condition.append(" \t ")
			
		elif querymn.get('withLike',False) == True and "," not in tklist:#one term with *
			condition.append(" \t ")
			condition.append(self.opLike)
			condition.append(" \t ")
			if tklist is not None:
				if table[0] is not None:
					tmp = self.replaceCaracters(table[0],isKey)
#				tmp = self.replaceCaracters(tklist,isKey)
					if "'" not in tmp and '"' not in tmp and not isKey:
						condition.append(" '")	
						condition.append(tmp)
						condition.append("' ")
					else:
						condition.append(tmp)
			else:
				condition.append('null')
			condition.append(" \t ")
			
		elif querymn.get('withLike',False) == False and "," not in tklist:#one term without *
			condition.append(" \t ")
			condition.append(self.opEq)
			condition.append(" \t ")
			if tklist is not None:
				if table[0] is not None:
					tmp = self.replaceCaracters(table[0],isKey)
#				tmp = self.replaceCaracters(tklist,isKey)
					if tmp is not None and "'" not in tmp and '"' not in tmp and not isKey:
						condition.append(" '")	
						condition.append(tmp)
						condition.append("' ")
					else:
						condition.append(tmp)
			else:
				condition.append('null')
		cond= "".join(condition)
		if "," in cond and "(" not in cond:
			cond= "(" + cond
		if "," in cond and ")" not in cond:
			cond += ")"
		return cond.replace("*","%")
 

	

##-----------------------------------------------------------------
##
## query builder : get and handle the results for a query where 2 fields were asked
##
##-----------------------------------------------------------------
	def getDoubleResultSet(self,query):
		'''
		@param query: the query to execute
		Handle the result if the query returned myTuples [(name,key),(name,key),(name,key)...]
		@return Return the tklist of 'unique names',list of 'keys', and hastable 'name:list of keys'
		'''
		#session staff
		query = query
		queryStr = "".join(query)
		queryStr = _carac.decodeCaracters(encoded=queryStr)
				
		result = []
		tklist = []
		dicoCodes = {}
		codeList = []
		#to go faster than if x in tklist
		namesD ={}
		keysD = {}
		
		append = codeList.append 
		append(" ( ")
		self.connection = DBconnection()
		self.connection.setDatabase("units")
		if(self.connection is not None):
			try:
				startQuery = time.time()				
				cursor = self.connection.executeQuery(queryStr)
				duree = time.time() - startQuery
				
				if duree > self.max:
					log2.info("query executed in %f seconds : %s" %(duree,"".join(queryStr)))
				
				resultSet = cursor.fetchall()
				closeConnection(self.connection)

				
			except Exception,e:
				log.info("PB with query : %s \n query: %s" %(e,queryStr))
				resultSet=[]
				closeConnection(self.connection)
			 
			size = len(resultSet)
			append = tklist.append
			append2 = codeList.append  
			
			mem={}
			withmyTuple=False
			for resultat in resultSet:
				#0 : name, 1 : key, 2:nb units
				if resultat is not None and len(resultat) > 1  and resultat[1] is not None:
					tmp0 = resultat[0]
					if tmp0 is None or str(tmp0)=='None':
						tmp0='not specified'
					tmp0=decode_htmlentities(tmp0)
					tmp1 = str(resultat[1]).strip()
					if len(resultat)>2:
						nbU = resultat[2]
						withmyTuple=True
					else:
						nbU = 0
					
					if not mem.has_key(tmp0+'_'+tmp1):
						mem[tmp0+'_'+tmp1] = nbU
						try:
							namesD[tmp0] += nbU 
						except KeyError:
							namesD[tmp0] = nbU					
					try:
						keysD[tmp1] += 1
					except KeyError:
						keysD[tmp1] = 1	  
						append2("\"")
						append2(tmp1)
						append2("\",")
					if(dicoCodes.has_key(tmp0)):
						val = dicoCodes[tmp0] 
						if tmp1 not in val:
							if (type(val) == ListType):
								val.append(tmp1)
								dicoCodes[tmp0] = val
							else:
								tmpVal = []
								tmpVal.append(val)
								tmpVal.append(tmp1)
								dicoCodes[tmp0] = tmpVal
					else:
						dicoCodes[tmp0] = tmp1
			codeList = codeList[0: len(codeList)-1]		  
			codeList.append("\") ")
			if(len(codeList) == 4):
				strCodeList = "\""+codeList[2]+"\""
			else:
				strCodeList = string.join(codeList,"")
			
			if withmyTuple:
				for key in namesD.keys():
					append((key,namesD[key]))
				tklist.sort(lambda x,y:cmp(x[0],y[0]))
			else:
				for key in namesD.keys():
					append(key)
				tklist.sort()

		append = result.append 
		append(tklist)
		append(strCodeList)
		append(dicoCodes)
		queryStr=None#clean for the session file
		query=None#clean for the session file
		resultSet=[]#clean for the session file
		return result
	
##-----------------------------------------------------------------
##
## query builder : get and handle the results for a query where 1 field was asked
##
##-----------------------------------------------------------------
	
	def getResultSet(self,query):
		'''
		@param query : the query to execute
		@return Return the tklist of names
		'''
		queryStr = "".join(query)
		queryStr = _carac.decodeCaracters(encoded=queryStr)
				
		tklist = []
		tmpD = {}
		self.connection = DBconnection()
		self.connection.setDatabase("units")
		if(self.connection is not None):
			try:
				startQuery = time.time()				
				cursor = self.connection.executeQuery(queryStr)
				duree = time.time() - startQuery
				
				if duree > self.max:
					log2.info("query executed in %f seconds : %s" %(duree,queryStr))
				
				resultSet = cursor.fetchall()
				closeConnection(self.connection)
				
			except Exception,e:
				log.info("PB with query : %s \n  queryStr:%s " %(e,queryStr))
				resultSet=[]
				closeConnection(self.connection)
			 
			append = tklist.append
			for resultat in resultSet:
				#0 : name, 1 : key
				if (resultat is not None):
					tmp = resultat[0]
					if tmp is None or str(tmp) == 'None':
						tmp='not specified'
					tmp=decode_htmlentities(tmp)
					try:
						tmpD[tmp] += 1
					except KeyError:
						tmpD[tmp] = 1	
						append(tmp)
			tklist.sort()
		queryStr=None#clean for the session file
		query=None#clean for the session file
		resultSet=[]#clean for the session file
		return tklist  
	
	
	def getBiorecordKeyTaxon(self):
		params = cherrypy.session.get('queryparams',[])
		querymn = cherrypy.session.get('u_qmg',{})
		taxonKeyList = querymn.get('taxonKeyList')
		query=[]
		
		try:
			self.propertiesFile.getProperty("select","taxon")
		except:
			_cfgObj = myPage.getCfgObj()
			propertiesFile = _cfgObj.queriesUnitLevelLocator %_cfgObj.admin.unitsDatabase
			if not(os.access(propertiesFile, os.R_OK|os.F_OK)):
				log.debug("\tNo read access to Properties File ",propertiesFile, "Quitting")
			self.propertiesFile = props(_cfgObj.queriesUnitLevelLocator %_cfgObj.admin.unitsDatabase)
		self.prop =  self.propertiesFile.getProperty
		query.append(self.prop("select","bioRecordKey"))			
		query.append(" \t ")
		query.append(self.prop("from","bioRecord"))
		query.append(" \t ")
		query = self.addJoinTable(select = "bioRecord",params = params, query=query)
		query.append(" ")
		query.append(self.prop("where","bioRecordTaxonKey"))
		query.append(" ")
		
		
		query.append(self.buildSimpleCondition(taxonKeyList,'bioRecordTaxonKey'))
		query.append(" ")  
		query = self.addAnd(params = params,joinTaxon=True,query=query)
		query.append(" ")
		return query


	def getNbUnits(self):
		params = cherrypy.session.get('queryparams',[])
		querymn = cherrypy.session.get('u_qmg',{})
		taxonKeyList = querymn.get('taxonKeyList')
		
		query=[]
		
		try:
			self.propertiesFile.getProperty("select","taxon")
		except:
			_cfgObj = myPage.getCfgObj()
			propertiesFile = _cfgObj.queriesUnitLevelLocator %_cfgObj.admin.unitsDatabase
			if not(os.access(propertiesFile, os.R_OK|os.F_OK)):
				log.debug("\tNo read access to Properties File ",propertiesFile, "Quitting")
			self.propertiesFile = props(_cfgObj.queriesUnitLevelLocator %_cfgObj.admin.unitsDatabase)
		self.prop =  self.propertiesFile.getProperty
	 
		query.append(self.prop("select","countbioRecordKey"))			
		query.append(" \t ")
		query.append(self.prop("from","bioRecord"))
		query.append(" \t ")
		query = self.addJoinTable(select = "bioRecord",params = params, query=query)
		query.append(" ")
		query.append(self.prop("where","bioRecordTaxonKey"))
		query.append(" ")
		querymn = cherrypy.session.get('u_qmg',{})
		tklist = querymn.get('taxonKeyList')
		query.append(self.buildSimpleCondition(tklist,'bioRecordTaxonKey'))
		query.append(" ")  
		query = self.addAnd(params = params,joinTaxon=True,query = query)
		query.append(" ")
		 

		return query
##-----------------------------------------------------------------
##
## query builder : full details from the cache
##
##----------------------------------------------------------------- 
	def buildQueryAllFields(self,biorecords):
		'''
		get all the details for the tklist of biorecordskey
		@param biorecords: the tklist of bioRecordKeys
		@param box : used for the 'order by' option
		@return Return the query
		'''
		
		
		query = []
		try:
			self.propertiesFile.getProperty("select","taxon")
		except:
			_cfgObj = myPage.getCfgObj()
			propertiesFile = _cfgObj.queriesUnitLevelLocator %_cfgObj.admin.unitsDatabase
			if not(os.access(propertiesFile, os.R_OK|os.F_OK)):
				log.debug("\tNo read access to Properties File ",propertiesFile, "Quitting")
			self.propertiesFile = props(_cfgObj.queriesUnitLevelLocator %_cfgObj.admin.unitsDatabase)
		prop =  self.propertiesFile.getProperty

		query.append(prop("select","full"))
		query.append(" ")
		biorec = []
		query.append(prop("where","bioRecordKey"))
		if type(biorecords) == type([]):
			biorec=[str(record) for record in biorecords]
			biorecStr='( '+', '.join(biorec)+' )'
			query.append(" IN ")
		else:
			biorecStr = str(biorecords)
			query.append(" = ")
		query.append(biorecStr)
		query.append(" ")
		query.append(" GROUP BY bioRecordKey ")
		return query  
	
##-----------------------------------------------------------------
##
## query builder : DL full details from the cache
##
##----------------------------------------------------------------- 
	def buildQueryAllFieldsDL(self,biorecords):
		'''
		get all the details for the tklist of biorecordskey
		@param biorecords: the tklist of bioRecordKeys
		@param box : used for the 'order by' option
		@return Return the query
		'''
		
		
		query = []
		try:
			propertiesFile.getProperty("select","dlCache")
		except:
			_cfgObj = myPage.getCfgObj()
			propertiesFile = _cfgObj.straight_queriesUnitLevelLocator %_cfgObj.admin.unitsDatabase
			if not(os.access(propertiesFile, os.R_OK|os.F_OK)):
				log.debug("\tNo read access to Properties File ",propertiesFile, "Quitting")
			propertiesFile = props(_cfgObj.straight_queriesUnitLevelLocator %_cfgObj.admin.unitsDatabase)
		prop =  propertiesFile.getProperty

		query.append(prop("select","dlCache"))
		query.append(" ")
		biorec = []
		query.append(prop("where","bioRecordKey"))
		if type(biorecords) == type([]):
			biorec.append("( ")
			for record in biorecords:
				biorec.append(str(record))
				biorec.append(",")
			biorec = biorec[0:len(biorec)-1]
			biorec.append(")")
			biorecStr = "".join(biorec)
			query.append(" IN ")
		else:
			biorecStr = str(biorecords)
			query.append(" = ")
		query.append(biorecStr)
		query.append(" ")
		query.append(" GROUP BY bioRecordKey ")
		return query 


##-----------------------------------------------------------------
##
## query builder : DL full details from the cache
##
##----------------------------------------------------------------- 
	def buildQueryAllFieldsCDM(self,biorecords):
		'''
		get all the details for the tklist of biorecordskey
		@param biorecords: the tklist of bioRecordKeys
		@param box : used for the 'order by' option
		@return Return the query
		'''
		
		
		query = []
		try:
			propertiesFile.getProperty("select","dlCDM")
		except:
			_cfgObj = myPage.getCfgObj()
			propertiesFile = _cfgObj.straight_queriesUnitLevelLocator %_cfgObj.admin.unitsDatabase
			if not(os.access(propertiesFile, os.R_OK|os.F_OK)):
				log.debug("\tNo read access to Properties File ",propertiesFile, "Quitting")
			propertiesFile = props(_cfgObj.straight_queriesUnitLevelLocator %_cfgObj.admin.unitsDatabase)
		prop =  propertiesFile.getProperty

		query.append(prop("select","dlCDM"))
		query.append(" ")
		biorec = []
		query.append(prop("where","bioRecordKey"))
		if type(biorecords) == ListType:
			biorec.append("( ")
			for record in biorecords:
				biorec.append(str(record))
				biorec.append(",")
			biorec = biorec[0:len(biorec)-1]
			biorec.append(")")
			biorecStr = "".join(biorec)
			query.append(" IN ")
		else:
			biorecStr = str(biorecords)
			query.append(" = ")
		query.append(biorecStr)
		query.append(" ")
		query.append(" GROUP BY bioRecordKey ")
		return query 
		
##-----------------------------------------------------------------
##
## query builder : count the number of recordBasis
##
##-----------------------------------------------------------------
	def countRecordBasis(self):
		'''
		build the query to count the number of recordbasis
		@param biorecords: the tklist of currentBiorecordKeysquery for the current search displays
		@return Return the number of record basis
		'''
		params = cherrypy.session.get('queryparams',[])
		querymn = cherrypy.session.get('u_qmg',{})
		taxonKeyList = querymn.get('taxonKeyList')
		
		query=[]
		try:
			self.propertiesFile.getProperty("select","taxon")
		except:
			_cfgObj = myPage.getCfgObj()
			propertiesFile = _cfgObj.queriesUnitLevelLocator %_cfgObj.admin.unitsDatabase
			if not(os.access(propertiesFile, os.R_OK|os.F_OK)):
				log.debug("\tNo read access to Properties File ",propertiesFile, "Quitting")
			self.propertiesFile = props(_cfgObj.queriesUnitLevelLocator %_cfgObj.admin.unitsDatabase)
		self.prop =  self.propertiesFile.getProperty
		query.append(self.prop("select","countRecordBasis"))			
		query.append(" \t ")
		query.append(self.prop("from","countRecordBasis"))
		query.append(" \t ")
		query = self.addJoinTable(select = "recordBasis",params=params,joinTaxon=False,query=query)
		query.append(" ")
		query.append(self.prop("where","countRecordBasis"))
		query.append(" ")
		query.append(self.buildSimpleCondition(taxonKeyList,'bioRecordTaxonKey'))
		query.append(" ")  
		query = self.addAnd(params = params,joinTaxon=False,query = query)
		query.append(" ")
		query.append(self.prop("groupBy","countRecordBasis"))

		return query
		
##-----------------------------------------------------------------
##
## query builder : count the number of multimedia contents
##
##-----------------------------------------------------------------
	def countMultimedia(self,biorecords):
		'''
		build the query to count the number of records that have multimedia contens
		@param biorecords: the tklist of bioRecordKeys
		@return Return the number of results with multimedia
		'''
		
		
		#log.info("getNbOfUnitsWithMultimedia")
		query = []
		prop =  self.propertiesFile.getProperty
		try:
			self.propertiesFile.getProperty("select","taxon")
		except:
			_cfgObj = myPage.getCfgObj()
			propertiesFile = _cfgObj.queriesUnitLevelLocator %_cfgObj.admin.unitsDatabase
			if not(os.access(propertiesFile, os.R_OK|os.F_OK)):
				log.debug("\tNo read access to Properties File ",propertiesFile, "Quitting")
			self.propertiesFile = props(_cfgObj.queriesUnitLevelLocator %_cfgObj.admin.unitsDatabase)
		prop =  self.propertiesFile.getProperty
	
		query.append(prop("select","nbMulti"))
		query.append(" ")
		biorec=[]
		query.append(prop("where","imagerecordbiorecordkey"))
		if type(biorecords) == ListType:
			biorec=[str(record) for record in biorecords]
			biorecStr='( '+', '.join(biorec)+' )'
			query.append(" IN ")
		else:
			biorecStr = str(biorecords)
			query.append(" = ")
		query.append(biorecStr)
		query.append(" ")
		
		queryStr = "".join(query)
		queryStr = _carac.decodeCaracters(encoded=queryStr)
		
		#log.info("count nbmultimedia: %s" % queryStr)
		
		self.connection = DBconnection()
		self.connection.setDatabase("units")
		if(self.connection is not None):
			try:
				startQuery = time.time()
				
				cursor = self.connection.executeQuery(queryStr)
				duree = time.time() - startQuery
				
				if duree > self.max:
					log2.info("query executed in %f seconds : %s" %(duree,"".join(queryStr)))
				
				resultSet = cursor.fetchall()
				closeConnection(self.connection)
				nb = resultSet[0][0]
			except Exception,e:
				log.debug("PB with query : %s \n query:%s  " %(e,queryStr))
				closeConnection(self.connection)
				nb=0
			return nb  
		queryStr=None#clean for the session file
		query=None#clean for the session file
		resultSet=[]#clean for the session file
		return 0						

	def replaceNotSpecified(self,tklist):
		if tklist is None:
			return None
		notspe=tklist.replace('(','').replace(')','').split(", ")
		tmp=[]
		for elt in notspe:
			try:
				elt= elt.strip().replace('$$virg$$',',')
			except:
				pass
			if elt is not None and  elt.lower() == 'not specified':
				tmp.append('null')
			else:
				enc=encode_htmlentities(elt)
				if enc != elt:
					tmp.append("'%s'"%enc)
				tmp.append("'%s'"%elt)
		if len(tmp)==1:
			if tmp[0]=='null':
				return None
		return ",".join(tmp)
		
		
	def removeAbbreviation(self,tklist):
		tklist=tklist.replace('"','').replace("'","")
		tklist=tklist.replace('(','')
		tklist=tklist.replace(')','').strip()			  
		tklist = tklist.split(", ")
		querymn = cherrypy.session.get('u_qmg',{})
		querymn['hasRecordBasis'] = False
		cherrypy.session['u_qmg'] = querymn
		
		recordBasisDict = self.buildDic(myPage.getCfgObj().recordBasis.recordBasisList)
		recordBasisInv = {}
		tmp=[]
		for key in recordBasisDict.keys():
			recordBasisInv[recordBasisDict[key]] = key	 
		try:
			for full in tklist:
				abbrev=""
				if recordBasisInv.has_key(full):
					abbrev=recordBasisInv[full]
				else:
					if full == "not specified":
						abbrev = None
					else:
						abbrev = full
				if abbrev is not None:
					tmp.append("'%s'"%abbrev)
					#if search for specimen, search for type too
					if abbrev == 's':
						tmp.append("'t'")
				else:
					querymn['hasRecordBasis'] = True
					cherrypy.session['u_qmg'] = querymn
		except Exception,e:
			log.info("pb with recorbasis %s" %e)
		return ",".join(tmp)
	
	def buildDic(self,string):
		dico={}
		tklistmyTuples = string.split(";")
		for myTuple in tklistmyTuples:
			try:
				abbrev = myTuple.split("(")[1].split(",")[0].split(")")[0]
				name = myTuple.split("(")[1].split(",")[1].split("(")[0].split(")")[0]
				dico[abbrev] = name
			except:
				pass
		return dico		
		
	def getSpecimenOfTheDay(self):
		
		query = []
		try:
			self.propertiesFile.getProperty("select","taxon")
		except:
			_cfgObj = myPage.getCfgObj()
			propertiesFile = _cfgObj.queriesUnitLevelLocator %_cfgObj.admin.unitsDatabase
			if not(os.access(propertiesFile, os.R_OK|os.F_OK)):
				log.debug("\tNo read access to Properties File ",propertiesFile, "Quitting")
			self.propertiesFile = props(_cfgObj.queriesUnitLevelLocator %_cfgObj.admin.unitsDatabase)
		prop =  self.propertiesFile.getProperty

		queryStr=prop("select","specimenOfTheDay")
		
		self.connection = DBconnection()
		self.connection.setDatabase("units")
		if(self.connection is not None):
			try:
				startQuery = time.time()				
				cursor = self.connection.executeQuery(queryStr)
				duree = time.time() - startQuery
				
				if duree > self.max:
					log2.info("query executed in %f seconds : %s" %(duree,queryStr))
				
				resultSet = cursor.fetchall()
				closeConnection(self.connection)
				
				
			except Exception,e:
				log.info("PB with query : %s \n  queryStr:%s " %(e,queryStr))
				resultSet=None
				closeConnection(self.connection)
		queryStr=None#clean for the session file
		query=None#clean for the session file
		return resultSet

	def getUnitsDetails(self,bioRecordKey):
		query = []
		try:
			self.propertiesFile.getProperty("select","taxon")
		except:
			_cfgObj = myPage.getCfgObj()
			propertiesFile = _cfgObj.queriesUnitLevelLocator %_cfgObj.admin.unitsDatabase
			if not(os.access(propertiesFile, os.R_OK|os.F_OK)):
				log.debug("\tNo read access to Properties File ",propertiesFile, "Quitting")
			self.propertiesFile = props(_cfgObj.queriesUnitLevelLocator %_cfgObj.admin.unitsDatabase)
		prop =  self.propertiesFile.getProperty
		query.append(prop("select","unitsDetails"))
		query.append(" ")
		query.append(prop("where","bioRecordKey"))
		query.append(" =  %s" % bioRecordKey)
		queryStr = "".join(query)
		self.connection = DBconnection()
		self.connection.setDatabase("units")
		if(self.connection is not None):
			try:
				startQuery = time.time()				
				cursor = self.connection.executeQuery(queryStr)
				duree = time.time() - startQuery
				
				if duree > self.max:
					log2.info("query executed in %f seconds : %s" %(duree,queryStr))
				
				resultSet = cursor.fetchall()
				closeConnection(self.connection)
				
				
			except Exception,e:
				log.info("PB with query : %s \n  queryStr:%s " %(e,queryStr))
				resultSet=None
				closeConnection(self.connection)
		queryStr=None#clean for the session file
		query=None#clean for the session file
		return resultSet		
					
	def getQueryDetailsFromCache(self,unitID,bioKey,collID,instID):
		query=[]
		_cfgObj = myPage.getCfgObj()
		propertiesFile = _cfgObj.straight_queriesUnitLevelLocator %_cfgObj.admin.unitsDatabase
		if not(os.access(propertiesFile, os.R_OK|os.F_OK)):
			log.debug("\tNo read access to Properties File ",propertiesFile, "Quitting")
		self.propertiesFile = props(_cfgObj.straight_queriesUnitLevelLocator %_cfgObj.admin.unitsDatabase)
		prop =  self.propertiesFile.getProperty
		query.append(prop("select","cacheDetails"))
		query.append(" ")
		if bioKey is not None:
			query.append(prop("where","bioKey"))
			query.append(" =  '%s' " % bioKey)
		else:
			query.append(prop("where","unitID"))
			query.append(" =  '%s' " % unitID)
			query.append(prop("and","collID"))
			query.append(" =  '%s' " % collID)
			query.append(prop("and","instID"))
			query.append(" =  '%s' " % instID)
		queryStr = "".join(query)
		self.connection = DBconnection()
		self.connection.setDatabase("units")
		if(self.connection is not None):
			try:
				startQuery = time.time()				
				cursor = self.connection.executeQuery(queryStr)
				duree = time.time() - startQuery
				
				if duree > self.max:
					log2.info("query executed in %f seconds : %s" %(duree,queryStr))
				
				resultSet = cursor.fetchall()
				closeConnection(self.connection)
				
				
			except Exception,e:
				log.info("PB with query : %s \n  queryStr:%s " %(e,queryStr))
				resultSet=None
				closeConnection(self.connection)
		queryStr=None#clean for the session file
		query=None#clean for the session file
		return resultSet		

	def getNamesThesaurus(self,name,thesaurus):
		query = []
#		log.info("getNamesth: %s - %s " %(name,thesaurus))
		self.loadProperties(straightSearch=cherrypy.session.get('straightSearch'))
		query.append(self.prop("thesaurus",thesaurus))
		query.append(" '%s' "%name)
		queryStr=" ".join(query)
		self.connection = DBconnection()
		self.connection.setDatabase("thesaurus%s"%thesaurus)
		if(self.connection is not None):
			try:
				startQuery = time.time()				
				cursor = self.connection.executeQuery(queryStr)
				duree = time.time() - startQuery
				
				if duree > self.max:
					log2.info("query executed in %f seconds : %s" %(duree,queryStr))
				
				resultSet = cursor.fetchall()
				closeConnection(self.connection)
				
				
			except Exception,e:
				log.info("PB with query : %s \n  queryStr:%s " %(e,queryStr))
				resultSet=[]
				closeConnection(self.connection)
		return [p[0] for p in resultSet]
	
	def getUnitsForConcepts(self,zklist,zklistH,wzklist,wzklistH):
		if zklistH == "" or zklistH is None or len(zklistH) ==0:
			wzklist=""
		query = []
		cherrypy.session['message']=''
		query.append(self.propertiesFile.getProperty("select","unitsName"))
		query.append("   ")
		#with higherTaxon to include or to exclude
		#if len(tmpH)>2 or len(wtmpH)>2:
		if zklistH != "":
			query.append(self.propertiesFile.getProperty("from","taxonHigher"))
			query.append("   ")
			query.append(self.propertiesFile.getProperty("where","taxonHigher"))
			#with higher Taxon
			if '(' in zklistH:
				query.append(" IN ")
			else:
				query.append(" = ")
			query.append(zklistH)
			query.append(self.propertiesFile.getProperty("or","taxonHigherGenus"))
			if '(' in zklistH:
				query.append(" IN ")
			else:
				query.append(" = ")
			query.append(zklistH)
			query.append(self.propertiesFile.getProperty("or","taxonHigherFamily"))
			if '(' in zklistH:
				query.append(" IN ")
			else:
				query.append(" = ")
			query.append(zklistH)
		
			#with taxonName	
			if len(zklist)>2:
				query.append(self.propertiesFile.getProperty("or","taxonName"))
				if '(' in zklist:
					query.append(" IN ")
				else:
					query.append(" = ")
				query.append(zklist)
#			query.append(') ')	
			
			#with taxonName to exlude:
			if wzklist!="":
				query.append(" ")
				query.append(self.propertiesFile.getProperty(" and ","taxonName"))
				if '(' in wzklist:
					query.append(" NOT IN ")
				else:
					query.append(" != ")
				query.append(wzklist)
				
		#only with taxonName to include or exclude	
		else:
			if len(zklist)>2 or len(wzklist)>2:	
				query.append(" ")
				query.append(self.propertiesFile.getProperty("from","taxon"))
				query.append(" \t ")
				query.append(self.propertiesFile.getProperty("where","taxon"))
				#taxonName to include
				if len(zklist)>2:
					if '(' in zklist:
						query.append(" IN ")
					else:
						query.append(" = ")
					query.append(zklist)
					#taxonName to exclude, too
					if len(wzklist)>2:
						query.append(self.propertiesFile.getProperty("and","taxonName"))
						if '(' in wzklist:
							query.append(" NOT IN ")
						else:
							query.append(" != ")
						query.append(wzklist)
				else:
					#only taxonName to exclude
					if len(wzklist)>2:
						if '(' in wzklist:
							query.append(" NOT IN ")
						else:
							query.append(" != ")
						query.append(wzklist)

		query.append(" ")
		queryString = " ".join(query)
		queryString.replace("*","%")
		return queryString	
def replaceReservedCaracters(tklist):
#	tmp = tklist.replace("<"," ")
#	tmp = tmp.replace(">"," ")
#	tklist = tmp.replace("="," ")
	return tklist

def closeConnection(connection):
	try:
		connection.close()
	except:
		log.info("already closed")

from htmlentitydefs import name2codepoint as n2cp, codepoint2name as cp2n
import re

def substitute_entity(match):
	ent = match.group(2)
	if match.group(1) == "#":
		return unichr(int(ent))
	else:
		cp = n2cp.get(ent)

		if cp:
			return unichr(cp)
		else:
			return match.group()
	

def decode_htmlentities(string):
	if type(string) != type('i'):
		return string
	entity_re = re.compile("&(#?)(\d{1,5}|\w{1,8});")
	if page.Page().getCfgObj().admin.unitsDatabase == "mssql"  and not isinstance(string,unicode):
		try:
			tmp=unicode(string,'latin-1', errors='replace')
		except:
			tmp=string
	else:
		tmp=string
	try:
		return entity_re.subn(substitute_entity, tmp)[0]
	except Exception,e:
		log.info("ignore %s"%string)
		pass

def encode_htmlentities(string):
	if type(string) !=type('i'):
		return string
	try:
		string=unicode(string)
	except:
		pass
	nb=[]
	tmpl=""
	for c in string:
		o=ord(c)
		nb.append(o)
		tmpl=tmpl+'&#'+str(o)+';'
	for n in nb:
		if n>1000:
			return tmpl
	return string
	