#!/usr/bin/env python
# -*- coding: utf-8 -*-
import cherrypy,os
import logging, logging.config,re,random,sha,time
import libxml2
import xml.sax
import urllib
from xml.sax import parseString,ContentHandler

from pyExcelerator import *

# debugging to file
log = logging.getLogger("div")


class saxABCDHandler(ContentHandler):
	def __init__(self):
		self.tagsList=[]
		self.attribute=None
		self.nbUnits=0
		self.content=""
	
	def startElement(self,name,attr):
		if name == 'UnitID':
			self.nbUnits +=1
		self.currentName =name
			
	def characters(self,content):
		if content is not None:
			tmp=content.replace("\t","").replace("\n","").replace("  "," ")
			while "  " in tmp:
				tmp=tmp.replace("  "," ")
		else:
			tmp = ""
		self.content+=tmp
		
		
	def endElement(self, name):   
		if self.content is not None and  self.content != "" and  self.currentName not in self.tagsList:
			self.tagsList.append(self.currentName)
		self.content=""
		self.currentName=None 
		
class saxDarwinHandler(ContentHandler):
	def __init__(self):
		self.tagsList=[]
		self.attribute=None
		self.nbUnits=0
		self.content=""
	
	def startElement(self,name,attr):
		if "darwin:CatalogNumber" in name:
			self.nbUnits +=1
		self.currentName =name
			
	def characters(self,content):
		if content is not None:
			tmp=content.replace("\t","").replace("\n","").replace("  "," ")
			while "  " in tmp:
				tmp=tmp.replace("  "," ")
		else:
			tmp = ""
		self.content+=tmp
		
		
	def endElement(self, name): 
		if self.content is not None and  self.content != "" and  self.currentName not in self.tagsList:
			self.tagsList.append(self.currentName)  
		self.currentName=None 
		self.content=""

class saxABCDContentHandler(ContentHandler):
	def __init__(self):
		self.attribute=None
		self.dataset={}
		self.unitdata={}
		self.filldataset=False
		self.fillunit=False
		self.tagslist=[]
		self.unitID=""
		self.data={}
		self.content=""
		
	def startElement(self,name,attr):
		if name == 'DataSet':
			self.filldataset=True
		if name == "Unit":
			self.fillunit=True
		self.currentName =name
			
	def characters(self,content):
		if self.fillunit:
			if self.currentName == "UnitID":
				self.unitdata=self.dataset
				self.unitID=content			
			
		if content is not None:
			tmp=content.replace("\t","").replace("\n","").replace("  "," ")
			while "  " in tmp:
				tmp=tmp.replace("  "," ")
		else:
			tmp = ""
		self.content+=tmp
		
		
		
	def endElement(self, name):
		if self.content is not None and  self.content != "" and  self.currentName in self.tagslist:
			if self.filldataset and not self.fillunit:
				tmp=[]
				if self.dataset.has_key(self.currentName):
					tmp = self.dataset[self.currentName]
					if self.content not in tmp:
						tmp.append(self.content)					
				else:
					tmp = [self.content]
				self.dataset[self.currentName]=tmp
				
			elif self.fillunit:
				tmp=[]
				if self.unitdata.has_key(self.currentName):
					tmp = self.unitdata[self.currentName]
					if self.content not in tmp:
						tmp.append(self.content)
					
				else:
					tmp = [self.content]
				self.unitdata[self.currentName]=tmp
		if name == "DataSet":
			self.filldataset=False 
		if name == "Unit":
			self.fillunit=False
			self.data[self.unitID] = self.unitdata  
			self.unitdata={}
		self.currentName=None 
		self.content=""
		
	def setTagsList(self,tagslist):
		self.tagslist = tagslist
				
class saxDarwinContentHandler(ContentHandler):
	def __init__(self):
		ContentHandler.__init__(self)
		self.attribute=None
		self.dataset={}
		self.unitdata={}
		self.filldataset=False
#		self.fillunit=False
		self.tagslist=[]
		self.unitID=""
		self.data={}
		self.content=""
		
	def startElement(self,name,attr):
#		if name == 'DataSet':
#			self.filldataset=True
		self.currentName =name
		
			
	def characters(self,content):
		if "darwin:CatalogNumber" in str(self.currentName):
#		   self.unitdata=self.dataset
			self.unitID=content  
			
		if content is not None:
			tmp=content.replace("\t","").replace("\n","").replace("  "," ")
			while "  " in tmp:
				tmp=tmp.replace("  "," ")
		else:
			tmp = ""
		
		self.content+=tmp
		
		
		
		
	def endElement(self, name):
		if self.content is not None and  self.content != "" and  self.currentName in self.tagslist:
			tmp=[]
			if self.unitdata.has_key(self.currentName):
				tmp = self.unitdata[self.currentName]
				if self.content not in tmp:
					tmp.append(self.content)
				
			else:
				tmp = [self.content]
			self.unitdata[self.currentName]=tmp
		
#		if name == "DataSet":
#			self.filldataset=False 
		if name == "record" :
			self.data[self.unitID] = self.unitdata  
			self.unitdata={}
		self.currentName=None 
		self.content=""
		
	def setTagsList(self,tagslist):
		self.tagslist = tagslist
				
class Spreadsheet:
	#dictionnary of refine actions
	
	def __init__(self):
		self.ws=None
		self.format="ABCD"
		self.unitsdata={}
		self.liste=[]
		self.nbUnits=0
		
	def convert(self,xmlToConvert,format): 
		#log.info("convert %s %s - XML to XLS "%(xmlToConvert,format))
		if "abcd" in format:
			self.format="ABCD"
		else:
			self.format="Darwin"
			
		#self.setTags("http://localhost/portal/static/files/%s" % xmlToConvert)
		self.setTags("http://localhost/edit/static/files/%s" % xmlToConvert)
		w = Workbook()
		self.ws = w.add_sheet('test')
		self.setHeaders()
		self.fillBook()
		
		chaine = ("spreadsheet_%s"%xmlToConvert);
		date = time.strftime('_%d_%m_%y',time.localtime())
		fileName = chaine+date+".xls"
		if ".xml" in fileName:
			fileName=fileName.replace(".xml","")
		
		filesDir = cherrypy.config.get("uploads")
		os.chdir(filesDir) 
		w.save(fileName)
		return str(fileName)
	
	def setTags(self,xmlToConvert):
#		log.info("settags: %s" %xmlToConvert)
		f = urllib.urlopen(xmlToConvert)
#		f = urllib.urlopen(xmlToConvert)
		self.response = f.read()
		try:
			if self.format == "ABCD":
				handler = saxABCDHandler()
			else:
				handler = saxDarwinHandler()
			parseString(self.response, handler)
			self.liste= handler.tagsList
			self.nbUnits=handler.nbUnits
		except Exception,e:
			log.error('FAILED to read xml preferences %s' %e)
		
	
		
	def setHeaders(self):
#		log.info("set headers")
		i=0
		while i < len(self.liste):
			title = str(self.liste[i])
			#log.info("title %s"% type(title))
			if self.format=="ABCD":
				rs = re.findall('[A-Z][^A-Z]*',title)
			else:
				rs = re.findall('[:][^:]*',title)
				tmp = ""
				for word in rs:
					tmp += " "+word
				rs = re.findall('[A-Z][^A-Z]*',tmp)
			fs = ""
			for word in rs:
				fs += " "+word
			self.ws.write(0, i, fs.replace(":",""))
			i+=1
			
	def fillBook(self):
#		log.info("fillbook")
		try:
			if self.format == "ABCD":
				handler = saxABCDContentHandler()
			else:
				handler = saxDarwinContentHandler()
				
			handler.setTagsList(self.liste)

			parseString(self.response, handler)
			self.unitsdata = handler.data
#			self.dataset=handler.dataset
		except Exception,e:
			log.error('FAILED to read xml preferences in fillBook %s' %e)
			
		i=1 #ligne
		j=0 # colonne
		units = self.unitsdata.keys()
		for unit in units:
			data=self.unitsdata[unit]
			while j<len(self.liste):
				try:
					self.ws.write(i,j,",".join(data[self.liste[j]]))			
				except:
					pass
				j+=1
			j=0;
			i+=1
			
