#!/usr/bin/env python
# -*- coding: utf-8 -*-
############################################################################################################
#
#   IMPORTS
#
#===========================================================================================================
import cherrypy
import libxml2
import xml.sax
from xml.sax import parseString,ContentHandler, make_parser
import urllib,string,re,sys,os,logging, logging.config,time
from types import *
import xml.dom.minidom

import timeoutsocket
import biocase.configuration



# debugging to file
log = logging.getLogger("div")


############################################################################################################
#
#   CLASSES
#
#===========================================================================================================
class ServiceError(Exception):
	def __init__(self, *args):
		Exception.__init__(self, *args)

class HttpError(ServiceError):
	def __init__(self, url):
		ServiceError.__init__(self, url)
		self.url=url
		
class MalformedResponseError(ServiceError):
	def __init__(self, response):
		ServiceError.__init__(self, response)
		self.response=response
		
class XMLError(ServiceError):
	def __init__(self, xml):
		ServiceError.__init__(self, xml)
		self.xml = xml
		
class NoResultError(ServiceError):
	def __init__(self, res):
		ServiceError.__init__(self, res)
		self.res = res
 
class relationHandler(ContentHandler):
	def __init__(self):
		self.list=[]
		self.tag='name'
		self.currentTag=None
		self.attribute=None
	
	def startElement(self,name,attr):
		self.currentName=name
		if attr.has_key(self.attribute):
			self.list.append(attr.get(self.attribute))
			self.currentName =None
			
	def characters(self,content):
		if self.currentName == self.tag:
			if content not in self.list:
				self.list.append(content.replace('"',"'"))
		
	def endElement(self, name):   
		self.currentName=None 
		
class statusHandler(ContentHandler):
	def __init__(self,references=[]):
		self.obj=None
		self.tolog=False
		self.content=""
		self.conceptName=""
		self.status="N.A"
		self.reference="N.A"
		self.nameId=''
		self.referenceid=''
		self.referencesAuthorized=references

		
		
	def startElement(self,name,attr):
		if name == 'reference':
			self.tolog=True
		if name == 'name':
			self.nameId=attr.get('id')
		if name =="reference":
			self.referenceid=attr.get('id')
	
	def characters(self,content):
		self.content+=content
	
	def endElement(self, name):
		
		if name == 'name':
			self.conceptName=self.content.replace('\n','').replace('\t','')
		if name == 'status':
			self.status=self.content.replace('\n','').replace('\t','')
		if name == 'reference':
			self.reference = self.content.replace('\n','').replace('\t','')
		
		if self.tolog:
			try:
				conceptName = ConceptName()
			except:
				from Concept import ConceptName
				conceptName = ConceptName()
			conceptName.name = self.conceptName
			conceptName.status = self.status
			conceptName.reference = self.reference
			conceptName.nameId = self.nameId
			conceptName.referenceid = self.referenceid
			conceptName.parent = self.obj
			if str(self.referenceid) in self.referencesAuthorized or self.referencesAuthorized == [] or  self.referencesAuthorized==['']:
				self.obj.conceptsNames.append(conceptName)	
#			else:
#				log.info("rejette %s %s"%(conceptName.name,self.referenceid))
			self.tolog=False
		self.content=""

class simpleHandler(ContentHandler):
	def __init__(self,references=[]):
		self.content=""
		self.reference="N.A"
		self.name=''
		self.isName=False
		self.referenceid=''
		self.referencesAuthorized=references
		self.names=[]

		
	def startElement(self,name,attr):
		if name == 'name':
			self.isName=True
		if name =="reference":
			self.referenceid=attr.get('id')
	
	def characters(self,content):
		self.content+=content
		
	def endElement(self, name):
		if self.isName:
			self.isName=False
			self.name=self.content.replace('\n','').replace('\t','')
			self.content=""
		if name == 'reference':
			self.reference = self.content.replace('\n','').replace('\t','')
			if str(self.referenceid) in self.referencesAuthorized or self.referencesAuthorized == [] or  self.referencesAuthorized==['']:
				self.names.append(self.name)
			self.content=""	
		
class relatedHierarchyConceptHandler(ContentHandler):
	global relation
	def __init__(self):
		self.obj = None
		self.name = ""
		self.content=""
		self.reference=""
		self.relation=""
		self.relationType=''
		self.status=''
		self.name2=''
		self.reference2=''
		self.relation2=''
		self.hierarchy={}
		self.tri=[]
		self.nameId=""
		self.nameId2=''
		self.dataSchemaConcept=''
		self.start=False
		self.cle1=''
		self.cle2=''
		try:
			cherrypy.session.get('relationlists').keys()
			self.relationlistsdict = cherrypy.session.get('relationlists')
		except:
			from thesaurus.ThesaurusLoader import TransformXmlForRelations
			tmp = TransformXmlForRelations().loadRelations()
			self.relationlistsdict = cherrypy.session.get('relationlists')
		
		
	def startElement(self,name,attr):		
#		if name == "relation":
#			self.relation = attr.get('name')
#			self.relations.append(self.relation)
		if name=="relationSet":
			self.start=True

		if name == "name" and self.start:
			self.relationType=attr.get('relationtype')
			cid=str(attr.get('id'))
			self.nameId=cid
			self.name2=attr.get('name')
			
			cid2=str(attr.get('id2'))
			self.nameId2=cid2
			
			self.cle1=self.nameId
			self.cle2=self.nameId2
			
			
		if name =="concept":
			stat=attr.get('dataSchemaConcept','paf')
			if stat != 'dataSchemaConcept':
				self.status=stat
			self.dataSchemaConcept=stat
			
			
	def characters(self,content):
		if content is not None:
			self.content +=content
		
	def endElement(self,name):
		self.content=self.content.replace("\n","").replace("\t","")
		
		if name == 'reference':
			self.reference = self.content
			self.reference=cherrypy.session.get('referenceDic').get(self.reference,self.reference)
			self.cle1+='|'+self.reference
		if name == 'reference_2':
			self.reference2 = self.content
			self.reference2=cherrypy.session.get('referenceDic').get(self.reference2,self.reference2)
			self.cle2+='|'+self.reference2
		
		if name=='name':
			self.name = self.content
			
		if name =='concept' and self.start: 
			tmp=self.hierarchy.get(self.cle1,[])
			relTemp=self.relationType.split('_inverse')[0]
			if '_inverse' in self.relationType:
				for rList in self.relationlistsdict.values():
					for r in rList:
						if r.relationName == relTemp:
							self.relation=r.relationNameInverseDisplay
							self.relation2=r.relationNameDisplay
							self.relationType=r.relationType
							break
			else:				
				for rList in self.relationlistsdict.values():
					for r in rList:
						if r.relationName == relTemp:
							self.relation=r.relationNameDisplay
							self.relation2=r.relationNameInverseDisplay
							self.relationType=r.relationType
							break		
			if (self.relation,self.cle2) not in tmp:	
				tmp.append((self.relation,self.cle2))		
			self.hierarchy[self.cle1]=tmp	
			
			try:
				concept = Concept()
			except:
				from Concept import Concept
				concept = Concept()
			concept.name = self.name
			#concept.reference = self.reference
			concept.relation=self.relation
			concept.relationType=self.relationType
			concept.parent=self.obj
			#concept.status=self.status
			concept.nameId=self.nameId
			concept.dataSchemaConcept=self.dataSchemaConcept
			concept.reference=self.reference
			self.obj.relatedConcepts.append(concept)
			
			concept2=Concept()
			concept2.name=self.name2
			concept2.relation=self.relation2
			concept2.relationType=self.relationType
			concept2.parent=self.obj
			concept2.nameId=self.nameId2
			concept2.dataSchemaConcept=self.dataSchemaConcept
			concept2.reference=self.reference2
			self.obj.relatedConcepts.append(concept2)
			
			self.logName=False
			self.logReference=False
			self.status=''
#		if name=='relation':
#			try:
#				self.relations.pop()
#				self.relation=self.relations[len(self.relations)-1]
#			except:
#				self.relation='error occured'
		self.content=""
		
		
	
class relatedConceptsHandler(ContentHandler):
	def __init__(self):
		self.obj = None
		self.name = ""
		self.content=""
		self.reference=""
		self.reference2=""
		self.relation=""
		self.relationSet=False
		self.relationType=''
		self.status=''
		self.accepted=''
		self.dataSchemaConcept=''
		
	def startElement(self,name,attr):			
		if name == "relation":
			self.relation = attr.get('name')
		
		if name == "relationSet":	
			self.relationSet=True
			
		if name == "name" and self.relationSet:
			self.relationType=attr.get('relationtype')
			self.accepted=attr.get('name')
		
		if name =="concept":
			stat=attr.get('dataSchemaConcept','paf')
			if stat != 'dataSchemaConcept':
				self.status=stat
			self.dataSchemaConcept=stat
	
	def characters(self,content):
		self.content +=content.replace("\n","").replace("\t","")
		
	def endElement(self,name):
		if name=='status':
			self.status=self.content.replace('\n','').replace('\t','')
		if name=='reference_2':
			self.reference2=self.content.replace('\n','').replace('\t','')
			
		if name=='reference':
			self.reference=self.content.replace('\n','').replace('\t','')
			
		if name=='name':
			self.name = self.content
		
		if name=='relationSet':
			self.relationSet=False
		
		if name == "concept" and self.relationSet:
			try:
				concept = Concept()
			except:
				from Concept import Concept
				concept = Concept()
			concept.name = self.name
			concept.reference = self.reference
			concept.relation=self.relation
			concept.relationType=self.relationType
			concept.parent=self.obj
			concept.status=self.status
			concept.acceptedname=self.accepted
			concept.reference2=self.reference2
			concept.dataSchemaConcept=self.dataSchemaConcept
			self.obj.relatedConcepts.append(concept)
			self.status=''
		self.content=""
			
		
	
class saxHandler(ContentHandler):
	def __init__(self):
		ContentHandler.__init__(self)
		self.currentName=None
		self.addName=False
		self.newName=False
		self.savedName=""
		self.content=""
		self.dico={}
		self.reference=False
		self.referenceName=""

		
	def startElement(self,name,attr):
		#log.info("saxHandler %s" %name)
		if name == 'reference':
			self.addName=True
			self.reference=True
		if name == "name":
			self.newName=True
		self.currentName =name
			
	def characters(self, content):
		self.content+=content
		
		
	def endElement(self, name):
		if self.reference:
			self.referenceName=self.content
		
		if self.newName:
			if self.currentName == "name":
				self.savedName=self.content		
		
		if self.addName:
			key = "%s [ref: %s]" %(self.content,self.referenceName)
			if self.dico.has_key(key):
				temp=self.dico.get(key)
			else:
				temp=[]
			key2 =  "%s [ref: %s]" %(self.savedName,self.referenceName)
			if key2 not in temp:
				temp.append(key2)
			self.dico[key]=temp
		if name == "concept":
			self.addName=False 
		if name == "reference":
			self.addName=False
			self.reference=False
		self.currentName=None 
		self.content=""

class conceptHandler(ContentHandler):
	def __init__(self):
		ContentHandler.__init__(self)
		self.key=""
		self.concept=False
		self.conceptData=False
		self.relationset=False
		self.relation=False
		self.inName=False
		self.dico={}
		self.content=""
		self.relationName=""
		self.relationadded=False
		self.conceptRef=""
		
	def startElement(self,name,attr):
		if name == 'concept':
			if attr.get('dataSchemaConcept',"toto") == "toto":
				self.concept=True
			else:
				self.conceptData=True
			
		if name == 'relationSet':
			self.relationset=True
				
		if name == 'relation':
			self.relation=True
			self.relationName=attr.get('name')
			#log.info("attribut: %s" %self.relationName)
		
		if name == "name":
			self.inName=True
			
	def characters(self, content):
		self.content+=content
		
		
	def endElement(self, name):
		#construit la clé

		if self.concept and not self.relationset and self.inName and not self.conceptData:
			self.conceptRef=self.content
			self.key=self.conceptRef
		if self.relationset and self.relation and self.concept and not self.relationadded:
			self.key=self.relationName+" ["+self.conceptRef.strip()+"]"
			self.relationadded=True
			
		#si est entrain de lire un synonyme ou autre
		if self.inName and self.relation and self.conceptData and self.relationset:
			if self.dico.has_key(self.key):
				tmp = self.dico.get(self.key)
			else:
				tmp=[]
			if self.content not in tmp:
				tmp.append(self.content)
			self.dico[self.key]=tmp
			

		if name == "concept":
			self.conceptData=False
		if name == "relationSet":
			self.relationset=False
			self.key=""
			self.conceptRef=""
			self.concept=False
		if name == "relation":
			self.relation=False
			self.relationadded=False
		if name == "name":
			self.inName=False
		
		self.content=""

# ----------------------------------------------------------------------------
		
class ThesaurusServiceQuery:
	
	
	def __init__(self,thesaurus='taxon'):
		self.response=None
		self.relationList = None
		self.thesaurus=thesaurus
		self.thesaurusURL=None
		self.thesaurusProperties={}#store the time out in the dictionnary
		self.getThesaurusServiceURL()
		
	def getThesaurusServiceURL(self):
		#log.info("thesaurus: %s" %self.thesaurus);
		try:
			myPage = page.Page()
		except:
			import page
			myPage = page.Page()
		self.thesaurusServiceURL=[]
		try:
			if myPage.getCfgObj().admin.forTaxonomist:
				document = xml.dom.minidom.parse(urllib.urlopen('%s'%myPage.getCfgObj().checklist.thesauriURL))
			else:
				document = xml.dom.minidom.parse(urllib.urlopen('%s'%myPage.getCfgObj().checklist.thesauriSimpleURL))	 
			for item in document.getElementsByTagName('thesaurus'):
				if item.getAttribute('type') == self.thesaurus:
					try:
						address=item.getElementsByTagName('url')[0].firstChild.data
						try:
							timeout= int(item.getElementsByTagName('timeout')[0].firstChild.data)
						except:
							timout=60
						
						self.thesaurusServiceURL.append(address)
						self.thesaurusProperties[address]=timeout
					except:
						pass
		except:
			document=None  
		#log.info(self.thesaurusServiceURL)	   
		
	def getConceptsByTerm(self,selection,index):
		self.thesaurusURL = self.thesaurusServiceURL[index]

		return self.sendQuery(method="getConceptsByTerm",request=selection,thesaurus=self.thesaurus)

	def getNamesLike(self,selection,index):
		self.thesaurusURL = self.thesaurusServiceURL[index]
		return self.sendQuery(method="getNamesLike",request=selection,thesaurus=self.thesaurus,returnDoc=True)
	
	def getAllRelatedConcepts(self,nameId,referenceid,status,index,relation):
		tmp = [nameId,referenceid,status]
		conceptNameParams="toto".join(tmp)
		#log.info("getAllRelatedConcepts %s" %conceptNameParams)
		self.thesaurusURL = self.thesaurusServiceURL[index]
			
		option = {"relation":relation}
		
	
		return self.sendQuery(method='getAllRelatedConcepts',request=conceptNameParams,option=option,thesaurus=self.thesaurus)
	
	def sendQuery(self,method=None,request=None,option=None,thesaurus='Fauna Europaea',returnDoc=False):	
		timeout = self.thesaurusProperties[self.thesaurusURL]		
		timeoutsocket.setDefaultSocketTimeout(timeout)
		recursive=cherrypy.session.get('recursive',False)
		
		if recursive and (thesaurus=='Fauna Europaea' or thesaurus=='Fauna Europaea wa'):
			if method == 'getAllRelatedConcepts':
				params = {'method': method, 'conceptKey':request, 'thesaurus':thesaurus, 'recursive':recursive}		
			else:
				params = {'method': method, 'term':request, 'thesaurus':thesaurus, 'recursive':recursive}		
		else:
			if method == 'getAllRelatedConcepts':
				params = {'method': method,'conceptKey':request,'thesaurus':thesaurus}
			else:
				params = {'method': method,'term':request,'thesaurus':thesaurus}
		params = urllib.urlencode(params)
		
		if option is not None and type(option) == type({}):
			for key in option.keys():
				if key == 'relation':
					params+='&%s=%s' %(key,'toto'.join(option[key]))
				else:  
					for value in option[key]:
						params += '&%s=%s' %(key,value)  
		
		#log.info("query to the thesaurus:  %s" %params )
		try:
			f = urllib.urlopen(self.thesaurusURL,params)
			self.response = f.read()
		except Exception,e :
			log.info("HTTP ERROR: Thesaurs service URL COULD NOT BE OPENED %s" % e)
			raise HttpError(self.thesaurusURL)
		
		
		# parse the xml into xmllib2 DOM:
		try:
			self.doc = libxml2.parseDoc(self.response)
		except Exception,e:
			self.doc = None
			log.info("ERROR: NO WELL FORMED XML Thesaurus RESPONSE FOUND %s" %e)
			raise MalformedResponseError(self.response)	  
		
		if returnDoc:
			return self.response
		return self
		 

	def getContentForTerm(self,myConcept,references):
#		log.info("getContentForTerm %s" %references)
		handler = statusHandler(references=references)
		handler.obj = myConcept
		parseString(self.response, handler)
		
	def getContentForRelatedConcepts(self,conceptName):
		if cherrypy.session.get('recursive',False):
			handler=relatedHierarchyConceptHandler()
		else:
			handler=relatedConceptsHandler()
		handler.obj=conceptName
		
		parseString(self.response,handler)
		
		if cherrypy.session.get('recursive',False):
			cherrypy.session['hierarchy']=handler.hierarchy
	
	# ------------------------------------------------------------------------------------
	def getContent(self, asDoc=True,tag='name',attr=None):
		#log.info("getContent %s" %self.response)
		dico={}
		if tag == 'relation':
			try:
				handler = relationHandler()
				handler.tag  = tag
				handler.attribute = attr
				parseString(self.response, handler)
			except Exception,e:
				log.error('FAILED to read xml preferences %s' %e)
			dico= handler.list
		elif tag == 'name':				
			try:
				handler = saxHandler()
				#log.info("reponse de screugneu: %s" %self.response)
				parseString(self.response, handler)
				dico = handler.dico
			except Exception,e:
				log.error('FAILED to read xml preferences %s' %e)
		else:
			try:
				handler = conceptHandler()
				parseString(self.response, handler)
				dico = handler.dico
			except Exception,e:
				log.error('FAILED to read xml preferences %s' %e)
			#log.info("DICO :%s" %dico)
		return dico
	
	#---------------------------------
	def getNames(self,resXML,references):
		handler=simpleHandler()
		parseString(resXML, handler)
		return handler.names
		