
#!/usr/bin/env python
# -*- coding: utf-8 -*-
import cherrypy
import kid
import re
import logging, logging.config, os, sys, string,time


# --------------------------------------------------------------------------------
# use logging
log = logging.getLogger("div")


import biocase.configuration
import biocase.divers
import biocase.divers.datasource

from requestHandler.dbConnection import DBconnection
from requestHandler.props import *

cfgObj = biocase.configuration.getConfigObj()
menuObjDict = biocase.divers.datasource.getMenuDico(cfgObj)


# --------------------------------------------------------------------------------


class Page(object):
	'''Base class for all html webpages.'''
	# data accessible to all webapp pages:
	global cfgObj
	global menuObjDict
	 
	
	
	def __init__(self):
		self.title= cfgObj.server.websiteTitle
		self.nbResultsPerPage=0
		self.nbResults=0

	def redirect(self, url):
		if url.startswith('/') and cfgObj.server.webroot not in url:
			url = self.getMountPoint(url)
		raise cherrypy.HTTPRedirect(url)

	
	def getMountPoint(self, path='/'):
		return cherrypy.tree.url(path)

	
	def getNbUnits(self):
		propertiesFile = props(cfgObj.queriesUnitLevelLocator %cfgObj.admin.unitsDatabase)
		query = propertiesFile.getProperty("select","countUnits")
		connection = DBconnection()
		connection.setDatabase("units")
		if(connection is not None):
			try:
				startQuery = time.time()
				cursor = connection.executeQuery(query)
				resultSet = cursor.fetchall()
				try:
					connection.close()
				except:
					pass
			except Exception,e:
				log.info("PB with query : %s \n query:%s " %(e,query))
				resultSet=[]
				try:
					connection.close()
				except:
					pass
		return resultSet[0][0]

	

	def render(self, filePath, fileName, title=None, trail=True, body=None, nextHistory=None, action='',  **kwargs):
		cfgObj = self.getCfgObj()
		# self.baseurl
		self.baseurl = self.getMountPoint('/')
		
		#get the cookie properties
		self.getPreferences()
		
		self.nbUnits = cherrypy.session.get('nbUnitsDB',None)
		if self.nbUnits is None:
			self.nbUnits = str(self.getNbUnits()).strip()
			l = len(self.nbUnits)
			d = l / 3
			for i in range(1,d+1):
				self.nbUnits = self.nbUnits[:l-3*i] + "." + self.nbUnits[l-3*i:]
			if self.nbUnits[0]==".":
				self.nbUnits=self.nbUnits[1:]
			cherrypy.session['nbUnitsDB']=self.nbUnits
			
		 #add the properties to the kwargs
		kwargs['lang'] = cherrypy.session.get('lang')
		kwargs['group'] = cherrypy.session.get('group')
		kwargs['unitSearch'] = cherrypy.session.get('unitSearch')
		kwargs['tableHeaders'] = cherrypy.session.get('tableHeaders')
		kwargs['nbResultPerPage'] = cherrypy.session.get('nbResultsPerPage')
		kwargs['message']=cherrypy.session.get('message','')
		if cfgObj.admin.metadata == "False":
			kwargs['metadataDB']=False
		else:
			kwargs['metadataDB']=True 
		if cfgObj.admin.forEDIT == "False":
			kwargs['forEDIT']=False
		else:
			kwargs['forEDIT']=True
		
		try:
			cherrypy.session['nbResults']=kwargs['size']
		except:
			pass
		
		kwargs['thesaurusActivated']=cherrypy.session.get('thesaurusActivated',False)
		#build file name with path + lang + name
		if '.kid' not in fileName:
			fileName+='.kid'
		if '_' in fileName:
			file=filePath+cherrypy.session.get('lang')+fileName
		else:
			file=filePath+fileName
			
			
		# update file path to absolute path. mod_python has problems otherwise
		tmpl_file = os.path.join(cfgObj.webappLocator, file)
		tmpl_name = file[:-4]

		# try to find titles
		if title is None:
			if hasattr(self,'title'):title = self.title
			else: title = self.__class__.__name__
		if cfgObj.server.websiteTitle not in title:
			title = cfgObj.server.websiteTitle + " " + title
		try:
			if self.nbUnits not in title and ("index" in title or "simple search" in title or "advanced search" in title):
				title += " - %s units" %self.nbUnits
		except:
			pass
		
		
		
		#for naviguation with reload
		prevHistory = None
		nextHistory=None
		comingFrom = cherrypy.request.headerMap.items()
		#try:
			#path = cherrypy.request.path[len(self.baseurl):]
			#prevHistory = self.getPrevHistory(path,comingFrom)
		#except:
			#prevHistory = None
		#if nextHistory is not None:
			#nextHistory= self.baseurl+ nextHistory	
		
		noMem=False
		try:
			direct=kwargs['directLink']
			if str(direct) == "True":
				direct=True
				direct=True
				prevHistory=None
				nextHistory=None
				noMem=True 
			else:
				direct=False			
		except:
			direct=False
		
		# calculate navigator trail list
		navlist=[]
		

		if trail:
			base=""
			path = cherrypy.request.path[len(self.baseurl):]
			if noMem:
				memory='#'
			else:
				memory=self.getMemory(path,comingFrom)

			for p in path.split('/'):
				if len(p) > 1 and p.lower() not in (cfgObj.server.webroot,'index','default','static'):
					maj = string.upper(p[0])
					pp = p[1:len(p)]
					pp = maj + pp
					ppp = pp.replace("_"," ")
					if ppp.lower() in ("units", "search","browse","preview", "results", "details", "confirmation", "validation", "alert", "annotation"):
						if ppp not in ('Results'):
							navlist.append((ppp,base+p))
						else:
							navlist.append((ppp,"javascript:window.location.href='"+memory+"'"))
						base+=p+"/"

			# add query string if there was any to thelast entry

			if len(navlist) > 0 and len(cherrypy.request.queryString) > 0:
				lastEntry = navlist.pop()
				navlist.append( (lastEntry[0],"%s?%s"%(lastEntry[1],cherrypy.request.queryString)) )
		
		cherrypy.session['directLink'] = direct
		# send http headers
		cherrypy.response.headerMap['Content-Type'] = "text/html; charset=utf-8"
		
  
		# render template
		#log.debug("Rendering: name=%s, title=%s, body=%s, trail=%s, navlist=%s, **kwargs=%s" %(tmpl_name, title, body, str(trail), str(navlist), str(kwargs) ) )
		
		tmpl = kid.Template(name=tmpl_name, baseurl=self.baseurl, title=title, body=body, trail=trail, prevHistory=prevHistory, nextHistory=nextHistory, navlist=navlist, action=action, **kwargs)
		if 'Map' in title:
			return tmpl.serialize(output='html')
		else:
			return tmpl.serialize(output='xhtml')



	def getPrevHistory(self,path,comingFrom):
		prevHistory=None
		if 'units' in path:
			if "preview" in path:
				for x,y in comingFrom:
					if x == "Referer":
						comingFrom = y
				if 'map' in comingFrom:
					prevHistory = self.baseurl+"search/map"
				elif 'simple' in comingFrom:
					prevHistory = self.baseurl+"search/units/simpleSearch"
				else:
					prevHistory = self.baseurl+"search/units/advancedSearch"
			elif "available" in path:
				prevHistory = self.baseurl+"search/units/preview"
			elif "detailed" in path:
				prevHistory = self.baseurl+"search/units/results"	 
				for x,y in comingFrom:
					if x == "Referer":
						if '/index' in y:
							prevHistory=None
						break
			elif "annotated" in path:
				prevHistory = self.baseurl+"search/units/details"	 
				for x,y in comingFrom:
					if x == "Referer":
						if '/index' in y:
							prevHistory=None
						break
		#if 'metadata' in path:
			#if "preview" in path:
				#for x,y in 'comingFrom':
					#if x == "Referer":
						#comingFrom = y
				#if 'simple' in comingFrom:
					#prevHistory = self.baseurl+"search/metadata/simpleSearch"
				#else:
					#if cherrypy.session.has_key('M_Browse'):
						#prevHistory = self.baseurl+"search/metadata/browsing"
					#else:
						#prevHistory = self.baseurl+"search/metadata/browsingSearch"
			#elif "browse" in path:
				#prevHistory = self.baseurl+"search/metadata/browsingSearch"	 
				#for x,y in comingFrom:
					#if x == "Referer":
						#if '/index' in y:
							#prevHistory=None
						#break
			#elif "detailed" in path:
				#prevHistory = self.baseurl+"search/metadata/preview"	 
				#for x,y in comingFrom:
					#if x == "Referer":
						#if '/index' in y:
							#prevHistory=None
						#break
		return prevHistory

	def getMemory(self,path,comingFrom):
		memory=""
		if 'units' in path:
			if "available" in path:
				memory = self.baseurl+"search/units/preview"
			else:
				memory = self.baseurl+"search/units/"
			if "detailed" in path or "confirmation" in path:
				memory = self.baseurl+"search/units/results"
				for x,y in comingFrom:
					if x == "Referer":
						if '/index' in y:
							memory=""
						break
		#else:
			#if "detailed" in path :
				#memory = self.baseurl+"search/metadata/preview"
				#for x,y in comingFrom:
					#if x == "Referer":
						#if '/index' in y:
							#memory=""
						#break
		return memory
					
	def getMenuObj(self, name):
		if menuObjDict.has_key(name):
			return menuObjDict[name]
		else:
			return None
		
	def getCfgObj(self):
		return cfgObj

	def savePreferences(self):
		'''
		set the cookie
		if attributes are not specified, default value are : language english and group by name
		called by the submit button from the Preferences index page
		'''
		tableHeaders = cherrypy.session.get('tableHeaders',['name','country','collectionId'])
		cookieValue = cherrypy.session.get('lang','de') +"_"+ cherrypy.session.get('group','taxonBox') +"_"+ cherrypy.session.get('unitSearch','unitSimple') +"_~"+ tableHeaders[0]
		
		for elt in tableHeaders[1:]:
			cookieValue = cookieValue+"-"+elt
		cookieValue = cookieValue+"_"+str(cherrypy.session.get('nbResultPerPage',20))
		
		if cherrypy.session.get('GBIFagreement',False):
			cookieValue+="_GBIFagreement"
		gmt_expiration_time = time.gmtime(time.time() +  (6000 * 6000))
		expireTime = time.strftime("%a, %d-%b-%Y %H:%M:%S GMT", gmt_expiration_time)
		try:
			#delete the old cookie
			cherrypy.response.simple_cookie['%sPREFERENCES'%self.getCfgObj().server.cookieName]['expires'] = 0
			cherrypy.response.simple_cookie['%sPREFERENCES'%self.getCfgObj().server.cookieName] = cookieValue
		except:
			cherrypy.response.simple_cookie['%sPREFERENCES'%self.getCfgObj().server.cookieName] = cookieValue
		cherrypy.response.simple_cookie['%sPREFERENCES'%self.getCfgObj().server.cookieName]['path'] = '/'
		cherrypy.response.simple_cookie['%sPREFERENCES'%self.getCfgObj().server.cookieName]['version'] = 1
		cherrypy.response.simple_cookie['%sPREFERENCES'%self.getCfgObj().server.cookieName]['expires'] = expireTime

		cherrypy.response.headerMap["Cache-Control"] = "no-store, no-cache, must-revalidate, post-check=0, pre-check=0"
		cherrypy.response.headerMap["Pragma"] = "no-cache"
	
	def getPreferences(self,optionHeader=None):
		'''
		get the cookie values
		'''
		try:
			cookie = cherrypy.request.simple_cookie['%sPREFERENCES'%self.getCfgObj().server.cookieName].value
		except :
			cookie= "en_taxonBox_unitSimple_~taxonName-country-collectionId_20"
			cherrypy.response.simple_cookie['%sPREFERENCES'%self.getCfgObj().server.cookieName] = cookie
			cherrypy.response.simple_cookie['%sPREFERENCES'%self.getCfgObj().server.cookieName]['path'] = '/'
			gmt_expiration_time = time.gmtime(time.time() +  (6000 * 6000))
			expireTime = time.strftime("%a, %d-%b-%Y %H:%M:%S GMT", gmt_expiration_time)
			cherrypy.response.simple_cookie['%sPREFERENCES'%self.getCfgObj().server.cookieName]['expires'] = expireTime
			try:
				pref_lang_header = cherrypy.request.headers["Accept-Language"]
				regex = re.compile(u"\w+(-\w+)?(;q=[\d\.]+)?$")
				pref_lang = [e.split(";",1)[0] for e in pref_lang_header.split(",") if regex.match(e)][0]
				if pref_lang not in ["fr","de","en","cn","lt","swe","fin","es","dk","is","nor"]:
					pref_lang="en"
			except Exception,e:
				pref_lang = "en"
		#for Internet Explorer	
		if "~" not in cookie:
			cookie= "en_taxonBox_unitSimple_~taxonName-country-collectionId_20" 
			try:
				pref_lang_header = cherrypy.request.headers["Accept-Language"]
				regex = re.compile(u"\w+(-\w+)?(;q=[\d\.]+)?$")
				pref_lang = [e.split(";",1)[0] for e in pref_lang_header.split(",") if regex.match(e)][0]
				if pref_lang not in ["fr","de","en","cn","lt","swe","fin","es","dk","is","nor"]:
					pref_lang="en"
			except Exception,e:
				pref_lang = "en"
		cookieParts = cookie.split("_")
		try:
			cherrypy.session['lang']=pref_lang
		except:
			cherrypy.session['lang'] = cookieParts[0]
		group = cookieParts[1]
		if 'Box' not in group:
			group='taxonBox' # hack for the old cookies version
		cherrypy.session['group'] = group
		cherrypy.session['unitSearch'] = cookieParts[2]
		cherrypy.session['nbResultsPerPage'] = cookieParts[4]
		try:
			a=int(cookieParts[4])
			if a > 500:
				cherrypy.session['nbResultsPerPage'] =500	
		except:
			cherrypy.session['nbResultsPerPage'] =20
			
		if "GBIFagreement" in cookie:
			cherrypy.session['GBIFagreement']=True
		else:
			cherrypy.session['GBIFagreement']=False
		#_20_GBIFagreement
		tableHeaders = []
		tmp = cookie.split("~")[1]
		headerList = tmp.split("-")
		if len(headerList) > 1:
			#more than one tableHeader in the cookie
			for elt in headerList:
				if "_" in elt:
					tableHeaders.append(elt.split('_')[0])
				else:
					tableHeaders.append(elt)
		else:
			#just the field name in the tableHeaders
			tableHeaders=[tmp]
		cherrypy.session['tableHeaders'] = tableHeaders
		cherrypy.session['showColumns'] = tableHeaders
		if optionHeader is not None:
			tableHeaders.append(optionHeader)
			cherrypy.session['tableHeaders'] = tableHeaders
			cherrypy.session['showColumns'] = tableHeaders
			self.savePreferences()		  
	
	
	def getGroup(self):
		self.getPreferences()
		return cherrypy.session.get('group')
	
	def getTableHeaders(self,optionHeader=None):
		self.getPreferences(optionHeader=optionHeader)
		
	
	def getLang(self):
		self.getPreferences()
		return cherrypy.session.get('lang')
		
	def getUnitsSearch(self):
		self.getPreferences()
		return cherrypy.session.get('unitSearch')
	
	

	def getNbResultPerPage(self):
		self.getPreferences()
		return cherrypy.session.get('nbResultsPerPage')
	
		
	def setNumberOfResults(self,nb):
		cherrypy.session['nbOfResult']=nb
		
	def checkGBIFAgreementCookie(self):
		self.getPreferences()
		return cherrypy.session.get('GBIFagreement',False)
	
	def acceptGBIF(self):
		self.getPreferences()
		
		tableHeaders = cherrypy.session.get('tableHeaders',['name','country','collectionId'])
		cookieValue = cherrypy.session.get('lang','en') +"_"+ cherrypy.session.get('group','taxonBox') +"_"+ cherrypy.session.get('unitSearch','unitSimple') +"_~"+ tableHeaders[0]
		
		for elt in tableHeaders[1:]:
			cookieValue = cookieValue+"-"+elt
		cookieValue = cookieValue+"_"+str(cherrypy.session.get('nbResultPerPage',20))
		
		if cherrypy.session.get('GBIFagreement',False):
			cookieValue+="_GBIFagreement"
		
		cookieValue=cookieValue+"_"+'GBIFagreement'
		gmt_expiration_time = time.gmtime(time.time() +  (6000 * 6000))
		expireTime = time.strftime("%a, %d-%b-%Y %H:%M:%S GMT", gmt_expiration_time)
		try:
			#delete the old cookie
			cherrypy.response.simple_cookie['%sPREFERENCES'%self.getCfgObj().server.cookieName]['expires'] = 0
			cherrypy.response.simple_cookie['%sPREFERENCES'%self.getCfgObj().server.cookieName] = cookieValue
		except:
			cherrypy.response.simple_cookie['%sPREFERENCES'%self.getCfgObj().server.cookieName] = cookieValue
		cherrypy.response.simple_cookie['%sPREFERENCES'%self.getCfgObj().server.cookieName]['path'] = '/'
		cherrypy.response.simple_cookie['%sPREFERENCES'%self.getCfgObj().server.cookieName]['version'] = 1
		cherrypy.response.simple_cookie['%sPREFERENCES'%self.getCfgObj().server.cookieName]['expires'] = expireTime

		cherrypy.response.headerMap["Cache-Control"] = "no-store, no-cache, must-revalidate, post-check=0, pre-check=0"
		cherrypy.response.headerMap["Pragma"] = "no-cache"
		
