#!/usr/bin/env python
# -*- coding: utf-8 -*-
import cherrypy
import kid
import logging, logging.config, os, sys

from requestHandler.dbConnection import DBconnection
import page

# use logging
log = logging.getLogger("query")

class Registry(page.Page):
	
	def __init__(self):
		self.filePath = 'registry/'
		self.fileName = '_registry_index.kid'
		self.title = "Registry"
		self.body = "registryPage" 
		   
	@cherrypy.expose
	def index(self):
		self.filePath = 'registry/'
		self.fileName = '_registry_index.kid'
#		self.file = 'registry/registry_index.kid'
		return self.render(filePath=self.filePath,fileName=self.fileName, title=self.title,body=self.body)


class Host(page.Page):
	
	def __init__(self):
		self.filePath = 'registry/'
		self.fileName = '_host.kid'
		self.title = "Registry information : hosting institutions"
		self.body = "registryPage" 
		self.hostTable = None
		   
	@cherrypy.expose
	def index(self):
		self.filePath = 'registry/'
		self.fileName = '_host.kid'
#		self.file = 'registry/host.kid'
		if cherrypy.session.get('hostTable',None) is None:
			self.getHosts()
		return self.render(filePath=self.filePath,fileName=self.fileName, title=self.title,body=self.body,hosts=cherrypy.session.get('hostTable'))
	
	def getHosts(self):
		self.connection = DBconnection()
		self.connection.setDatabase("registry")
		query ='''SELECT  provider.name as name, uddi_business_key as uddi, town as town, country as country, home_url as url, protocol_fk as protocol,  
		count(datasource_id) as nbOf_datasources,  sum (number_of_records) as nbOf_records
		FROM registry.provider
		JOIN registry.datasource ON provider_id=provider_fk 
 		WHERE datasource.active_flag
		GROUP BY provider.name, uddi_business_key, town, country, home_url, protocol_fk
		ORDER BY name'''
		if(self.connection is not None):
			try:
				cursor = self.connection.executeQuery(query)
				resultSet = cursor.fetchall() 
				closeConnection(self.connection)
				
			except Exception,e:
				log.info("PB with query : %s \n query: %s " %(e,query))
				resultSet=[]
				closeConnection(self.connection)
			self.hostTable=resultSet
			cherrypy.session['hostTable']=self.hostTable
			
			
def closeConnection(connection):
	try:
		connection.close()
	except:
		log.info("already closed")
	
class Datasources(page.Page):
	
	def __init__(self):
		self.filePath = 'registry/'
		self.fileName = '_institution.kid'
		self.title = "Registry information : datasources"
		self.body = "registryPage"	
		self.institutionTable = None
	 
	@cherrypy.expose
	def index(self):
		self.filePath = 'registry/'
		self.fileName = '_institution.kid'
		if cherrypy.session.get('institutionTable',None) is None:
			self.getDatasources()
		return self.render(filePath=self.filePath,fileName=self.fileName, title=self.title,body=self.body,dataSource = cherrypy.session.get('institutionTable'))

	def getDatasources(self):
		self.connection = DBconnection()
		self.connection.setDatabase("registry")
		query =''' SELECT  datasource.name as name, description, uddi_business_key as uddi,  provider_fk as provider, number_of_records as nbOf_records
		FROM registry.provider
		JOIN registry.datasource ON provider_id=provider_fk 
 		WHERE datasource.active_flag 
		ORDER BY name'''
		if(self.connection is not None):
			try:
				cursor = self.connection.executeQuery(query)
				resultSet = cursor.fetchall() 
				closeConnection(self.connection)
				
			except Exception,e:
				log.info("PB with query : %s \n query: %s " %(e,query))
				resultSet=[]
				closeConnection(self.connection)
			self.institutionTable=resultSet
			cherrypy.session['institutionTable']=self.institutionTable

class Collections(page.Page):
	
	def __init__(self):
		self.filePath = 'registry/'
		self.fileName = '_collection.kid'
		self.title = "Registry information : collections"
		self.body = "registryPage"	
		self.collectionTable = None
		
		
	@cherrypy.expose
	def index(self):
		self.filePath = 'registry/'
		self.fileName = '_collection.kid'
		if cherrypy.session.get('collectionTable',None) is None:
			self.getCollection()		
		return self.render(filePath=self.filePath,fileName=self.fileName, title=self.title,body=self.body,collections = cherrypy.session.get('collectionTable'))

	def getCollection(self):
		self.connection = DBconnection()
		self.connection.setDatabase("registry")
		query ='''SELECT c.name, c.home_url, c.contact_data_name, c.description, c.datasource_fk, d.name 
		FROM registry.collection c, registry.datasource d 
		WHERE c.datasource_fk=d.datasource_id
		AND c.active_flag
		ORDER BY d.name,c.name
		''' 
		if(self.connection is not None):
			try:
				cursor = self.connection.executeQuery(query)
				resultSet = cursor.fetchall() 
				closeConnection(self.connection)
				
			except Exception,e:
				log.info("PB with query : %s \n query: %s " %(e,query))
				resultSet=[]
				closeConnection(self.connection)
			self.collectionTable=resultSet
			keys = {}
			for line in resultSet:
				k=line[5]
				tmp=keys.get(k,[])
				tmp.append([line[0],line[1],line[2],line[3]])
				keys[k]=tmp				
			
			self.collectionTable = keys
			cherrypy.session['collectionTable']=self.collectionTable