<?xml version="1.0" encoding="UTF-8"?>
<!-- 	**************************************************************************
		**	Templates library                	**
		**                        **
		**	Common templates used in several stylesheets for processing ABCD	**
		**	documents.                    **
		**                        **
		**	Author: Javier de la Torre             		**
		**************************************************************************
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:fn="http://www.w3.org/2004/07/xpath-functions" xmlns:xdt="http://www.w3.org/2004/07/xpath-datatypes" xmlns:n1="http://www.tdwg.org/schemas/abcd/1.2" exclude-result-prefixes="xsl xs fn xdt n1">
	<!--
	** replaceCharsInString template
	** 
	** Description: function that takes three parameters:
	** StringIn: String where the replacement should take effect
	** charsIn: The characters that will replace charsOut
	** charsOut: The characters that should be replaced by charsIn
	************************************************************
-->
    <!-- <xsl:variable ></xsl:variable>  -->
    <!--  <xsl:param name="PrefferdLanguage">cn</xsl:param>  -->
    <!--  <xsl:param name="AlternatePrefferdLanguage">en</xsl:param>  -->
    <xsl:param name="PrefferdLanguage">DE</xsl:param>
    <xsl:param name="AlternatePrefferdLanguage">EN</xsl:param>
    
	<xsl:template name="replaceCharsInString">
		<xsl:param name="stringIn"/>
		<xsl:param name="charsIn"/>
		<xsl:param name="charsOut"/>
		<xsl:choose>
    <xsl:when test="contains($stringIn,$charsIn)">
    	<xsl:value-of select="concat(substring-before($stringIn,$charsIn),$charsOut)"/>
    	<xsl:call-template name="replaceCharsInString">
    		<xsl:with-param name="stringIn" select="substring-after($stringIn,$charsIn)"/>
    		<xsl:with-param name="charsIn" select="$charsIn"/>
    		<xsl:with-param name="charsOut" select="$charsOut"/>
    	</xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
    	<xsl:value-of select="$stringIn"/>
    </xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- _________________________________________________________________________ -->
	<!--
		* preferedTaxonName template
		* 
		* This template selects from an ABCD 1.2 unit the prefered
		* identification name.
		* It takes care if there are multiple identifications, if the prefered flag is set,
		* if it is being used 1 or True to indeicate the flag, etc.
		****************************************
	  template for selecting the accepted name -->
	<xsl:template name="preferedTaxonName">
		<span class="style1">
		<xsl:text> 
        	</xsl:text>
			<xsl:for-each select="n1:Identifications/n1:Identification">
			<xsl:text> 
        	</xsl:text>
				<!--General rule for names -->
				<!-- Avoid execution if there are no Identifications-->
				<!--Differenciate if there is only one identification o more -->
				<xsl:choose>
					<xsl:when test="count(../n1:Identification) = 1">
						<!--Only one identification, is shown as non prefered -->
						<span class="preferedbig">
							<xsl:value-of select="n1:TaxonIdentified/n1:NameAuthorYearString"/>
						</span>
						<xsl:text> 
        				</xsl:text>
					</xsl:when>
					<!-- more than 1 identifications -->
					<xsl:otherwise>
						<!--Check if there is a preferedflag -->
						<xsl:choose>
							<xsl:when test="not(@PreferredIdentificationFlag)">
								<!-- Identification without prefered flag -->
								<xsl:value-of select="n1:TaxonIdentified/n1:NameAuthorYearString"/> |
								<xsl:text> 
        						</xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:choose>
									<xsl:when test="@PreferredIdentificationFlag= '1' or @PreferredIdentificationFlag='true'">
										<!--Multiple identifications, prefered one -->
										<span class="preferedbig">
											<xsl:value-of select="n1:TaxonIdentified/n1:NameAuthorYearString"/>
										</span>
										<xsl:text> 
        								</xsl:text>
									</xsl:when>
									<xsl:otherwise>
										<!--Multiple identifications, non prefered one -->
									</xsl:otherwise>
								</xsl:choose>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
			<xsl:text> 
        	</xsl:text>
		</span>
	</xsl:template>
	<!-- _____________________________________________________________________________________  -->
	<xsl:template name="RightsTable">
		<xsl:if test="string(.)">
    <table width="96%"  border="0" cellspacing="0" cellpadding="0">
    	<xsl:if test="string(n1:TermsOfUse)">
    	<tr>
    		<td>
    <xsl:text>
    </xsl:text>
    		
        <!-- <strong>使用条件: </strong><xsl:value-of select="n1:TermsOfUse"/> -->
        
    		<xsl:choose>
	       		<xsl:when
	           test="count(n1:TermsOfUse) = 1">
	           <strong>使用条件: </strong><xsl:value-of select="n1:TermsOfUse"/>
		   		        </xsl:when>
		   		        <xsl:otherwise>
		   		         <xsl:variable name="termsOfUse"></xsl:variable>
		   		        	<xsl:for-each select="n1:TermsOfUse">
		   		        	  <xsl:value-of select="@language" ></xsl:value-of>
		   		        	  <xsl:if test="@language = $PrefferdLanguage">
		   		        	  		<xsl:variable name="termsOfUse" seclect="../n1:TermsOfUse">
		   		        	  		</xsl:variable>
		   		        	  </xsl:if>
    <xsl:text>
    </xsl:text>
		   		        	</xsl:for-each>
		   		        	<strong>使用条件: </strong>
		   		        	<xsl:value-of select="$termsOfUse"/>
	               </xsl:otherwise>
	   		        </xsl:choose>
    		 <xsl:text>
   			</xsl:text>
        		</td>
    	</tr>
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	<xsl:if test="string(n1:SpecificRestrictions)">
    	<tr>
    		<td>
    <xsl:text>
    </xsl:text>
        <strong>特定限制: </strong><xsl:value-of select="n1:SpecificRestrictions"/>
    		 <xsl:text>
   			</xsl:text>
        		</td>
    	</tr>
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	<!-- Cmplex type LegalOwner -->
    	<xsl:if test="string(n1:LegalOwner)">
    	<tr>
    		<td>
    <xsl:text>
    </xsl:text>
        <!-- 
        <strong>法定拥有者: </strong><xsl:value-of select="n1:LegalOwner/n1:Organisation/n1:OrganisationName"/>
        <span class="label">法定拥有者: </span>
         -->
         <span class="label">法定拥有者: </span><br/>
        <xsl:for-each select="n1:LegalOwner"> 
        	<xsl:call-template name="ContactData" />
        </xsl:for-each>
    		 <xsl:text>
   			</xsl:text>
        		</td>
    	</tr>
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	<!--  -->
    	<xsl:if test="string(n1:CopyrightDeclaration)">
    	<tr>
    		<td>
    <xsl:text>
    </xsl:text>
        <strong>版权公告: </strong><xsl:value-of select="n1:CopyrightDeclaration"/>
    		 <xsl:text>
   			</xsl:text>
        		</td>
    	</tr>
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	<xsl:if test="string(n1:IPRDeclaration)">
    	<tr>
    		<td>
    <xsl:text>
    </xsl:text>
        <strong>知识产权_Declaration: </strong><xsl:value-of select="n1:IPRDeclaration"/>
    		 <xsl:text>
   			</xsl:text>
        		</td>
    	</tr>
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	<xsl:if test="string(n1:RightsURL)">
    	<tr>
    		<td>
    <xsl:text>
    </xsl:text>
        <strong>权利网址: </strong><xsl:value-of select="n1:RightsURL"/>
    		 <xsl:text>
   			</xsl:text>
        		</td>
    	</tr>
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    </table>
		</xsl:if>
    <xsl:text>
    </xsl:text>
	</xsl:template>
		
	<!-- _____________________________________________________________________________________  -->
	<xsl:template name="ContactData">
	<table width="96%"  border="0" cellspacing="0" cellpadding="0">
	<tr>
	  <xsl:if test="n1:Organisation/n1:OrganisationName">
	  	<th>联络组织名称</th>
	  </xsl:if>
    <xsl:text>
    </xsl:text>
	  <xsl:if test="n1:Organisation/n1:OrganisationCodes">
	  	<th>联络组织代码</th>
	  </xsl:if>
    <xsl:text>
    </xsl:text>
	  <xsl:if test="n1:Person/n1:PersonName">
	     <th>联络人名</th>
	  </xsl:if>
    <xsl:text>
    </xsl:text>
	  <xsl:if test="n1:Role">
     	<th>联络人职务</th>
     	</xsl:if>
    <xsl:text>
    </xsl:text>
     <xsl:if test="n1:Addresses">
         <th>联络人地址</th>
     </xsl:if>
    <xsl:text>
    </xsl:text>
     <xsl:if test="n1:TelephoneNumbers">
        <th>联络人电话</th>
     </xsl:if>
    <xsl:text>
    </xsl:text>
     <xsl:if test="n1:EmailAddresses">
        <th>联络人电子邮件</th>
     </xsl:if>
    <xsl:text>
    </xsl:text>
     <xsl:if test="n1:URLs">
     	<th>联络网址</th>
     </xsl:if>
    <xsl:text>
    </xsl:text>
	</tr>
	<tr>
	   <!--   Organisation 0/1 cmpl-type [OrganisationType]
          		OrganisationName 0/1 xtnd-W3C [xs:string]
               		Language
          OrganisationCodes 0/1
               OrganisationCode 0/∞ xtnd-W3C [xs:string]
                    PreferredFlag
             prefferd       
    -->
	   <xsl:if test="n1:Organisation">
	   	<xsl:if test="n1:Organisation/n1:OrganisationName">
	   	<td>
    <xsl:text>
    </xsl:text>
	   		<xsl:value-of
	       select="n1:Organisation/n1:OrganisationName">
	   		</xsl:value-of>
	   	 <xsl:text>
   			</xsl:text>
        		</td>
	   	</xsl:if>
    <xsl:text>
    </xsl:text>
	   	<xsl:if test="n1:Organisation/n1:OrganisationCodes">
	   	<td>
    <xsl:text>
    </xsl:text>
	   		<xsl:choose>
	       <xsl:when
	       	test="count(n1:Organisation/n1:OrganisationCodes/n1:OrganisationCode) = 1">
	       	<!--  <span class="preferedbig">
	       		联络组织代码 :
	       	</span> -->
	       	<xsl:value-of
	       		select="n1:Organisation/n1:OrganisationCodes/n1:OrganisationCode">
	       	</xsl:value-of>
	       </xsl:when>
	       <xsl:otherwise>
	       	<xsl:for-each
	       		select="n1:Organisation/n1:OrganisationCodes/n1:OrganisationCode">
	       		<!--Check if there is a preferedflag -->
	       		<xsl:choose>
	           <xsl:when
	           	test="not(@PreferredFlag) or @PreferredFlag= '0'">
	           	<!--  <span class="label">
	           		联络组织代码: 
	           	</span>
	           	 -->
	           	<xsl:value-of select="."></xsl:value-of>
	           </xsl:when>
	           <xsl:otherwise>
	           	<xsl:choose>
	           		<xsl:when
	               test="@PreferredFlag= '1' or @PreferredFlag='true'">
	               <!--Multiple identifications, prefered one -->
	               <!--  <span class="preferedbig">
	               	联络组织代码: 
	               </span>  -->
	               <xsl:value-of select="."></xsl:value-of>
	           		</xsl:when>
	           	</xsl:choose>
	           </xsl:otherwise>
	       		</xsl:choose>
	       		<br/>
	       	</xsl:for-each>
	       </xsl:otherwise>
	   		</xsl:choose>
	   		 <xsl:text>
   			</xsl:text>
        		</td>
	   	</xsl:if>
    <xsl:text>
    </xsl:text>
	   	
	   </xsl:if>
    <xsl:text>
    </xsl:text>
	   <!--
                    
     Person 0/1 cmpl-type [PersonNameType]
          PersonName 1/1 W3C-type [string]
    
          SortPersonName 0/1 W3C-type [string]
      -->     
     <xsl:if test="n1:Person">
     <td>
    <xsl:text>
    </xsl:text>
     	<xsl:if test="n1:Person/n1:PersonName">
     		<xsl:value-of select="n1:Person/n1:PersonName"></xsl:value-of>
     		<br/>
     	</xsl:if>
    <xsl:text>
    </xsl:text>
     	<xsl:if test="n1:Person/n1:SortPersonName">
     		<xsl:value-of select="n1:Person/n1:SortPersonName"></xsl:value-of>
     		<br/>
     	</xsl:if>
    <xsl:text>
    </xsl:text>
     	 <xsl:text>
   			</xsl:text>
        		</td>
     </xsl:if>
    <xsl:text>
    </xsl:text>  
       
     <!--
          
     Role 0/1 xtnd-W3C [xs:string]
          Language
     -->
     <xsl:if test="n1:Role">
     <td>
    <xsl:text>
    </xsl:text>
     	<!-- <span class="label">联络人职务: </span> -->
     		<xsl:value-of select="n1:Role"></xsl:value-of>
     		<br/>
      <xsl:text>
   			</xsl:text>
        		</td>
     </xsl:if>
    <xsl:text>
    </xsl:text>
     <!--     
     Addresses 0/1
          Address 0/∞ xtnd-W3C [xs:string]
               PreferredFlag
     -->
     <xsl:if test="n1:Addresses">
     <td>
    <xsl:text>
    </xsl:text>
     		<xsl:choose>
	       <xsl:when
	       	test="count(n1:Addresses/n1:Address) = 1">
	       	<!--  <span class="preferedbig">
	       		联络人地址 :
	       	</span>
	       	 -->
	       	<xsl:value-of
	       		select="n1:Addresses/n1:Address">
	       	</xsl:value-of>
	       </xsl:when>
	       <xsl:otherwise>
	       	<xsl:for-each
	       		select="n1:Addresses/n1:Address">
	       		<!--Check if there is a preferedflag -->
	       		<xsl:choose>
	           <xsl:when
	           	test="not(@PreferredFlag) or @PreferredFlag= '0'">
	           	<!-- <span class="label">
	           		联络人地址: 
	           	</span>
	           	 -->
	           	<xsl:value-of select="."></xsl:value-of>
	           </xsl:when>
	           <xsl:otherwise>
	           	<xsl:choose>
	           		<xsl:when
	               test="@PreferredFlag= '1' or @PreferredFlag='true'">
	               <!--Multiple identifications, prefered one -->
	               <!-- <span class="preferedbig">
	               	联络人地址: 
	               </span>
	                -->
	               <xsl:value-of select="."></xsl:value-of>
	           		</xsl:when>
	           	</xsl:choose>
	           </xsl:otherwise>
	       		</xsl:choose>
	       		<br/>
	       	</xsl:for-each>
	       </xsl:otherwise>
	   		</xsl:choose>
	   	 <xsl:text>
   			</xsl:text>
        		</td>
     </xsl:if>
    <xsl:text>
    </xsl:text>
     <!--
     TelephoneNumbers 0/1
          TelephoneNumber 0/∞ cmpl-type [TelephoneNumberType]
               PreferredFlag
               Number 1/1 W3C-type [string]
               UsageNotes 0/1 W3C-type [string]
     -->
     <xsl:if test="n1:TelephoneNumbers">
     <td>
    <xsl:text>
    </xsl:text>
     		<xsl:choose>
	       <xsl:when
	       	test="count(n1:TelephoneNumbers/n1:TelephoneNumber) = 1">
	       	<!-- <span class="preferedbig">
	           联络人电话 :
	       	 -->
	       	<xsl:value-of
	       		select="n1:TelephoneNumbers/n1:TelephoneNumber/n1:Number">
	       	</xsl:value-of>
	       	<xsl:if test="string(n1:TelephoneNumbers/n1:TelephoneNumber/n1:UsageNotes)">
	       	(<xsl:value-of select="n1:TelephoneNumbers/n1:TelephoneNumber/n1:UsageNotes"></xsl:value-of>)
	       	</xsl:if>
    <xsl:text>
    </xsl:text>
	       	
	       </xsl:when>
	       <xsl:otherwise>
	       	<xsl:for-each
	       		select="n1:TelephoneNumbers/n1:TelephoneNumber">
	       		<!--Check if there is a preferedflag -->
	       		<xsl:choose>
	           <xsl:when
	           	test="not(@PreferredFlag) or @PreferredFlag= '0'">
	           	<!-- <span class="label">
	           		LB_Contact_联络人电话: 
	           	</span> -->
	           	<xsl:value-of select="."></xsl:value-of>
	           </xsl:when>
	           <xsl:otherwise>
	           	<xsl:choose>
	           		<xsl:when
	               test="@PreferredFlag= '1' or @PreferredFlag='true'">
	               <!--Multiple identifications, prefered one -->
	               <!-- <span class="preferedbig">
	               	LB_Contact_联络人电话: 
	               </span> -->
	               <xsl:value-of select="."></xsl:value-of>
	           		</xsl:when>
	           	</xsl:choose>
	           </xsl:otherwise>
	       		</xsl:choose>
	       		<br/>
	       	</xsl:for-each>
	       </xsl:otherwise>
	   		</xsl:choose>
	   	 <xsl:text>
   			</xsl:text>
        		</td>
     </xsl:if>
    <xsl:text>
    </xsl:text>    
               
     <!--          
     EmailAddresses 0/1
          EmailAddress 0/∞ xtnd-W3C [xs:token]
               PreferredFlag
     -->          
     <xsl:if test="n1:EmailAddresses">
     <td>
    <xsl:text>
    </xsl:text>
     <xsl:choose>
	       <xsl:when
	       	test="count(n1:EmailAddresses/n1:EmailAddress) = 1">
	       	<!-- <span class="preferedbig">
	       		联络人电子邮件 :
	       	</span> -->
	       	<a href="mailto:{n1:EmailAddresses/n1:EmailAddress}">EMAIL</a>
	       </xsl:when>
	       <xsl:otherwise>
	       	<xsl:for-each
	       		select="n1:EmailAddresses/n1:EmailAddress">
	       		<!--Check if there is a preferedflag -->
	       		<xsl:choose>
	           <xsl:when
	           	test="not(@PreferredFlag) or @PreferredFlag= '0'">
	           	<!-- <span class="label">
	           		联络人电子邮件: 
	           	</span> -->
	           	<a href="mailto:{../n1:EmailAddress}">EMAIL</a>
	           </xsl:when>
	           <xsl:otherwise>
	           	<xsl:choose>
	           		<xsl:when
	               test="@PreferredFlag= '1' or @PreferredFlag='true'">
	               <!--Multiple identifications, prefered one -->
	               <!-- <span class="preferedbig">
	               	联络人电子邮件: 
	               </span> -->
	               <a href="mailto:{../n1:EmailAddress}">EMAIL</a>
	           		</xsl:when>
	           	</xsl:choose>
	           </xsl:otherwise>
	       		</xsl:choose>
	       		<br/>
	       	</xsl:for-each>
	       </xsl:otherwise>
	   		</xsl:choose>
       <xsl:text>
   			</xsl:text>
        		</td>
     </xsl:if>
    <xsl:text>
    </xsl:text>
     <!--           
     URLs 0/1
          URL 0/∞ xtnd-W3C [xs:anyURI]
               PreferredFlag
      -->
      <xsl:if test="n1:URLs">
      <td>
    <xsl:text>
    </xsl:text>
      <xsl:choose>
	       <xsl:when
	       	test="count(n1:URLs/n1:URL) = 1">
	       	<!-- <span class="preferedbig">
	       		联络网址 :
	       	</span> -->
	       	<a href="{n1:URLs/n1:URL}" target ="_blank">URL</a>
	       </xsl:when>
	       <xsl:otherwise>
	       	<xsl:for-each
	       		select="n1:URLs/n1:URL">
	       		<!--Check if there is a preferedflag -->
	       		<xsl:choose>
	           <xsl:when
	           	test="not(@PreferredFlag) or @PreferredFlag= '0'">
	           	<!-- <span class="label">
	           		联络网址: 
	           	</span> -->
	           	<a href="{../n1:URL}" target ="_blank">URL</a>
	           </xsl:when>
	           <xsl:otherwise>
	           	<xsl:choose>
	           		<xsl:when
	               test="@PreferredFlag= '1' or @PreferredFlag='true'">
	               <!--Multiple identifications, prefered one -->
	               <!-- <span class="preferedbig">
	               	联络网址: 
	               </span> -->
	               <a href="{../n1:URL}" target ="_blank">URL</a>
	           		</xsl:when>
	           	</xsl:choose>
	           </xsl:otherwise>
	       		</xsl:choose>
	       		<br/>
	       	</xsl:for-each>
	       </xsl:otherwise>
	   		</xsl:choose>
	   	 <xsl:text>
   			</xsl:text>
        		</td>
     </xsl:if>
    <xsl:text>
    </xsl:text>
     </tr>         
    </table>
	</xsl:template>
</xsl:stylesheet>