<?xml version="1.0" encoding="UTF-8"?>
<!-- 	**************************************************************************
		**	Unit details library for ABCD 1.2            **
		**                        **
		**	This template process the information of ABCD units. It needs to	**
		**	include the dk_ABCD1.2_CommonTemplates.xslt file, but if it is being 	**
		**	called by the All_parts XSLT then it is already included before		**
		**	and should be mantained commented            **
		**                        **
		**	Author: Javier de la Torre             		**
		**************************************************************************
-->

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:fn="http://www.w3.org/2004/07/xpath-functions" xmlns:xdt="http://www.w3.org/2004/07/xpath-datatypes" xmlns:n1="http://www.tdwg.org/schemas/abcd/1.2" exclude-result-prefixes="xsl xs fn xdt n1">
	<xsl:output version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes" media-type="text/html"/> 
<!-- 	<xsl:include href="dk_ABCD1.2_CommonTemplates.xslt" /> -->
	
	<xsl:template name="UnitDetails" match="/">
		<hr size="1"/>
		<h3 class="background">Units details</h3>
		<!-- We first create our own UnitD to refeer to it inside the document -->
		<xsl:for-each select="//n1:DataSets/n1:DataSet">
		<xsl:variable name="DataSetId" select="position()"/>
		<xsl:for-each select="n1:Units/n1:Unit">
		
    <!-- We first calculate the ID for this Unit to use it after -->    
    <xsl:variable name="UnitID" select="concat($DataSetId,'_',position())"/>
    <!-- Now the varibale ID contains the Unique identifier -->
    <div id="Unit">
    	<!-- *********************************/HEADER ************************************** 	-->
        	<table width="96%" border="0">
    		<tr>
        <td>
    <xsl:text>
    </xsl:text><a target="_blank"><xsl:attribute name="name"><xsl:value-of select="$UnitID"/></xsl:attribute></a>

        	<xsl:call-template name="preferedTaxonName"/>
        	<xsl:text> 
        	</xsl:text>
        	<br/>
        	<!-- ** GUID ** -->
        	<span class="label">Objekt-id: </span>
        		<span class="style1">
            <xsl:value-of select="n1:UnitID"/>
        		</span>
        	
        	<xsl:if test="n1:RecordBasis">
        		<br/>
        		<span class="label">Datapostunderlag: </span>
        		<xsl:value-of select="n1:RecordBasis"/>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
         <xsl:text>
   			</xsl:text>
        		</td>
        <td align="right">
    <xsl:text>
    </xsl:text>
        	<span class="label">Udspringsinstitut: </span>
            	<xsl:text>
 </xsl:text> <xsl:value-of select="../../n1:OriginalSource/n1:SourceName"/> (<xsl:value-of select="../../n1:OriginalSource/n1:SourceInstitutionCode"/>)<br/><xsl:text>
    </xsl:text>
        	<span class="label">Sidst opdateret: </span>
        	<xsl:value-of select="../../n1:OriginalSource/n1:SourceLastUpdatedDate"/>
        	<br/>
        	<xsl:if test="../../n1:OriginalSource/n1:SourceWebAddress">
        		<a target="_blank">
            <xsl:attribute name="href"><xsl:value-of select="../../n1:OriginalSource/n1:SourceWebAddress"/></xsl:attribute>URL</a> |
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="../../n1:DatasetDerivations/n1:DatasetDerivation/n1:Supplier/n1:EmailAddresses/n1:EmailAddress">
        		<a>
            <xsl:attribute name="href"><xsl:text disable-output-escaping="yes">mailto: </xsl:text><xsl:value-of select="../../n1:DatasetDerivations/n1:DatasetDerivation/n1:Supplier/n1:EmailAddresses/n1:EmailAddress"/></xsl:attribute>E-post</a>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
         <xsl:text>
   			</xsl:text>
        		</td>
    		</tr>
    	</table>
    	<!-- *********************************/HEADER ************************************** 	-->
    	<!-- *********************************IDENTIFICATIONS ************************************** 	-->
    	<h3 class="background">Klassificering(er)</h3>
    	<table width="96%" border="0">
    		<tr>
        <th>Name</th>
        <xsl:if test="n1:Identifications/n1:Identification/n1:TaxonIdentified/n1:HigherTaxa/n1:HigherTaxon != ''">
        	<th>Taxonomi</th>
        </xsl:if>
    <xsl:text>
    </xsl:text>
            <xsl:if test="string(n1:Identifications/n1:Identification/n1:IdentificationReference)">
        		<th>Reference</th>
        </xsl:if>
    <xsl:text>
    </xsl:text>
            <xsl:if test="string(n1:Identifications/n1:Identification/n1:IdentificationNotes)">
            	<th>Anmærkninger </th>
        </xsl:if>
    <xsl:text>
    </xsl:text>
            <xsl:if test="string(n1:Identifications/n1:Identification/n1:TaxonIdentified/n1:InformalNameString)">
            	<th>Trivialnavn(e)</th>
        </xsl:if>
    <xsl:text>
    </xsl:text>
    		</tr>
    		<xsl:for-each select="n1:Identifications/n1:Identification">
        <xsl:sort select="@PreferredIdentificationFlag" data-type="text" order="descending"/>
        <!-- Change the color of the background depending if it is a PREFERED identification or not -->
        <tr>
        	<td>
    <xsl:text>
    </xsl:text>
        		<!-- ***********************************************************************+NAME****************************************************** -->
        		<!--General rule for names -->
        		<!-- Avoid execution if there are no Identifications-->
        		<!--Differenciate if there is only one identification o more -->
        		<xsl:choose>
            <xsl:when test="count(../n1:Identification) = 1">
            	<!--Only one identification, is shown as non prefered -->
                		<span class="prefered"><xsl:value-of select="n1:TaxonIdentified/n1:NameAuthorYearString"/></span>
            </xsl:when>
            <!-- more than 1 identifications -->
            <xsl:otherwise>
            	<!--Check if there is a preferedflag -->
            	<xsl:choose>
            		<xsl:when test="not(@PreferredIdentificationFlag)">
                <!-- Identification without prefered flag -->
                <xsl:value-of select="n1:TaxonIdentified/n1:NameAuthorYearString"/>
            		</xsl:when>
            		<xsl:otherwise>
                <xsl:choose>
                	<xsl:when test="@PreferredIdentificationFlag= '1' or @PreferredIdentificationFlag='true'">
                		<!--Multiple identifications, prefered one -->
                		<span class="prefered">
                    <xsl:value-of select="n1:TaxonIdentified/n1:NameAuthorYearString"/>
                		</span>
                	</xsl:when>
                	<xsl:otherwise>
                		<!--Multiple identifications, non prefered one -->
                		<xsl:value-of select="n1:TaxonIdentified/n1:NameAuthorYearString"/>
                	</xsl:otherwise>
                </xsl:choose>
            		</xsl:otherwise>
            	</xsl:choose>
            </xsl:otherwise>
        		</xsl:choose>
        		<!-- ***********************************************************************+NAME****************************************************** -->
        		<xsl:if test="n1:IdentificationDate">
            <br/>
            <span class="label">Datum: </span>
            <xsl:value-of select="n1:IdentificationDate"/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:Identifier">
            <br/>
            <span class="label">Bestemmer: </span>
            <xsl:value-of select="n1:Identifier"/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        	 <xsl:text>
   			</xsl:text>
        		</td>
        	<xsl:if test="n1:TaxonIdentified/n1:HigherTaxa/n1:HigherTaxon != ''">
        		<td>
    <xsl:text>
    </xsl:text>
            <xsl:for-each select="n1:TaxonIdentified/n1:HigherTaxa/n1:HigherTaxon">
            	<xsl:if test="@TaxonRank">
            		<span class="label">
                <xsl:value-of select="@TaxonRank"/>: 
            		</span>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	<xsl:value-of select="."/>
            	<!--
            	<xsl:if test="count(.)">
            		<br/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	-->
            	<br/>
            </xsl:for-each>
        		 <xsl:text>
   			</xsl:text>
        		</td>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
            	<xsl:if test="string(n1:IdentificationReference)">
        		<td>
    <xsl:text>
    </xsl:text>
            <xsl:value-of select="n1:IdentificationReference/n1:ReferenceCitation"/>
            <br/>
            <span class="label">Detaljer: </span>
            <xsl:value-of select="n1:IdentificationReference/n1:ReferenceDetail"/>
        		 <xsl:text>
   			</xsl:text>
        		</td>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
            	<xsl:if test="string(n1:IdentificationNotes)">
        		<td>
    <xsl:text>
    </xsl:text>
            <xsl:value-of select="n1:IdentificationNotes"/>
        		 <xsl:text>
   			</xsl:text>
        		</td>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
            	<xsl:if test="string(n1:TaxonIdentified/n1:InformalNameString)">
        		<td>
    <xsl:text>
    </xsl:text>
                <xsl:value-of select="n1:TaxonIdentified/n1:InformalNameString"/> <xsl:if test="@language" >(<xsl:value-of select="@Language"/>)</xsl:if>
    <xsl:text>
    </xsl:text>
        		 <xsl:text>
   			</xsl:text>
        		</td>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        </tr>
    		</xsl:for-each>
    	</table>
    	<!-- *********************************IDENTIFICATIONS ************************************** 	-->
    	<!-- *********************************Named Collections************************************** 	-->
    	<xsl:if test="n1:NamedCollections">
    		<h3 class="background">Navngivne samlinger</h3>
    		<table width="96%">
        <tr>
        	<xsl:for-each select="n1:NamedCollections/n1:NamedCollection">
        		<span class="label">Navngiven samling: </span>
        		<xsl:value-of select="."></xsl:value-of>
        	</xsl:for-each>
        </tr>
    		</table>
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	<!-- *********************************Named Collections************************************** 	-->
    	<!-- *********************************GATHERING ************************************** 	-->
    	<xsl:if test="string(n1:Gathering)">
    		<h3 class="background">Indsamling</h3>
    		<table width="96%">
        <tr>
        	<xsl:if test="string(n1:Gathering/n1:GatheringSite)">
        		<th>Beliggenhed </th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="string(n1:Gathering/n1:GatheringAgents)">
        		<th>Indsamler(e) </th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="string(n1:Gathering/n1:GatheringSite/n1:Altitude)">
        	<th>Øvrig information </th></xsl:if>
    <xsl:text>
    </xsl:text>
        </tr>
        <tr valign="top" bgcolor="#f4f4f4">
        	<xsl:if test="string(n1:Gathering/n1:GatheringSite)">
        	<td>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="string(n1:Gathering/n1:GatheringSite/n1:Country)">
        		  <xsl:if test="string(n1:Gathering/n1:GatheringSite/n1:Country/n1:CountryName)">
            <span class="label">Land: </span>
            	<xsl:value-of select="n1:Gathering/n1:GatheringSite/n1:Country/n1:CountryName"/> 
            	<xsl:if test="string(n1:Gathering/n1:GatheringSite/n1:Country/n1:ISO2Letter)"> 
            	(<xsl:value-of select="n1:Gathering/n1:GatheringSite/n1:Country/n1:ISO2Letter"/>)
            	</xsl:if>
    <xsl:text>
    </xsl:text> 
            	<xsl:if test="string(n1:Gathering/n1:GatheringSite/n1:Country/n1:ISO3Letter)"> 
            	(<xsl:value-of select="n1:Gathering/n1:GatheringSite/n1:Country/n1:ISO3Letter"/>)
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            <br/>
            </xsl:if>
    <xsl:text>
    </xsl:text>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="string(n1:Gathering/n1:GatheringSite/n1:NamedAreas)">
            <xsl:for-each select="n1:Gathering/n1:GatheringSite/n1:NamedAreas/n1:NamedArea">
               <xsl:if test="string(n1:NamedAreaClass)">
               <xsl:if test="string(n1:NamedAreaName)">
            	<span class="label">
            	<xsl:value-of select="n1:NamedAreaClass"/>: </span>
            	<xsl:value-of select="n1:NamedAreaName"/>
            	<br/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
	 <xsl:if test="not (n1:NamedAreaClass)">
               <xsl:if test="string(n1:NamedAreaName)">
            	<span class="label">Region: </span>
            	<xsl:value-of select="n1:NamedAreaName"/>
            	<br/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            </xsl:for-each>
            
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="string(n1:Gathering/n1:GatheringSite/n1:LocalityText)">
            <span class="label">Beliggenhed: </span>
            <xsl:value-of select="n1:Gathering/n1:GatheringSite/n1:LocalityText"/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
            		
            		<xsl:if test="n1:Gathering/n1:GatheringSite/n1:SiteCoordinateSets">
            		<br/>
            		<form xml:space="default" action="http://linuxgurrl.agr.gc.ca/mapdata/itis/itisrosa.php" method="POST" target="_blank" name ="form{$UnitID}">
                <input>
                	<xsl:attribute name="value">%3C%3Fxml+version%3D%271.0%27+encoding%3D%27iso-8859-1%27%3F%3E%3Cresponse%3E%3Cheader%3E%3Cauthor%3E%3C%2Fauthor%3E%3Cboundingbox%3E-180%2C-90%2C180%2C90%2CWorld%3C%2Fboundingbox%3E%3Cdescription%3EThis+Generic+Point+Mapper+is+a+service+provided+by+the+Canadian+Biological+Information+Facility%3C%2Fdescription%3E%3Cifx%3E%3C%2Fifx%3E%3Clanguage%3Een%3C%2Flanguage%3E%3Cprojection%3Elatlong%3C%2Fprojection%3E%3Crecordcount%3E%3C%2Frecordcount%3E%3Ctimestamp%3E2004-11-30+11%3A10%3A58.043%3C%2Ftimestamp%3E%3Ctitle%3ESimple+access+to+ABCD+providers+-+Point+Location+Data%3C%2Ftitle%3E%3Curl%3Ehttp%3A%2F%2Fwww.cbif.gc.ca%2Fmc%2Findex_e.php%3C%2Furl%3E%3C%2Fheader%3E%3Crecords<xsl:for-each select="n1:Gathering/n1:GatheringSite/n1:SiteCoordinateSets/n1:SiteCoordinates">%3E%3Crecord<xsl:for-each select="n1:CoordinatesLatLong"><xsl:for-each select="n1:LatitudeDecimal">%3E%3Clatitude%3E<xsl:apply-templates/>%3C%2Flatitude</xsl:for-each><xsl:for-each select="n1:LongitudeDecimal">%3E%3Clongitude%3E<xsl:apply-templates/>%3C%2Flongitude</xsl:for-each></xsl:for-each>%3E%3Crecordurl%3E%3C%2Frecordurl%3E%3C%2Frecord</xsl:for-each>%3E%3C%2Frecords%3E%3C%2Fresponse%3E</xsl:attribute>
                	<xsl:attribute name="type">hidden</xsl:attribute>
                	<xsl:attribute name="name">xml</xsl:attribute>
                </input>
<span class="label">Koordinater (Lat|Lon)<xsl:if test="n1:Gathering/n1:SiteCoordinateSets/n1:SiteCoordinates/n1:CoordinateMethod">(<xsl:value-of select="n1:Gathering/n1:SiteCoordinateSets/n1:SiteCoordinates/n1:CoordinateMethod"/>)</xsl:if>: </span>
             <xsl:value-of select="n1:Gathering/n1:GatheringSite/n1:SiteCoordinateSets/n1:SiteCoordinates/n1:CoordinatesLatLong/n1:LatitudeDecimal"/>, <xsl:value-of select="n1:Gathering/n1:GatheringSite/n1:SiteCoordinateSets/n1:SiteCoordinates/n1:CoordinatesLatLong/n1:LongitudeDecimal"/> <a href="Javascript:document.form{$UnitID}.submit();" target="_blank"> Map!</a>
           
            		</form>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	<!-- /For to create a map-->
            	<xsl:if test="LongitudeDecimal/text()">
            		<br/>
            		<form xml:space="default" action="http://linuxgurrl.agr.gc.ca/mapdata/itis/itisrosa.php" method="POST" target="_blank">
                <xsl:attribute name="name">GeneralMap</xsl:attribute>
                    <input><xsl:attribute name="value">%3C%3Fxml+version%3D%271.0%27+encoding%3D%27iso-8859-1%27%3F%3E%3Cresponse%3E%3Cheader%3E%3Cauthor%3E%3C%2Fauthor%3E%3Cboundingbox%3E-180%2C-90%2C180%2C90%2CWorld%3C%2Fboundingbox%3E%3Cdescription%3EThis+Generic+Point+Mapper+is+a+service+provided+by+the+Canadian+Biological+Information+Facility%3C%2Fdescription%3E%3Cifx%3E%3C%2Fifx%3E%3Clanguage%3Een%3C%2Flanguage%3E%3Cprojection%3Elatlong%3C%2Fprojection%3E%3Crecordcount%3E%3C%2Frecordcount%3E%3Ctimestamp%3E2004-11-30+11%3A10%3A58.043%3C%2Ftimestamp%3E%3Ctitle%3ESimple+access+to+ABCD+providers+-+Point+Location+Data%3C%2Ftitle%3E%3Curl%3Ehttp%3A%2F%2Fwww.cbif.gc.ca%2Fmc%2Findex_e.php%3C%2Furl%3E%3C%2Fheader%3E%3Crecords%3E%3Crecord<xsl:for-each select="LongitudeDecimal">%3E%3Clatitude%3E<xsl:apply-templates/>%3C%2Flatitude</xsl:for-each><xsl:for-each select="dwc:DecimalLongitude">%3E%3Clongitude%3E<xsl:apply-templates/>%3C%2Flongitude</xsl:for-each>%3E%3Crecordurl%3E%3C%2Frecordurl%3E%3C%2Frecord%3E%3C%2Frecords%3E%3C%2Fresponse%3E</xsl:attribute><xsl:attribute name="type">hidden</xsl:attribute><xsl:attribute name="name">xml</xsl:attribute></input>
                Coordinates (Lat|Lon): : <xsl:value-of select="LongitudeDecimal"/>|<xsl:value-of select="dwc:DecimalLongitude"/>  <a href="Javascript:document.GeneralMap.submit()"> Map!</a>
            		</form>
            	</xsl:if>
    <xsl:text>
    </xsl:text>

        	 <xsl:text>
   			</xsl:text>
        		</td>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:Gathering/n1:GatheringAgents">
        		<td>
    <xsl:text>
    </xsl:text>
            <xsl:for-each select="n1:Gathering/n1:GatheringAgents/n1:GatheringAgent">
            	<xsl:apply-templates/>
            	<br/>
            </xsl:for-each>
        		 <xsl:text>
   			</xsl:text>
        		</td>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        		<td>
    <xsl:text>
    </xsl:text>
            <xsl:if
            	test="string(n1:Gathering/n1:GatheringSite/n1:Altitude/n1:MeasurementText)">
            	<span class="label">Højde: </span>
            	<xsl:value-of select="n1:Gathering/n1:GatheringSite/n1:Altitude/n1:MeasurementText"/>
            	<br/>
            </xsl:if>
    <xsl:text>
    </xsl:text>
            <xsl:if
            	test="string(n1:Gathering/n1:GatheringSite/n1:Altitude/n1:MeasurementAtomized)">
            	<xsl:for-each
            		select="n1:Gathering/n1:GatheringSite/n1:Altitude/n1:MeasurementAtomized">
            		<span class="label">Højde: </span>
            		<xsl:value-of select="n1:MeasurementLowerValue"/>
            		<xsl:value-of select="n1:MeasurementScale"/>
            		<xsl:if test="string(n1:MeasurementUpperValue)">-
                <xsl:value-of select="n1:MeasurementUpperValue"/></xsl:if>
                <xsl:for-each select="n1:MeasurementLowerValue">
            	<xsl:value-of select="@ValueDataType"/>
            	</xsl:for-each>
            	<xsl:for-each select="n1:MeasurementUpperValue">
            	<xsl:value-of select="@ValueDataType"/>
            	</xsl:for-each>
    <xsl:text>
    </xsl:text>
            		<xsl:value-of select="n1:MeasurementScale"/>
            		<br/>
            	</xsl:for-each>
            </xsl:if>
    <xsl:text>
    </xsl:text>
            <xsl:if
            	test="string(n1:Gathering/n1:GatheringSite/n1:Depth/n1:MeasurementAtomized)">
            	<xsl:for-each
            		select="n1:Gathering/n1:GatheringSite/n1:Depth/n1:MeasurementAtomized">
            		<span class="label">Dybde: </span>
            		<xsl:value-of select="n1:MeasurementLowerValue"/>
            		<xsl:value-of select="n1:MeasurementScale"/>
            		<xsl:if test="string(n1:MeasurementUpperValue)">-
                <xsl:value-of select="n1:MeasurementUpperValue"
                /></xsl:if>
    <xsl:text>
    </xsl:text>
            		<xsl:value-of select="n1:MeasurementScale"/>
            		<br/>
            	</xsl:for-each>
            </xsl:if>
    <xsl:text>
    </xsl:text>
            <xsl:if test="string(n1:Gathering/n1:GatheringSite/n1:Height/n1:MeasurementAtomized)">
            	<xsl:for-each select="n1:Gathering/n1:GatheringSite/n1:Height/n1:MeasurementAtomized">
            		<span class="label">Højde: </span>
            		<xsl:value-of select="n1:MeasurementLowerValue"/>
            		<xsl:value-of select="n1:MeasurementScale"/>
            		<xsl:if test="string(n1:MeasurementUpperValue)">- 
                <xsl:value-of select="n1:MeasurementUpperValue"/>
            		</xsl:if>
    <xsl:text>
    </xsl:text>
            		<xsl:value-of select="n1:MeasurementScale"/>
            		<br/>
            	</xsl:for-each>
            </xsl:if>
    <xsl:text>
    </xsl:text>		
            <xsl:if
            	test="string(n1:Gathering/n1:GatheringSite/n1:BiotopeData)">
            	<span class="label">Biotop: </span>
            	<xsl:value-of
            		select="n1:Gathering/n1:GatheringSite/n1:BiotopeData"/>
            	<br/>
            </xsl:if>
    <xsl:text>
    </xsl:text>
            <xsl:if test="string(n1:Gathering/n1:GatheringDateTime/DateText)">
            	<span class="label">Datum: </span>
            	<xsl:value-of select="n1:Gathering/n1:GatheringDateTime/DateText"/>
            	<br/>
            </xsl:if>
    <xsl:text>
    </xsl:text>
            <xsl:if test="string(n1:Gathering/n1:Project/n1:ProjectTitle)">
            	<span class="label">Projekt: </span>
            	<xsl:value-of select="n1:Gathering/n1:ProjectTitle"/>
            </xsl:if>
    <xsl:text>
    </xsl:text>
            <xsl:if test="string(n1:Gathering/n1:GatheringCode)">
            	<span class="label">Indsamlingskode: </span>
            	<xsl:value-of select="n1:Gathering/n1:GatheringCode"/>
            </xsl:if>
    <xsl:text>
    </xsl:text>
            
        		 <xsl:text>
   			</xsl:text>
        		</td>
        </tr>
    		</table>
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	<!-- *********************************GATHERING ************************************** 	-->
    	<!-- *********************************DIGITAL IMAGES ************************************** 	-->
    	<xsl:if test="n1:UnitDigitalImages/n1:UnitDigitalImage/n1:ImageURI">
    		<xsl:for-each select="n1:UnitDigitalImages">
        <h3 class="background">  Digitale billeder</h3>
        <table cellpadding="5" cellspacing="5" width="96%">
        	<tbody>
        		<tr valign="top" bgcolor="#f4f4f4">
            <td>
    <xsl:text>
    </xsl:text>
            	<ul>
            <xsl:text>
            </xsl:text>
            		<xsl:for-each select="n1:UnitDigitalImage/n1:ImageURI">
                <li>
                	<xsl:choose>
                		<xsl:when test="substring(.,1,7)='http://' or substring(.,1,8)='https://'">
                    <a href="{.}" target ="_blank">
                	<xsl:if test="string-length(.)>80">
                		<xsl:value-of select="substring(.,1,40)"/>...<xsl:value-of select="substring(.,60)"/>
                	</xsl:if>
    <xsl:text>
    </xsl:text>
                	<xsl:if test="not(string-length(.)>80)">
                		<xsl:value-of select="."/>
                	</xsl:if>
    <xsl:text>
    </xsl:text>
                </a>
                		</xsl:when>
                		<xsl:otherwise>
                    <xsl:value-of select="." disable-output-escaping="yes"/>
                		</xsl:otherwise>
                	</xsl:choose>
                <xsl:text>
            </xsl:text>
 </li>
            <xsl:text>
            </xsl:text>
            		</xsl:for-each>
            	<xsl:text>
            </xsl:text>
 </ul>
            <xsl:text>
            </xsl:text>
             <xsl:text>
   			</xsl:text>
        		</td>
            	<!-- IPR statements for pictures -->
        		<!--	<xsl:for-each select="n1:UnitDigitalImage/n1:ImageIPR">
            	<td>
    <xsl:text>
    </xsl:text>
            		<span class="label">IPR: </span>
            		<xsl:apply-templates/>
            	 <xsl:text>
   			</xsl:text>
        		</td>
            </xsl:for-each>-->
        		</tr>
        	</tbody>
        </table>
    		</xsl:for-each>
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	<!-- *********************************DIGITAL IMAGES ************************************** 	-->
    	<!-- *********************************FACTS ************************************** 	-->
        	<xsl:if test="n1:UnitFacts/n1:FactText">        
    	<xsl:for-each select="n1:UnitFacts">
    		<h3 class="background">Fakta</h3>
    		<table width="96%">
        <tr>
        	<xsl:if test="n1:UnitFact/n1:FactType">
        		<th>Fakta type</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:UnitFact/n1:FactText">
        		<th>Fakta tekst</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:UnitFact/n1:DateEntered">
        		<th>Dato indført</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:UnitFact/n1:AddedBy">
        		<th>Tilføjet af </th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:UnitFact/n1:Reference">
        		<th>Reference</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        </tr>
        <xsl:for-each select="n1:UnitFact">
        	<tr>
        		<xsl:if test="n1:FactType">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:for-each select="n1:FactType">
            		<xsl:apply-templates/>
            	</xsl:for-each>
             <xsl:text>
   			</xsl:text>
        		</td>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:FactText">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:for-each select="n1:FactText">
            		<xsl:apply-templates/>
            	</xsl:for-each>
             <xsl:text>
   			</xsl:text>
        		</td>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:DateEntered">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:for-each select="n1:DateEntered">
            		<xsl:apply-templates/>
            	</xsl:for-each>
             <xsl:text>
   			</xsl:text>
        		</td>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:AddedBy">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:for-each select="n1:AddedBy">
            		<xsl:apply-templates/>
            	</xsl:for-each>
             <xsl:text>
   			</xsl:text>
        		</td>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:Reference">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:for-each select="n1:Reference">
            		<xsl:apply-templates/>
            	</xsl:for-each>
             <xsl:text>
   			</xsl:text>
        		</td>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        	</tr>
        </xsl:for-each>
    		</table>
    	</xsl:for-each>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
    	<!-- *********************************FACTS ************************************** 	-->
    	<!-- ******************************** UNIR MEASUREMENTS ********************  -->
    	<xsl:for-each select="n1:UnitMeasurements">
    		<xsl:for-each select="n1:UnitMeasurement">
        <table width="96%">
        	<tr>
        		<xsl:if test="n1:UnitMeasurements/n1:UnitMeasurement/n1:MeasurementAppliesTo">
            <th>Opmålingen gælder </th>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:UnitMeasurements/n1:UnitMeasurement/n1:MeasurementMethod">
            <th>Målemetode</th>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:UnitMeasurements/n1:UnitMeasurement/n1:MeasurementDuration">
            <th>Måle tid</th>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:UnitMeasurements/n1:UnitMeasurement/n1:MeasurementAccuracy">
            <th>Opmålingsnøjagtighed</th>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:UnitMeasurements/n1:UnitMeasurement/n1:ParameterMeasured">
            <th>Opmålt parameter</th>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:UnitMeasurements/n1:UnitMeasurement/n1:MeasurementScale">
            <th>Målestok</th>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:UnitMeasurements/n1:UnitMeasurement/n1:MeasurementLowerValue">
            <th>Nedre måleværdi</th>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:UnitMeasurements/n1:UnitMeasurement/n1:MeasurementUpperValue">
            <th>Øvre måleværdi </th>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        	</tr>
        	<xsl:for-each select="n1:MeasurementAtomized">
        		<tr>
            <xsl:for-each select="n1:MeasurementAppliesTo">
            	<td>
    <xsl:text>
    </xsl:text>
            		<xsl:apply-templates/>
            	 <xsl:text>
   			</xsl:text>
        		</td>
            </xsl:for-each>
            <xsl:for-each select="n1:MeasurementMethod">
            	<td>
    <xsl:text>
    </xsl:text>
            		<xsl:apply-templates/>
            	 <xsl:text>
   			</xsl:text>
        		</td>
            </xsl:for-each>
            <xsl:for-each select="n1:MeasurementDuration">
            	<td>
    <xsl:text>
    </xsl:text>
            		<xsl:apply-templates/>
            	 <xsl:text>
   			</xsl:text>
        		</td>
            </xsl:for-each>
            <xsl:for-each select="n1:MeasurementAccuracy">
            	<td>
    <xsl:text>
    </xsl:text>
            		<xsl:apply-templates/>
            	 <xsl:text>
   			</xsl:text>
        		</td>
            </xsl:for-each>
            <xsl:for-each select="n1:ParameterMeasured">
            	<td>
    <xsl:text>
    </xsl:text>
            		<xsl:apply-templates/>
            	 <xsl:text>
   			</xsl:text>
        		</td>
            </xsl:for-each>
            <xsl:for-each select="n1:MeasurementScale">
            	<td>
    <xsl:text>
    </xsl:text>
            		<xsl:apply-templates/>
            	 <xsl:text>
   			</xsl:text>
        		</td>
            </xsl:for-each>
            <xsl:for-each select="n1:MeasurementLowerValue">
            	<td>
    <xsl:text>
    </xsl:text>
            		<xsl:apply-templates/>
            	 <xsl:text>
   			</xsl:text>
        		</td>
            </xsl:for-each>
            <xsl:for-each select="n1:MeasurementUpperValue">
            	<td>
    <xsl:text>
    </xsl:text>
            		<xsl:apply-templates/>
            	 <xsl:text>
   			</xsl:text>
        		</td>
            </xsl:for-each>
        		</tr>
        	</xsl:for-each>
        </table>
    		</xsl:for-each>
    	</xsl:for-each>
    	<!-- ******************************** UNIR MEASUREMENTS ********************  -->
    	<!--********************************** UNIT COLLECTION DOMAIN/ BOTANICAL GARDEN ***************************** -->
    	<xsl:for-each select="n1:UnitCollectionDomain">
    		<xsl:if test="n1:HerbariumUnit">
        <h3 class="background">Data specifikke for herbarium eksemplarer</h3>
        <table width="96%">
        	<tr>
        		<td>
    <xsl:text>
    </xsl:text>
            <span class="label">Exsikater: </span>
            <xsl:value-of select="n1:HerbariumUnit/n1:Exsiccatum"/>
        		 <xsl:text>
   			</xsl:text>
        		</td>
        	</tr>
        </table>
    		</xsl:if>
    <xsl:text>
    </xsl:text>
    		<xsl:if test="n1:BotanicalGardenUnit">
    		<h3 class="background">Data specifikke for botanisk haver</h3>
    		</xsl:if>
    <xsl:text>
    </xsl:text>
    		<table width="96%">
        <tr>
        	<xsl:if test="n1:BotanicalGardenUnit/n1:AccessionSpecimenNumbers">
        		<th>Eksemplarets/objektets accessionsnummer/numre</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:BotanicalGardenUnit/n1:AccessionStatus">
        		<th>Accessions status</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:BotanicalGardenUnit/n1:AccessionMaterialType">
        		<th>Accessionsmateriale type</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:BotanicalGardenUnit/n1:Hardiness">
        		<th>Hårdførhed </th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:BotanicalGardenUnit/n1:ProvenanceCategory">
        		<th>Oprindelseskategori </th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:BotanicalGardenUnit/n1:PropagationHistoryCode">
        		<th>Kode for forplantningshistorie</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:BotanicalGardenUnit/n1:AccessionLineage">
        		<th>Accessionslinie</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:BotanicalGardenUnit/n1:DonorCategory">
        		<th>Giverkategori</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        </tr>
        <xsl:for-each select="n1:BotanicalGardenUnit">
        	<tr>
        		<xsl:for-each select="n1:AccessionSpecimenNumbers">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:apply-templates/>
             <xsl:text>
   			</xsl:text>
        		</td>
        		</xsl:for-each>
        		<xsl:for-each select="n1:AccessionStatus">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:apply-templates/>
             <xsl:text>
   			</xsl:text>
        		</td>
        		</xsl:for-each>
        		<xsl:for-each select="n1:AccessionMaterialType">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:apply-templates/>
             <xsl:text>
   			</xsl:text>
        		</td>
        		</xsl:for-each>
        		<xsl:for-each select="n1:Hardiness">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:apply-templates/>
             <xsl:text>
   			</xsl:text>
        		</td>
        		</xsl:for-each>
        		<xsl:for-each select="n1:ProvenanceCategory">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:apply-templates/>
             <xsl:text>
   			</xsl:text>
        		</td>
        		</xsl:for-each>
        		<xsl:for-each select="n1:PropagationHistoryCode">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:apply-templates/>
             <xsl:text>
   			</xsl:text>
        		</td>
        		</xsl:for-each>
        		<xsl:for-each select="n1:AccessionLineage">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:apply-templates/>
             <xsl:text>
   			</xsl:text>
        		</td>
        		</xsl:for-each>
        		<xsl:for-each select="n1:DonorCategory">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:apply-templates/>
             <xsl:text>
   			</xsl:text>
        		</td>
        		</xsl:for-each>
        	</tr>
        </xsl:for-each>
    		</table>
    	</xsl:for-each>
    	<!-- *********************************OTHER DATA ************************************** 	-->
    	<xsl:if test="n1:LastEditor or n1:DateLastEdited or n1:CollectorsFieldNumber or n1:UnitStateDomain/n1:SpecimenUnit/n1:NomenclaturalTypeDesignations/n1:NomenclaturalTypeDesignation/n1:TypeStatus">
    		<h3 class="background">Øvrige data</h3>
    		<table width="96%">
        <tbody>
        	<tr bgcolor="#f4f4f4" valign="top">
        		<td>
    <xsl:text>
    </xsl:text>
            <!-- Last editor -->
            <xsl:for-each select="n1:LastEditor">
            	<span class="label">Seneste redaktør: </span>
            	<xsl:apply-templates/>
            </xsl:for-each>
            <!-- Last editor -->
            <xsl:for-each select="n1:DateLastEdited">
            	<span class="label">Datum_Last_Edited: </span>
            	<xsl:apply-templates/>
            </xsl:for-each>
            <xsl:for-each select="n1:CollectorsFieldNumber">
            	<span class="label">Indsamlerens feltnummer: </span>
            	<xsl:apply-templates/>
            </xsl:for-each>
            <xsl:for-each select="n1:UnitStateDomain/n1:SpecimenUnit/n1:NomenclaturalTypeDesignations/n1:NomenclaturalTypeDesignation/n1:TypeStatus">
            	<br/>
            	<span class="label">Type status: </span>
            	<xsl:apply-templates/>
            </xsl:for-each>
            <xsl:for-each select="n1:UnitStateDomain/n1:SpecimenUnit/n1:NomenclaturalTypeDesignations/n1:NomenclaturalTypeDesignation/n1:TypifiedName">
            	<br/>
            	<span class="label">Karakteristisk navn: </span>
            	<xsl:apply-templates/>
            </xsl:for-each>
            <xsl:for-each select="n1:UnitStateDomain/n1:SpecimenUnit/n1:NomenclaturalTypeDesignations/n1:NomenclaturalTypeDesignation/n1:NomenclaturalReference">
            	<br/>
            	<span class="label"> Nomenklatorisk reference: </span>
            	<xsl:apply-templates/>
            </xsl:for-each>
        		 <xsl:text>
   			</xsl:text>
        		</td>
        	</tr>
        </tbody>
    		</table>
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	<!-- *********************************OTHER DATA ************************************** 	-->
    	<!-- ********************************* IPR Specific for the Unit ************************************** 	-->
    	<xsl:for-each select="n1:RecordRights">
    		<h3 class="background">Specifikke objektrettigheder</h3>
    		<xsl:call-template name="RightsTable"/>
    	</xsl:for-each>
    	<!-- *********************************IPR Specific for the Unit************************************** 	-->
    	<!-- ********************************* UnitStatements ************************************** 	-->
    	<xsl:for-each select="n1:UnitStatements">
    		<h3 class="background">Objekt statements</h3>
    		<table width="96%">
        <tbody>
        	<tr bgcolor="#f4f4f4" valign="top">
        		<td>
    <xsl:text>
    </xsl:text>
            <xsl:apply-templates/>
        		 <xsl:text>
   			</xsl:text>
        		</td>
        	</tr>
        </tbody>
    		</table>
    	</xsl:for-each>
    	<!-- ********************************* UnitStatements************************************** 	-->
    	<!-- *********************************NOTES ************************************** 	-->
    <xsl:if test="string(n1:UnitDescription)">
    	<xsl:for-each select="n1:UnitDescription">
    		<h3 class="background">Anmærkninger</h3>
    		<table width="96%">
        <tbody>
        	<tr bgcolor="#f4f4f4" valign="top">
        		<td>
    <xsl:text>
    </xsl:text>
            <xsl:apply-templates/>
        		 <xsl:text>
   			</xsl:text>
        		</td>
        	</tr>
        </tbody>
    		</table>
    	</xsl:for-each>
    </xsl:if>
    <xsl:text>
    </xsl:text>
    	<!-- *********************************NOTES ************************************** 	-->
    	<p/>
    </div>
    <p/>
		</xsl:for-each>
		</xsl:for-each>	
		<!--      **************************************UNIT*********************************************  -->
	</xsl:template>
</xsl:stylesheet>