<?xml version="1.0" encoding="UTF-8"?>
<!-- 	**************************************************************************
		**	Unit details library for ABCD 2.0            **
		**                        **
		**	This template process the information of ABCD units. It needs to	**
		**	include the ABCD1.2_CommonTemplates.xslt file, but if it is being 	**
		**	called by the All_parts XSLT then it is already included before		**
		**	and should be mantained commented            **
		**                        **
		**	Author: Javier de la Torre             		**
		**************************************************************************
-->

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:fn="http://www.w3.org/2004/07/xpath-functions" xmlns:xdt="http://www.w3.org/2004/07/xpath-datatypes" xmlns:n1="http://www.tdwg.org/schemas/abcd/2.06" exclude-result-prefixes="xsl xs fn xdt n1">
	<xsl:output version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes" media-type="text/html"/> 
	<xsl:include href="nor_ABCD2.0_CommonTemplates.xslt" />  
	<xsl:include href="nor_ABCD2.0_EFG.xslt" />
	
	<xsl:template name="UnitDetails" match="/">
		<hr size="1"/>
		<h3 class="background 1">objektdetaljer</h3>
		<!-- We first create our own UnitD to refeer to it inside the document -->
		<xsl:for-each select="//n1:DataSets/n1:DataSet">
		<xsl:variable name="DataSetId" select="position()"/>
		<xsl:for-each select="n1:Units/n1:Unit">
		
    <!-- We first calculate the ID for this Unit to use it after -->    
    <xsl:variable name="UnitID" select="concat($DataSetId,'_',position())"/>
    <!-- Now the varibale ID contains the Unique identifier -->
    <div id="Unit">
    <xsl:text>
    </xsl:text>
    	<!-- *********************************/HEADER ************************************** 	-->
    	<table width="96%" border="0">
    		<tr>
        <td>
    <xsl:text>
    </xsl:text><a><xsl:attribute name="name"><xsl:value-of select="$UnitID"/></xsl:attribute></a><xsl:text>
    </xsl:text>

        	<xsl:call-template name="preferedTaxonName"/>
        	<xsl:text> 
        	</xsl:text>
        	<br/>
        	<!-- ** GUID ** -->
        	<span class="label">Objekt-ID: </span>
        		<span class="style1">
            <xsl:value-of select="n1:UnitID"/>
        		</span>
        	<xsl:if test="n1:UnitGUID">
        		<br/>
        		<span class="label">Objekt GUID: </span>
        		<xsl:value-of select="n1:UnitGUID"/>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	
        	<xsl:if test="n1:UnitIDNumeric">
        		<br/>
        		<span class="label">Objekt-ID_Numeric: </span>
        		<xsl:value-of select="n1:UnitIDNumeric"/>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:RecordBasis">
        		<br/>
        		<span class="label">Datapostunderlag: </span>
        		 <xsl:if test="n1:RecordBasis='S' or n1:RecordBasis='s'">Specimen</xsl:if>
<xsl:if test="n1:RecordBasis='O' or n1:RecordBasis='o'">Observation</xsl:if>
<xsl:if test="n1:RecordBasis='G' or n1:RecordBasis='g'">Germplasm</xsl:if>
<xsl:if test="n1:RecordBasis!='S' and n1:RecordBasis!='s' and n1:RecordBasis!='O' and n1:RecordBasis!='o' and n1:RecordBasis!='G' and n1:RecordBasis!='g'">
<xsl:value-of select="n1:RecordBasis"/>
</xsl:if>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:KindOfUnit">
        		<br/>
        		<span class="label">Objektstype: </span>
        		<xsl:value-of select="n1:KindOfUnit"/>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        </td>
        <td align="right">
    <xsl:text>
    </xsl:text>
        	<span class="label">Kildeinstitusjon: </span>
        		<xsl:value-of select="n1:SourceInstitutionID"/><br/>
<span class="label">Samling: </span><xsl:value-of select="n1:SourceID"/><br/>
        	<xsl:if test="string(n1:LastEditor)">
        		<span class="label">Siste redakt�r: </span>
        		<xsl:value-of select="n1:LastEditor"/><br/>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:DateLastEdited">
        		<span class="label">Sist oppdatert: </span>
        	<xsl:value-of select="n1:DateLastEdited"/>
        	<br/>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="../../n1:OriginalSource/n1:SourceWebAddress">
        		<a>
            <xsl:attribute name="href"><xsl:value-of select="../../n1:OriginalSource/n1:SourceWebAddress"/></xsl:attribute>URL</a> |
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="../../n1:DatasetDerivations/n1:DatasetDerivation/n1:Supplier/n1:EmailAddresses/n1:EmailAddress">
        		<a>
            <xsl:attribute name="href"><xsl:text disable-output-escaping="yes">mailto: </xsl:text><xsl:value-of select="../../n1:DatasetDerivations/n1:DatasetDerivation/n1:Supplier/n1:EmailAddresses/n1:EmailAddress"/></xsl:attribute>E-post</a>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        </td>
    		</tr>
    	</table>
    	<!-- *********************************/HEADER ************************************** 	-->
    	<!-- *********************************IDENTIFICATIONS ************************************** 	-->
    	<h3 class="background 2">Bestemming(er)</h3>
<table width="96%" border="0" cellspacing="0" cellpadding="0">
		
    		<xsl:for-each select="n1:Identifications/n1:Identification">
        <xsl:sort select="n1:PreferredFlag" data-type="number"  order="descending"/>
        <!-- Change the color of the background depending if it is a PREFERED identification or not -->
        <tr><td>
    <xsl:text>
    </xsl:text><span class="label">Namn: </span><xsl:text>
            </xsl:text></td><td>
    <xsl:text>
    </xsl:text>
        		<!-- ***********************************************************************+NAME****************************************************** -->
        		<!--General rule for names -->
        		<!-- Avoid execution if there are no Identifications-->
        		<!--Differenciate if there is only one identification o more -->
        		
        		
        		<xsl:choose>
            <xsl:when test="count(../n1:Identification) = 1">
            	<!--Only one identification, is shown as non prefered -->
            	<span class="prefered"><xsl:value-of select="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:FullScientificNameString"/></span>
            </xsl:when>
            <!-- more than 1 identifications -->
            <xsl:otherwise>
            	<!--Check if there is a preferedflag -->
            	<xsl:choose>
            		<xsl:when test="not(n1:PreferredFlag)">
                <!-- Identification without prefered flag -->
                <xsl:value-of select="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:FullScientificNameString"/>
            		</xsl:when>
            		<xsl:otherwise>
                <xsl:choose>
                	<xsl:when test="n1:PreferredFlag = '1' or n1:PreferredFlag='true'">
                		<!--Multiple identifications, prefered one -->
                		<span class="prefered">
                    <xsl:value-of select="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:FullScientificNameString"/>
                		</span>
                	</xsl:when>
                	<xsl:otherwise>
                		<!--Multiple identifications, non prefered one -->
                		<xsl:value-of select="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:FullScientificNameString"/>
                	</xsl:otherwise>
                </xsl:choose>
            		</xsl:otherwise>
            	</xsl:choose>
            </xsl:otherwise>
        		</xsl:choose>
        		<xsl:text>
    </xsl:text>
        		</td></tr>
        		<!-- ***********************************************************************+NAME****************************************************** -->
        		<xsl:if test="string(n1:Date)">
        		<xsl:choose>
            <xsl:when test="n1:PreferredFlag = '1' or n1:PreferredFlag='true'">
            <tr class="prefered"><td>
    <xsl:text>
    </xsl:text>
            <span class="label">Dato: </span><xsl:text>
            </xsl:text></td><td>
    <xsl:text>
    </xsl:text>
            <!--<xsl:value-of select="n1:Date"/>-->
            <xsl:if test="string(n1:Date/n1:DateText)">DateText: <xsl:value-of select="n1:Date/n1:DateText"/><br/></xsl:if><xsl:text>
 </xsl:text>
            <xsl:if test="string(n1:Date/n1:ISODateTimeBegin)">DateTimeBegin: <xsl:value-of select="n1:Date/n1:ISODateTimeBegin"/><br/></xsl:if><xsl:text>
 </xsl:text>
            <xsl:if test="string(n1:Date/n1:ISODateTimeEnd)">DateTimeEnd: <xsl:value-of select="n1:Date/n1:ISODateTimeEnd"/><br/></xsl:if><xsl:text>
 </xsl:text>
            </td>
            </tr>
            </xsl:when>
            <xsl:otherwise>
            	<tr><td>
    <xsl:text>
    </xsl:text>
            	<span class="label">Dato: </span><xsl:text>
            </xsl:text></td><td>
    <xsl:text>
    </xsl:text>
            	<!--<xsl:value-of select="n1:Date"/>-->
            <xsl:if test="string(n1:Date/n1:DateText)">DateText: <xsl:value-of select="n1:Date/n1:DateText"/><br/></xsl:if><xsl:text>
 </xsl:text>
            <xsl:if test="string(n1:Date/n1:ISODateTimeBegin)">DateTimeBegin: <xsl:value-of select="n1:Date/n1:ISODateTimeBegin"/><br/></xsl:if><xsl:text>
 </xsl:text>
            <xsl:if test="string(n1:Date/n1:ISODateTimeEnd)">DateTimeEnd: <xsl:value-of select="n1:Date/n1:ISODateTimeEnd"/><br/></xsl:if><xsl:text>
 </xsl:text>
            </td>
            	</tr>
            </xsl:otherwise>
        		</xsl:choose>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
	
        		<xsl:if test="string(n1:Identifiers/n1:Identifier/n1:PersonName/n1:FullName)">
            <xsl:choose>
            <xsl:when test="n1:PreferredFlag = '1' or n1:PreferredFlag='true'">
            <tr class="prefered"><td>
    <xsl:text>
    </xsl:text>
            <span class="label">Bestemmer: </span><xsl:text>
            </xsl:text></td><td>
    <xsl:text>
    </xsl:text>
            <xsl:value-of select="n1:Identifiers/n1:Identifier/n1:PersonName/n1:FullName"/></td>
            </tr>
            </xsl:when>
            <xsl:otherwise>
            	<tr><td>
    <xsl:text>
    </xsl:text>
            	<span class="label">Bestemmer: </span><xsl:text>
            </xsl:text></td><td>
    <xsl:text>
    </xsl:text>
            	<xsl:value-of select="n1:Identifiers/n1:Identifier/n1:PersonName/n1:FullName"/></td>
            	</tr>
        		</xsl:otherwise>
        		</xsl:choose>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        	
        	
		<xsl:if test="string(n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAddendum)">
    <xsl:choose>
    	<xsl:when test="n1:PreferredFlag = '1' or n1:PreferredFlag='true'">
    		<tr class="prefered"><td>
    <xsl:text>
    </xsl:text>
    		<span class="label">Navnetillegg: </span><xsl:text>
            </xsl:text></td><td>
    <xsl:text>
    </xsl:text>
    		<xsl:value-of select="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAddendum"/>
    		</td>
    		</tr>
    	</xsl:when>
    <xsl:otherwise>
    	<tr><td>
    <xsl:text>
    </xsl:text>
    	<span class="label">Navnetillegg: </span><xsl:text>
            </xsl:text></td><td>
    <xsl:text>
    </xsl:text>
    	<xsl:value-of select="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAddendum"/>
    	</td>
    	</tr>
    </xsl:otherwise>
		</xsl:choose>
		</xsl:if>
    <xsl:text>
    </xsl:text>
    
    	<xsl:if test="n1:Result/n1:TaxonIdentified/n1:HigherTaxa/n1:HigherTaxon or n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAtomised/n1:Botanical">
    	<xsl:choose>
    		<xsl:when test="n1:PreferredFlag = '1' or n1:PreferredFlag='true'">
    		<tr class="prefered"><td>
    <xsl:text>
    </xsl:text>
    		<span class="label">Taxonomi: </span><xsl:text>
            </xsl:text></td><td>
    <xsl:text>
    </xsl:text>
    		<xsl:for-each select="n1:Result/n1:TaxonIdentified/n1:HigherTaxa/n1:HigherTaxon">
        <xsl:value-of select="n1:HigherTaxonName"/>
        	<xsl:if test="n1:HigherTaxonRank">
        		<span class="example">
            (<xsl:value-of select="n1:HigherTaxonRank"/>)
        		</span>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	;
    		</xsl:for-each>
    		  <br/>
         <xsl:if test="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAtomised/n1:Botanical/n1:GenusOrMonomial">
            Genus: <xsl:value-of select="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAtomised/n1:Botanical/n1:GenusOrMonomial"/><br/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAtomised/n1:Botanical/n1:FirstEpithet">
            FirstEpithet: <xsl:value-of select="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAtomised/n1:Botanical/n1:FirstEpithet"/><br/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAtomised/n1:Botanical/n1:SecondEpithet">
            SecondEpithet: <xsl:value-of select="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAtomised/n1:Botanical/n1:SecondEpithet"/><br/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		
        		<xsl:if test="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAtomised/n1:Botanical/n1:AuthorTeam">
            AuthorTeam: <xsl:value-of select="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAtomised/n1:Botanical/n1:AuthorTeam"/><br/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>	
        		<xsl:if test="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAtomised/n1:Botanical/n1:Rank">
            Rank: <xsl:value-of select="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAtomised/n1:Botanical/n1:Rank"/><br/>
        		</xsl:if>
    <xsl:text>
    </xsl:text> 
    		</td>
    		</tr>
    		</xsl:when>
    		<xsl:otherwise>
        	<tr><td>
    <xsl:text>
    </xsl:text>
        	<span class="label">Taxonomi: </span><xsl:text>
            </xsl:text></td><td>
    <xsl:text>
    </xsl:text>
        <xsl:for-each select="n1:Result/n1:TaxonIdentified/n1:HigherTaxa/n1:HigherTaxon">
        	<xsl:value-of select="n1:HigherTaxonName"/>
        		<xsl:if test="n1:HigherTaxonRank">
            <span class="example">
            	(<xsl:value-of select="n1:HigherTaxonRank"/>)
            </span>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		;
        </xsl:for-each>
          <br/>
         <xsl:if test="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAtomised/n1:Botanical/n1:GenusOrMonomial">
            Genus: <xsl:value-of select="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAtomised/n1:Botanical/n1:GenusOrMonomial"/><br/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAtomised/n1:Botanical/n1:FirstEpithet">
            FirstEpithet: <xsl:value-of select="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAtomised/n1:Botanical/n1:FirstEpithet"/><br/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAtomised/n1:Botanical/n1:SecondEpithet">
            SecondEpithet: <xsl:value-of select="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAtomised/n1:Botanical/n1:SecondEpithet"/><br/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		
        		<xsl:if test="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAtomised/n1:Botanical/n1:AuthorTeam">
            AuthorTeam: <xsl:value-of select="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAtomised/n1:Botanical/n1:AuthorTeam"/><br/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>	
        		<xsl:if test="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAtomised/n1:Botanical/n1:Rank">
            Rank: <xsl:value-of select="n1:Result/n1:TaxonIdentified/n1:ScientificName/n1:NameAtomised/n1:Botanical/n1:Rank"/><br/>
        		</xsl:if>
    <xsl:text>
    </xsl:text> 
        </td>
        </tr>
    		</xsl:otherwise>
    	</xsl:choose>
    	</xsl:if>
    <xsl:text>
    </xsl:text>

    <xsl:if test="string(n1:References/n1:Reference/n1:TitleCitation)">
    	<xsl:choose>
    		<xsl:when test="n1:PreferredFlag = '1' or n1:PreferredFlag='true'">
        <tr class="prefered"><td>
    <xsl:text>
    </xsl:text>
        <span class="label">Referanse: </span><xsl:text>
            </xsl:text></td><td>
    <xsl:text>
    </xsl:text>
        <xsl:for-each select="n1:References/n1:Reference">
        		<xsl:value-of select="n1:TitleCitation"/>
        	<br/>
        	<xsl:if test="n1:CitationDetail">
        		<span>Detaljer: </span>
        		<xsl:value-of select="n1:CitationDetail"/>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:URI">
        		| <a href="{n1:URI}" target ="_blank">URL</a>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        </xsl:for-each>
        </td>
        </tr>
    		</xsl:when>
    		<xsl:otherwise>
        	<tr><td>
    <xsl:text>
    </xsl:text>
        	<span class="label">Referanse: </span><xsl:text>
            </xsl:text></td><td>
    <xsl:text>
    </xsl:text>
        	<xsl:for-each select="n1:References/n1:Reference">
        		<xsl:value-of select="n1:TitleCitation"/>
        	<br/>
        	<xsl:if test="n1:CitationDetail">
        		<span>Detaljer: </span>
        		<xsl:value-of select="n1:CitationDetail"/>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:URI">
        		| <a href="{n1:URI}" target ="_blank">URL</a>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        </xsl:for-each>
        </td>
        </tr>
    		</xsl:otherwise>
    	</xsl:choose>
    	</xsl:if>
    <xsl:text>
    </xsl:text>

    <xsl:if test="string(n1:Notes)">
    	<xsl:choose>
        <xsl:when test="n1:PreferredFlag = '1' or n1:PreferredFlag='true'">
        <tr class="prefered"><td>
    <xsl:text>
    </xsl:text>
        <span class="label">Kommentarer: </span><xsl:text>
            </xsl:text></td><td>
    <xsl:text>
    </xsl:text>
        <xsl:value-of select="n1:Notes"/>
        </td>
        </tr>
    		</xsl:when>
    		<xsl:otherwise>
        <tr><td>
    <xsl:text>
    </xsl:text>
        <span class="label">Kommentarer: </span><xsl:text>
            </xsl:text></td><td>
    <xsl:text>
    </xsl:text>
        <xsl:value-of select="n1:Notes"/>
        </td>
        </tr>
    		</xsl:otherwise>
    	</xsl:choose>
    </xsl:if>
    <xsl:text>
    </xsl:text>
    
    <xsl:if test="string(n1:Result/n1:TaxonIdentified/n1:InformalNameString)">
    	<xsl:choose>
    		<xsl:when test="n1:PreferredFlag = '1' or n1:PreferredFlag='true'">
        <tr class="prefered"><td>
    <xsl:text>
    </xsl:text>
        <span class="label">Trivialnavn: </span><xsl:text>
            </xsl:text></td><td>
    <xsl:text>
    </xsl:text>
        <xsl:value-of select="n1:Result/n1:TaxonIdentified/n1:InformalNameString"/> <xsl:if test="@language" >(<xsl:value-of select="@Language"/>)</xsl:if>
    <xsl:text>
    </xsl:text>
        </td>
        </tr>
    		</xsl:when>
    		<xsl:otherwise>
        <tr><td>
    <xsl:text>
    </xsl:text>
        <span class="label">Trivialnavn: </span><xsl:text>
            </xsl:text></td><td>
    <xsl:text>
    </xsl:text>
        <xsl:value-of select="n1:Result/n1:TaxonIdentified/n1:InformalNameString"/> <xsl:if test="@language" >(<xsl:value-of select="@Language"/>)</xsl:if>
    <xsl:text>
    </xsl:text>
        </td>
        </tr>
    		</xsl:otherwise>
    	</xsl:choose>
    </xsl:if>
    <xsl:text>
    </xsl:text>

    <tr><td>
    <xsl:text>
    </xsl:text>&#160; </td><td>
    <xsl:text>
    </xsl:text> &#160;</td></tr>
    		</xsl:for-each>
    	</table>
    	 <xsl:text>
    </xsl:text>
    	<!-- *********************************IDENTIFICATIONS ************************************** 	-->
    	<!-- ********************************* Extension ************************************** 	-->
    	<xsl:if test="n1:Identifications/n1:Identification/n1:Result/n1:Extension">
    		<xsl:call-template name="efgExtension" />	
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	<!-- *********************************Extension ************************************** 	-->
    	<!-- ********************************** Identifiers Details ******************************** -->
    	<xsl:if test="n1:Identifications/n1:Identification/n1:Identifiers/n1:Identifier/n1:Organisation or
        	n1:Identifications/n1:Identification/n1:Identifiers/n1:IdentifiersText or
        	n1:Identifications/n1:Identification/n1:Identifiers/n1:IdentificationSource or
        	n1:Identifications/n1:Identification/n1:Identifiers/n1:IdentifierRole">
    		<h3 class="background 3">Detaljer om objektbestemmer</h3>
    		<xsl:for-each select="n1:Identifications/n1:Identification/n1:Identifiers/n1:Identifier">
        <xsl:if test="n1:PersonName">
        	<xsl:if test="n1:PersonName/n1:FullName">
        		<span class="label">BestemmerName: </span>
        		<xsl:value-of select="n1:PersonName/n1:FullName"/>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<br/>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <xsl:if test="n1:Organisation">
        	<xsl:if test="n1:Organisation/n1:Name">
        		<span class="label">Bestemmerens organisasjon: </span>
        		<xsl:value-of select="n1:Organisation/n1:Name"/>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<br/>
        	<xsl:if test="n1:Organisation/n1:OrgUnits">
        	<span class="label">Bestemmerens organisasjonOrgUnits: </span>
        	<xsl:for-each select="n1:Organisation/n1:OrgUnits/n1:OrgUnit">
        		<xsl:value-of select="."/>
        		</xsl:for-each>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<br/>
        </xsl:if>
    <xsl:text>
    </xsl:text>
    		</xsl:for-each>
    		<xsl:if test="n1:Identifications/n1:Identification/n1:Identifiers/n1:IdentifiersText">
        	<span class="label">Tekst: </span>
        	<xsl:value-of select="n1:Identifications/n1:Identification/n1:Identifiers/n1:IdentifiersText"/>
        	<br/>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <xsl:if test="n1:Identifications/n1:Identification/n1:Identifiers/n1:IdentificationSource">
        	<span class="label">Referanse til bestemmer: </span>
        	<xsl:for-each select="n1:Identifications/n1:Identification/n1:Identifiers/n1:IdentificationSource">
        		<xsl:call-template name="reference">
        		</xsl:call-template>
        	</xsl:for-each>
        	<br/>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <xsl:if test="n1:Identifications/n1:Identification/n1:Identifiers/n1:IdentifierRole">
        	<span class="label">Funksjon: </span>
        	<xsl:value-of select="n1:Identifications/n1:Identification/n1:Identifiers/n1:IdentifierRole"/>
        	<br/>
        </xsl:if>
    <xsl:text>
    </xsl:text>
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	<!-- ********************************** Identifiers Details ******************************** -->
    	<!-- ****************************** Unit Refrences ************** -->
    	<xsl:if test="n1:SourceReference or n1:UnitReferences">
    		<h3 class="background 4">Objektsreferans(er)</h3>
    		<xsl:if test="n1:SourceReference">
        <span style="label">Kildereferanse: </span>
        <xsl:for-each select="n1:SourceReference">
        	<xsl:call-template name="reference">
        	</xsl:call-template>
        </xsl:for-each>
        <br/>
    		</xsl:if>
    <xsl:text>
    </xsl:text>
    		<xsl:if test="n1:UnitReferences">
        <span style="label">Objektsreferans(er): </span>
        <xsl:for-each select="n1:UnitReferences/n1:UnitReference">
        	<xsl:call-template name="reference">
        	</xsl:call-template>
        </xsl:for-each>
        <br/>
    		</xsl:if>
    <xsl:text>
    </xsl:text>
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	<!-- ****************************** Unit Refrences ************** -->
    	<!-- ************************ Record Owner **************** -->
    	<xsl:if test="n1:Owner">
    		<h3 class="background 5">Objektseier</h3>
    		<xsl:for-each select="n1:Owner">
        <xsl:call-template name="owner">
        </xsl:call-template>
    		</xsl:for-each>
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	<!-- ************************ Record Owner **************** -->
    	<!-- ************************ IPR for Unit ****************-->
    	<xsl:if test="n1:IPRStatements">
    		<h3 class="background 6">Rettighet til objekt</h3>
    		<xsl:for-each select="n1:IPRStatements">
        <xsl:text>
 </xsl:text><xsl:call-template name="myRightsTable"/><xsl:text>
 </xsl:text>
    		</xsl:for-each>
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	<!-- ************************ IPR for Unit ****************-->
    	<!-- ************************ Unit Content Contacts ****************-->
    	<xsl:if test="n1:UnitContentContacts">
    		<h3 class="background 7">Kontaktperson(er) for objektsinnhold</h3>
    		<xsl:for-each select="n1:UnitContentContacts/n1:UnitContentContact">
        <xsl:call-template name="owner">
        </xsl:call-template>
    		</xsl:for-each>
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	<!-- ************************ Unit Content Contacts ****************-->
    	<!-- ************************ Multimedia Objects ****************-->
    	<xsl:if test="n1:MultiMediaObjects">
    		<h3 class="background 8">LB_MultimediaObjects</h3>
    		<table border="1" cellpadding="5" cellspacing="5" width="96%">
        <tbody>
        	<xsl:for-each select="n1:MultiMediaObjects/n1:MultiMediaObject">
        		<tr valign="top" >
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:if test="n1:ID">
            		<span class="label">Digitalbilde ID: </span>
            		<xsl:value-of select="n1:ID"/>
            		<xsl:text>   </xsl:text>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            		
            	<xsl:if test="n1:FileURI">
            		<xsl:choose>
                <xsl:when test="substring(n1:FileURI,1,7)='http://' or substring(.,1,8)='https://'">
                	<xsl:if test="string-length(n1:FileURI) &gt;5 and (substring(n1:FileURI,string-length(n1:FileURI)-3,4)='mpeg' or substring(n1:FileURI,string-length(n1:FileURI)-2,3)='mpg')">
                	<embed   src="{n1:FileURI}" name="video"  palette="background"  align="left"  border="0"   width="320"   height="290"  loop="false"  autostart="true"  title="video comes here"  controls="smallconsole"  type="video/mpeg"></embed><br/>
                	<div class="clearer"/>
                	</xsl:if>
    <xsl:text>
    </xsl:text>
                	<a href="{n1:FileURI}" target ="_blank"><xsl:if test="not(string-length(n1:FileURI) &gt;5 and (substring(n1:FileURI,string-length(n1:FileURI)-3,4)='mpeg' or substring(n1:FileURI,string-length(n1:FileURI)-2,3)='mpg'))">
                	<xsl:if test="not(n1:Format='fpx')">
                	<img src="{n1:FileURI}" width='120px'/>
                	</xsl:if>
    <xsl:text>
    </xsl:text>
                	</xsl:if>
    <xsl:text>
    </xsl:text>
                	<br/>
                	<xsl:if test="string-length(n1:FileURI)>80">
                		<xsl:value-of select="substring(n1:FileURI,1,40)"/>...<xsl:value-of select="substring(n1:FileURI,60)"/>
                	</xsl:if>
    <xsl:text>
    </xsl:text>
                	<xsl:if test="not(string-length(n1:FileURI)>80)">
                		<xsl:value-of select="n1:FileURI"/>
                	</xsl:if>
    <xsl:text>
    </xsl:text>
                	<xsl:if test="n1:Format='fpx'">
                	<b> (high quality) </b>
                	</xsl:if>
    <xsl:text>
    </xsl:text>
                </a>
                    <!--
                    <a target="_blank">
                    	<xsl:attribute name="href">
                    		<xsl:value-of select="n1:FileURI"/>
                    	</xsl:attribute>
                    </a>
                    -->
                	</xsl:when>
                	<xsl:otherwise>
                		<xsl:value-of select="n1:FileURI" disable-output-escaping="yes"/>
                	</xsl:otherwise>
                </xsl:choose>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	
            	<xsl:if test="string(n1:ProductURI)">
            		<br/>
            		<span class="label">Produkt-URI: </span>
            		<xsl:value-of select="n1:ProductURI"/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	<xsl:if test="string(n1:Context)">
            		<br/>
            		<span class="label">Sammenheng: </span>
            		<xsl:value-of select="n1:Context"/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	<xsl:if test="string(n1:Format)">
            		<br/>
            		<span class="label">Format: </span>
            		<xsl:value-of select="n1:Format"/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	<xsl:if test="string(n1:ImageSize/n1:Width)">
            		<xsl:text>   </xsl:text>
            		<span class="label">St\ufffdrrelse: </span>
            		<xsl:value-of select="n1:ImageSize/n1:Width"/>
            		<xsl:text>x</xsl:text>
            		<xsl:value-of select="n1:ImageSize/n1:Height"/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	<xsl:if test="string(n1:ImageResolution)">
            		<xsl:text>   </xsl:text>
            		<span class="label">Oppl\ufffdsning: </span>
            		<xsl:value-of select="n1:ImageResolution"/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	<xsl:if test="string(n1:FileSize)">
            		<xsl:text>   </xsl:text>
            		<span class="label">Filst�rrelse: </span>
            		<xsl:value-of select="n1:FileSize"/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	<!--<xsl:text>
            </xsl:text>
 </ul>
            <xsl:text>
            </xsl:text>-->
        		</td>
        		</tr>
        		</xsl:for-each>
        		
        	
        		<xsl:for-each select="n1:MultiMediaObjects/n1:MultiMediaObject/n1:IPR">
            <xsl:text>
 </xsl:text><xsl:call-template name="myRightsTable"/><xsl:text>
 </xsl:text>
        		</xsl:for-each>
        		
        	</tbody>
        </table>
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	<!-- ************************ Multimedia Objects ****************-->
    	<!-- *********************************GATHERING ************************************** 	-->
    	<xsl:if test="string(n1:Gathering)">
    		<h3 class="background 9">Innsamling</h3>
    		<table width="96%">
        <tr>
        	<xsl:if test="string(n1:Gathering/n1:Code)">
        		<th>Kode:
        		<xsl:value-of select="n1:Gathering/n1:Code"/>
        		</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="string(n1:Gathering/n1:Method)">
        		<th>Metode :
            <xsl:value-of select="n1:Gathering/n1:Method"/>
        		</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        </tr>
        <tr>
        	<xsl:if test="string(n1:Gathering/n1:LocalityText)!='' or string(n1:Gathering/n1:Country)!=''">
        		<th>Lokalitet </th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="string(n1:Gathering/n1:Agents)">
        		<th>Innsamler </th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="string(n1:Gathering/n1:Altitude) or string(n1:Gathering/n1:Depth) or string(n1:Gathering/n1:Height) or string(n1:Gathering/n1:SiteMeasurementsOrFacts) or string(n1:Gathering/n1:Biotope) or string(n1:Gathering/n1:DateTime)">
        	<th>Annen informasjon </th></xsl:if>
    <xsl:text>
    </xsl:text>
        </tr>
        <tr valign="top">
        	<xsl:if test="string(n1:Gathering)">
        	<td>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="string(n1:Gathering/n1:Country)">
            <span class="label">Land: </span>
            	<xsl:value-of select="n1:Gathering/n1:Country/n1:Name"/> 
            	<xsl:if test="string(n1:Gathering/n1:Country/n1:ISO3166Code)"> 
            	(<xsl:value-of select="n1:Gathering/n1:Country/n1:ISO3166Code"/>)
            </xsl:if>
    <xsl:text>
    </xsl:text> 
            <br/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="string(n1:Gathering/n1:NamedAreas)">
            <xsl:for-each select="n1:Gathering/n1:NamedAreas/n1:NamedArea">
            	<xsl:choose>
            		<xsl:when test="n1:AreaClass">
                <span class="label"><xsl:value-of select="n1:AreaClass"/>: </span>
            		</xsl:when>
            		<xsl:otherwise><span class="label">Region: </span></xsl:otherwise>
            	</xsl:choose>
            	<xsl:value-of select="n1:AreaName"/>
            	<xsl:if test="n1:AreaCodeStandard">
            		<xsl:value-of select="n1:AreaCodeStandard"/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	<xsl:if test="n1:AreaCode">
            		<xsl:value-of select="n1:AreaCode"/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	<xsl:if test="n1:DataSource">
            		<xsl:value-of select="n1:DataSource"/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	<br/>
            </xsl:for-each>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="string(n1:Gathering/n1:LocalityText)">
            <span class="label">Lokalitet: </span>
            <xsl:value-of select="n1:Gathering/n1:LocalityText"/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:Gathering/n1:SiteCoordinateSets">
            <br/>
            <form xml:space="default" action="http://linuxgurrl.agr.gc.ca/mapdata/itis/itisrosa.php" method="POST" target="_blank" name ="form{$UnitID}">
                <input><xsl:attribute name="value">%3C%3Fxml+version%3D%271.0%27+encoding%3D%27iso-8859-1%27%3F%3E%3Cresponse%3E%3Cheader%3E%3Cauthor%3E%3C%2Fauthor%3E%3Cboundingbox%3E-180%2C-90%2C180%2C90%2CWorld%3C%2Fboundingbox%3E%3Cdescription%3EThis+Generic+Point+Mapper+is+a+service+provided+by+the+Canadian+Biological+Information+Facility%3C%2Fdescription%3E%3Cifx%3E%3C%2Fifx%3E%3Clanguage%3Een%3C%2Flanguage%3E%3Cprojection%3Elatlong%3C%2Fprojection%3E%3Crecordcount%3E%3C%2Frecordcount%3E%3Ctimestamp%3E2004-11-30+11%3A10%3A58.043%3C%2Ftimestamp%3E%3Ctitle%3ESimple+access+to+ABCD+providers+-+Point+Location+Data%3C%2Ftitle%3E%3Curl%3Ehttp%3A%2F%2Fwww.cbif.gc.ca%2Fmc%2Findex_e.php%3C%2Furl%3E%3C%2Fheader%3E%3Crecords<xsl:for-each select="n1:Gathering/n1:SiteCoordinateSets/n1:SiteCoordinates">%3E%3Crecord<xsl:for-each select="n1:CoordinatesLatLong"><xsl:for-each select="n1:LatitudeDecimal">%3E%3Clatitude%3E<xsl:apply-templates/>%3C%2Flatitude</xsl:for-each><xsl:for-each select="n1:LongitudeDecimal">%3E%3Clongitude%3E<xsl:apply-templates/>%3C%2Flongitude</xsl:for-each></xsl:for-each>%3E%3Crecordurl%3E%3C%2Frecordurl%3E%3C%2Frecord</xsl:for-each>%3E%3C%2Frecords%3E%3C%2Fresponse%3E</xsl:attribute><xsl:attribute name="type">hidden</xsl:attribute><xsl:attribute name="name">xml</xsl:attribute></input>
            	<span class="label">Koordinater (Lat|Lon)<xsl:if test="n1:Gathering/n1:SiteCoordinateSets/n1:SiteCoordinates/n1:CoordinateMethod">(<xsl:value-of select="n1:Gathering/n1:SiteCoordinateSets/n1:SiteCoordinates/n1:CoordinateMethod"/>)</xsl:if>: </span> 
            	<xsl:value-of select="n1:Gathering/n1:SiteCoordinateSets/n1:SiteCoordinates/n1:CoordinatesLatLong/n1:LatitudeDecimal"/>, <xsl:value-of select="n1:Gathering/n1:SiteCoordinateSets/n1:SiteCoordinates/n1:CoordinatesLatLong/n1:LongitudeDecimal"/> <a href="Javascript:document.form{$UnitID}.submit();"  > Map!</a>
            </form>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
            	<!-- /For to create a map-->
            	<xsl:if test="LongitudeDecimal/text()">
            		<br/>
            		<form xml:space="default" action="http://linuxgurrl.agr.gc.ca/mapdata/itis/itisrosa.php" method="POST" target="_blank">
                <xsl:attribute name="name">GeneralMap</xsl:attribute>
                    <input><xsl:attribute name="value">%3C%3Fxml+version%3D%271.0%27+encoding%3D%27iso-8859-1%27%3F%3E%3Cresponse%3E%3Cheader%3E%3Cauthor%3E%3C%2Fauthor%3E%3Cboundingbox%3E-180%2C-90%2C180%2C90%2CWorld%3C%2Fboundingbox%3E%3Cdescription%3EThis+Generic+Point+Mapper+is+a+service+provided+by+the+Canadian+Biological+Information+Facility%3C%2Fdescription%3E%3Cifx%3E%3C%2Fifx%3E%3Clanguage%3Een%3C%2Flanguage%3E%3Cprojection%3Elatlong%3C%2Fprojection%3E%3Crecordcount%3E%3C%2Frecordcount%3E%3Ctimestamp%3E2004-11-30+11%3A10%3A58.043%3C%2Ftimestamp%3E%3Ctitle%3ESimple+access+to+ABCD+providers+-+Point+Location+Data%3C%2Ftitle%3E%3Curl%3Ehttp%3A%2F%2Fwww.cbif.gc.ca%2Fmc%2Findex_e.php%3C%2Furl%3E%3C%2Fheader%3E%3Crecords%3E%3Crecord<xsl:for-each select="LongitudeDecimal">%3E%3Clatitude%3E<xsl:apply-templates/>%3C%2Flatitude</xsl:for-each><xsl:for-each select="dwc:DecimalLongitude">%3E%3Clongitude%3E<xsl:apply-templates/>%3C%2Flongitude</xsl:for-each>%3E%3Crecordurl%3E%3C%2Frecordurl%3E%3C%2Frecord%3E%3C%2Frecords%3E%3C%2Fresponse%3E</xsl:attribute><xsl:attribute name="type">hidden</xsl:attribute><xsl:attribute name="name">xml</xsl:attribute></input>
                Coordinates (Lat|Lon): : <xsl:value-of select="LongitudeDecimal"/>|<xsl:value-of select="dwc:DecimalLongitude"/>  <a href="Javascript:document.GeneralMap.submit()"> Map!</a>
            		</form>
            	</xsl:if>
    <xsl:text>
    </xsl:text>

        	</td>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:Gathering/n1:Agents">
        		<td>
    <xsl:text>
    </xsl:text>
            <xsl:for-each select="n1:Gathering/n1:Agents/n1:GatheringAgent">
<xsl:value-of select="n1:Person/n1:FullName"/>
            	<br/>
            </xsl:for-each>
            <xsl:for-each select="n1:Gathering/n1:Agents/n1:GatheringAgentsText">
            	<xsl:apply-templates/>
            	<br/>
            </xsl:for-each>
             <xsl:text>
    </xsl:text>
        		</td>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<td>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="string(n1:Gathering/n1:Altitude) or string(n1:Gathering/n1:Depth) or string(n1:Gathering/n1:Height) or string(n1:Gathering/n1:SiteMeasurementsOrFacts) or string(n1:Gathering/n1:Biotope) or string(n1:Gathering/n1:DateTime)">
            <xsl:if test="string(n1:Gathering/n1:Altitude/n1:MeasurementOrFactAtomised)">
            	<xsl:for-each select="n1:Gathering/n1:Altitude/n1:MeasurementOrFactAtomised">
            		<xsl:call-template name="measurementatomised">
                <xsl:with-param name="label">
                	H�yde over havet
                </xsl:with-param>
            		</xsl:call-template>
            	</xsl:for-each>
            	<xsl:if test="string(n1:Gathering/n1:Altitude/n1:MeasurementOrFactText)">
            		<span class="label"> H�yde over havet: </span>
            		<xsl:value-of select="string(n1:Gathering/n1:Altitude/n1:MeasurementOrFactText)"/>
            		<br/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	
            </xsl:if>
    <xsl:text>
    </xsl:text>	
        		  <xsl:if test="string(n1:Gathering/n1:Depth)">
            	<xsl:if test="string(n1:Gathering/n1:Depth/n1:MeasurementOrFactAtomised)">
            		<xsl:for-each select="n1:Gathering/n1:Depth/n1:MeasurementOrFactAtomised">
                <xsl:call-template name="measurementatomised">
                	<xsl:with-param name="label">
                		Dyp
                	</xsl:with-param>
                </xsl:call-template>
            		</xsl:for-each>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	<xsl:if test="string(n1:Gathering/n1:Depth/n1:MeasurementOrFactText)">
            		<span class="label"> Dyp: </span>
            		<xsl:value-of select="string(n1:Gathering/n1:Depth/n1:MeasurementOrFactText)"/>
            		<br/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            </xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="string(n1:Gathering/n1:Height)">
            <xsl:if test="string(n1:Gathering/n1:Height/n1:MeasurementOrFactAtomised)">
            	<xsl:for-each select="n1:Gathering/n1:Height/n1:MeasurementOrFactAtomised">
            		<xsl:call-template name="measurementatomised">
                <xsl:with-param name="label">
                	H�yde
                </xsl:with-param>
            		</xsl:call-template>
            	</xsl:for-each>
            </xsl:if>
    <xsl:text>
    </xsl:text>
            <xsl:if test="string(n1:Gathering/n1:Height/n1:MeasurementOrFactText)">
            		<span class="label"> H�yde: </span>
            		<xsl:value-of select="string(n1:Gathering/n1:Height/n1:MeasurementOrFactText)"/>
            		<br/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="string(n1:Gathering/n1:SiteMeasurementsOrFacts)">
            <xsl:for-each select="n1:Gathering/n1:SiteMeasurementsOrFacts/n1:SiteMeasurementOrFact">
            <xsl:if test="string(n1:MeasurementOrFactAtomised)">
            	<xsl:for-each select="n1:MeasurementOrFactAtomised">
            		<xsl:call-template name="measurementatomised">
                <xsl:with-param name="label">
                	M�linger p� (innsamlings)stedet
                </xsl:with-param>
            		</xsl:call-template>
            	</xsl:for-each>
            </xsl:if>
    <xsl:text>
    </xsl:text>
            </xsl:for-each>
        		</xsl:if>
    <xsl:text>
    </xsl:text>	
        		
        		<xsl:if test="string(n1:Gathering/n1:Biotope/n1:Text)">
            <span class="label">Biotop: </span>
            <xsl:value-of select="n1:Gathering/n1:Biotope/n1:Text"/><br/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="string(n1:Gathering/n1:DateTime)">
            <span class="label">Dato: </span>
             <br/><xsl:if test="string(n1:Gathering/n1:DateTime/n1:DateText)">DateText: <xsl:value-of select="n1:Gathering/n1:DateTime/n1:DateText"/><br/></xsl:if><xsl:text>
 </xsl:text>
            <xsl:if test="string(n1:Gathering/n1:DateTime/n1:ISODateTimeBegin)">DateTimeBegin: <xsl:value-of select="n1:Gathering/n1:DateTime/n1:ISODateTimeBegin"/><br/></xsl:if><xsl:text>
 </xsl:text>
            <xsl:if test="string(n1:Gathering/n1:DateTime/n1:ISODateTimeEnd)">DateTimeEnd: <xsl:value-of select="n1:Gathering/n1:DateTime/n1:ISODateTimeEnd"/><br/></xsl:if><xsl:text>
 </xsl:text>

        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="string(n1:Gathering/n1:Project/n1:ProjectTitle)">
            <span class="label">Prosjekt: </span>
            <xsl:value-of select="n1:Gathering/n1:Project/n1:ProjectTitle"/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="string(n1:Gathering/n1:Notes)"><br/>
            <span class="label">Notes: </span>
            <xsl:value-of select="n1:Gathering/n1:Notes"/><br/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>	
        	</td>
        </tr>
        <br/>
    		</table>
    		<table border="1" cellpadding="5" cellspacing="5" width="96%">
        <tr>
        	<xsl:if test="n1:Gathering/n1:Synecology/n1:Syntaxon">
        		<th>LB_Syntaxon</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	  <xsl:if test="n1:Gathering/n1:Synecology/n1:AssociatedTaxa ">
        		<th>LB_AssociatedTaxa</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	  <xsl:if test="n1:Gathering/n1:Synecology/n1:Comment ">
        		<th>LB_SynecologyComent</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        </tr>
        <tr>
        	<xsl:if test="n1:Gathering/n1:Synecology/n1:Syntaxon">
        		<td>
    <xsl:text>
    </xsl:text><xsl:value-of select="n1:Gathering/n1:Synecology/n1:Syntaxon"></xsl:value-of>
        		</td>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	  <xsl:if test="n1:Gathering/n1:Synecology/n1:AssociatedTaxa">
        		<td>
    <xsl:text>
    </xsl:text><xsl:value-of select="n1:Gathering/n1:Synecology/n1:AssociatedTaxa"></xsl:value-of>
        		</td>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	  <xsl:if test="n1:Gathering/n1:Synecology/n1:Comment">
        		<td>
    <xsl:text>
    </xsl:text><xsl:value-of select="n1:Gathering/n1:Synecology/n1:Comment"></xsl:value-of>
        		</td>
        	</xsl:if>
    <xsl:text>
    </xsl:text> 
        </tr>
    		</table>
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	<!-- *********************************GATHERING ************************************** 	-->
    	
    	<xsl:if test="string(n1:Gathering/n1:SiteImages)">
    		<h3 class="background a">  InnsamlingDigitalImages</h3>
    		<table border="1" cellpadding="5" cellspacing="5" width="96%">
        <tbody>
        	<xsl:for-each select="n1:Gathering/n1:SiteImages/n1:SiteImage">
        		<tr valign="top" >
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:if test="n1:ID">
            		<span class="label">Digitalbilde ID: </span>
            		<xsl:value-of select="n1:ID"/>
            		<xsl:text>   </xsl:text>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            		
            	<xsl:if test="n1:FileURI">
            		<xsl:choose>
                <xsl:when test="substring(n1:FileURI,1,7)='http://' or substring(.,1,8)='https://'">
                	<xsl:if test="string-length(n1:FileURI) &gt;5 and (substring(n1:FileURI,string-length(n1:FileURI)-3,4)='mpeg' or substring(n1:FileURI,string-length(n1:FileURI)-2,3)='mpg')">
                	<embed   src="{n1:FileURI}" name="video"  palette="background"  align="left"  border="0"   width="320"   height="290"  loop="false"  autostart="true"  title="video comes here"  controls="smallconsole"  type="video/mpeg"></embed><br/>
                	<div class="clearer"/>
                	</xsl:if>
    <xsl:text>
    </xsl:text>
                	<a href="{n1:FileURI}" target ="_blank"><xsl:if test="not(string-length(n1:FileURI) &gt;5 and (substring(n1:FileURI,string-length(n1:FileURI)-3,4)='mpeg' or substring(n1:FileURI,string-length(n1:FileURI)-2,3)='mpg'))">
                	<xsl:if test="not(n1:Format='fpx')">
                	<img src="{n1:FileURI}" width='120px'/>
                	</xsl:if>
    <xsl:text>
    </xsl:text>
                	</xsl:if>
    <xsl:text>
    </xsl:text>
                	<br/>
                	<xsl:if test="string-length(n1:FileURI)>80">
                		<xsl:value-of select="substring(n1:FileURI,1,40)"/>...<xsl:value-of select="substring(n1:FileURI,60)"/>
                	</xsl:if>
    <xsl:text>
    </xsl:text>
                	<xsl:if test="not(string-length(n1:FileURI)>80)">
                		<xsl:value-of select="n1:FileURI"/>
                	</xsl:if>
    <xsl:text>
    </xsl:text>
                </a>
                    <!--
                    <a target="_blank">
                    	<xsl:attribute name="href">
                    		<xsl:value-of select="n1:FileURI"/>
                    	</xsl:attribute>
                    </a>
                    -->
                	</xsl:when>
                	<xsl:otherwise>
                		<xsl:value-of select="n1:FileURI" disable-output-escaping="yes"/>
                	</xsl:otherwise>
                </xsl:choose>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	
            	<xsl:if test="string(n1:ProductURI)">
            		<br/>
            		<span class="label">Produkt-URI: </span>
            		<xsl:value-of select="n1:ProductURI"/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	<xsl:if test="string(n1:Context)">
            		<br/>
            		<span class="label">Sammenheng: </span>
            		<xsl:value-of select="n1:Context"/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	<xsl:if test="string(n1:Format)">
            		<br/>
            		<span class="label">Format: </span>
            		<xsl:value-of select="n1:Format"/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	<xsl:if test="string(n1:ImageSize/n1:Width)">
            		<xsl:text>   </xsl:text>
            		<span class="label">St�rrelse: </span>
            		<xsl:value-of select="n1:ImageSize/n1:Width"/>
            		<xsl:text>x</xsl:text>
            		<xsl:value-of select="n1:ImageSize/n1:Height"/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	<xsl:if test="string(n1:ImageResolution)">
            		<xsl:text>   </xsl:text>
            		<span class="label">Oppl�sning: </span>
            		<xsl:value-of select="n1:ImageResolution"/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	<xsl:if test="string(n1:FileSize)">
            		<xsl:text>   </xsl:text>
            		<span class="label">Filst�rrelse: </span>
            		<xsl:value-of select="n1:FileSize"/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            	<!--<xsl:text>
            </xsl:text>
 </ul>
            <xsl:text>
            </xsl:text>-->
        		</td>
        		</tr>
        		</xsl:for-each>
        		
        	
        		<xsl:for-each select="n1:Gathering/n1:SiteImages/n1:SiteImage/n1:IPR">
            <xsl:text>
 </xsl:text><xsl:call-template name="myRightsTable"/><xsl:text>
 </xsl:text>
        		</xsl:for-each>
        		
        	</tbody>
        </table>	
        
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	
    	<!-- Aspect -->        
    	<xsl:if test="string(n1:Gathering/n1:Aspect)">
    		<h3 class="background b">Aspekter av/Retning p� objektsdetaljer for eksemplarer</h3>
    		<strong>Aspekt/Retning </strong>
    		<xsl:for-each select="n1:Gathering/n1:Aspect">
        <xsl:if test="string(n1:Ordination)">
        	<strong>Ordinasjon: </strong>
        	<xsl:value-of select="n1:Ordination"/>
        	<xsl:text> </xsl:text>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <xsl:if test="string(n1:CompassBearing)">
        	<strong>Kompasskurs: </strong>
        	<xsl:value-of select="n1:CompassBearing"/>
        	<xsl:text> </xsl:text>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <xsl:if test="string(n1:Accuracy)">
        	<strong>N�yaktighet: </strong>
        	<xsl:value-of select="n1:Accuracy"/>
        	<xsl:text> </xsl:text>            	
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <!-- freetext description (AspectText) should probably rather be 
        	included as an alternative to the above!
        -->		
        <xsl:if test="string(n1:AspectText)">
        	<strong>Beskrivelse: </strong>
        	<xsl:value-of select="n1:AspectText"/>
        </xsl:if>
    <xsl:text>
    </xsl:text>
    		</xsl:for-each>	
    		<br/>
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	<!-- /Aspect -->
    	
    	<!-- *********************************Specimen Details ************************************** 	-->
    	<xsl:if test="string(n1:SpecimenUnit)">
    		<xsl:for-each select="n1:SpecimenUnit">
    		<xsl:if test="string(n1:Acquisition) or string(n1:Preparations) or string(n1:Accessions)">

    		<div>
        <h3 class="background c">Objektsdetaljer for beleggeksemplar</h3>
        <table width="96%" border="0">
        	
        		<xsl:text>
    </xsl:text>	
        		<xsl:if test="n1:Acquisition">
            <th>Dato for ervervelse</th>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		
        		<xsl:if test="n1:Acquisition/n1:AcquisitionType">
            <th>Type av ervervelse</th>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:Accessions/n1:AccessionNumber">
            <th>Aksesjonsnummer</th>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:Accessions/n1:AccessionCatalogue">
            <th>Aksesjonskatalog</th>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:Preparations/n1:Preparation/n1:PreparationType">
            <th >LB_PreparationType</th>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:Preparations/n1:Preparation/n1:PreparationProcess">
            <th>LB_PreparationProcess</th>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:Preparations/n1:Preparation/n1:PreparationMaterials">
            <th>LB_PreparationMaterials</th>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:Preparations/n1:Preparation/n1:PreparationAgent">
            <th>LB_PreparationAgent</th>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        
        	<tr>
        		
        		    <xsl:if test="n1:Acquisition/n1:AcquisitionDate">
        		    <td>
    <xsl:text>
    </xsl:text>
             <xsl:value-of select="n1:Acquisition/n1:AcquisitionDate"/>
               <xsl:text>
    </xsl:text>
              </td>
            </xsl:if>
    <xsl:text>
    </xsl:text>
        		
        		<xsl:if test="n1:Acquisition/n1:AcquisitionType">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:value-of select="n1:Acquisition/n1:AcquisitionType"/>
            	<xsl:text>
    </xsl:text>
            </td>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:Accessions/n1:AccessionNumber">
        		<td>
    <xsl:text>
    </xsl:text>
            <xsl:for-each select="n1:Accessions/n1:AccessionNumber">
            	<xsl:value-of select="."/><br/>
            </xsl:for-each>
             <xsl:text>
    </xsl:text>
        		</td>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:Accessions/n1:AccessionCatalogue">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:for-each select="n1:Accessions/n1:AccessionCatalogue">
            		<xsl:value-of select="."/><br/>
            	</xsl:for-each>
            </td>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:Preparations/n1:Preparation/n1:PreparationType">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:for-each select="n1:Preparations/n1:Preparation/n1:PreparationType">
            		<xsl:value-of select="."/><br/>
            	</xsl:for-each>
            </td>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:Preparations/n1:Preparation/n1:PreparationProcess">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:for-each select="n1:Preparations/n1:Preparation/n1:PreparationProcess">
            		<xsl:value-of select="."/><br/>
            	</xsl:for-each>
            </td>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:Preparations/n1:Preparation/n1:PreparationMaterials">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:for-each select="n1:Preparations/n1:Preparation/n1:PreparationMaterials">
            		<xsl:value-of select="."/><br/>
            	</xsl:for-each>
            </td>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:Preparations/n1:Preparation/n1:PreparationAgent">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:for-each select="n1:Preparations/n1:Preparation/n1:PreparationAgent">
            		<xsl:value-of select="."/><br/>
            	</xsl:for-each>
            </td>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        	</tr>
        
        <tr>
        	<xsl:if test="n1:Owner">
        	<td>
    <xsl:text>
    </xsl:text>
        	<span class="label">Owner: </span>
        	<xsl:for-each select="n1:Owner">
        		<xsl:call-template name="owner"></xsl:call-template>
        	</xsl:for-each>
        	</td>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        
        <xsl:if test="n1:NomenclaturalTypeDesignations">
        	<td>
    <xsl:text>
    </xsl:text>
        	<xsl:call-template name="reference"></xsl:call-template>
        	</td>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        </tr>	
        </table>
        
        
        
    		</div>
    		</xsl:if>
    <xsl:text>
    </xsl:text>
    	</xsl:for-each>
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	<!-- *********************************Specimen Details ************************************** 	-->
    	<xsl:if test="n1:UnitExtension">
    		<xsl:for-each select="n1:UnitExtension">
        <!-- <xsl:call-template name="efgExtension_Unit" />  -->
        <xsl:call-template name="efgExtension_Unit_nopref" />
    		</xsl:for-each>	
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	<!-- ********************************* PlantGeneticResourcesUnit************************************** 	-->
    	<p>
    		
    		<xsl:for-each select="n1:PlantGeneticResourcesUnit">
        <h3 class="background d">Objektsdetaljer for plantegenetiske ressurser</h3>
    		<!--
    		AncestralData 0/1 cmpl-type [StringL]
    		language [optional]
    		-->
        <span class="label">Objektsdetaljer for plantegenetiske ressurser</span>
    		<table width="96%" border="0">
        <xsl:if test="n1:NationalInventoryCode">
        	<tr>
        		<td>
            <span class="label">Nasjonal inventeringskode: </span>
        		<xsl:value-of select="n1:NationalInventoryCode"/><br/>
        		</td>
        	</tr>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <xsl:if test="n1:BreedingInstitutionCode">
        	<tr>
        		<td>
            <span class="label">Kode for avlsinstitusjon: </span>
            <xsl:value-of select="n1:BreedingInstitutionCode"/><br/>
        		</td>
        	</tr>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <xsl:if test="n1:BreedingCountryCode">
        	<tr>
        		<td>
            <span class="label">Kode for avlsland: </span>
            <xsl:value-of select="n1:BreedingCountryCode"/><br/>
        		</td>
        	</tr>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <xsl:if test="n1:BiologicalStatus">
        	<tr>
        		<td>
            <span class="label">Biologisk ilde for innsamlingservervelse: </span>
            <xsl:value-of select="n1:BiologicalStatus"/><br/>
        		</td>
        		
        	</tr>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <xsl:if test="n1:CollectingAcquisitionSource">
        	<tr>
        		<td>
            <span class="label">LB_CollectingAcquisitionSource: </span>
            <xsl:value-of select="n1:CollectingAcquisitionSource"/><br/>
        		</td>
        	</tr>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        
        <xsl:if test="n1:OtherIdentification">
        	<tr>
        		<td>
            <span class="label">Annen bestemming: </span>
            <xsl:value-of select="n1:OtherIdentification"/><br/>
        		</td>
        	</tr>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <xsl:if test="n1:LocationSafetyDuplicates">
        	<tr>
        		<td>
            <span class="label">Oppbevaringsplass for sikkerhetskopier: </span>
            <xsl:value-of select="n1:LocationSafetyDuplicates"/><br/>
        		</td>
        	</tr>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        
        <xsl:if test="n1:TypeGermplasmStorage">
        	<tr>
        		<td>
            <span class="label">Type oppbevaring av Germplasm: </span>
            <xsl:value-of select="n1:TypeGermplasmStorage"/><br/>
        		</td>
        	</tr>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <xsl:if test="n1:DecodedBreedingInstitute">
        	<tr>
        		<td>
            <span class="label">Avlsinstitutt fullt navn: </span>
            <xsl:value-of select="n1:DecodedBreedingInstitute"/><br/>
        		</td>
        	</tr>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <xsl:if test="n1:DecodedDonorInstitute">
        	<tr>
        		<td>
            <span class="label">Donorinsitutt fullt navn: </span>
            <xsl:value-of select="n1:DecodedBreedingInstitute"/><br/>
        		</td>
        	</tr>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <xsl:if test="n1:DecodedLocationSafetyDuplicates">
        	<tr>
        		<td>
            <span class="label">Oppbevaringsplass for sikkerhetskopier fullt navn: </span>
            <xsl:value-of select="n1:DecodedLocationSafetyDuplicates"/><br/>
        		</td>
        	</tr>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <xsl:if test="n1:GatheringInstitutionCode">
        	<tr>
        		<td>
            <span class="label">Innsamlingsinstitusjonskode: </span>
            <xsl:value-of select="n1:GatheringInstitutionCode"/><br/>
        		</td>
        	</tr>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <xsl:if test="n1:AccessionNames">
        	<tr>
        		<td>
            <span class="label">Aksesjonsnavn: </span>
            <xsl:for-each select="n1:AccessionNames/n1:AccessionNameText">
            	<xsl:value-of select="."/>
            </xsl:for-each>
        		</td>
        	</tr>
        </xsl:if>
    <xsl:text>
    </xsl:text>	
        
        
    		</table>
    	</xsl:for-each>
    	</p>
    	<!-- *********************************PlantGeneticResourcesUnit ************************************** 	-->
    	<!-- ******************************** UNIT MEASUREMENTS ********************  -->
    	<xsl:if test="n1:MeasurementsOrFacts/n1:MeasurementOrFact">
    	 <h3 class="background e">LB_UnitMeasurement</h3>
    	   
    	   <xsl:for-each select="n1:MeasurementsOrFacts/n1:MeasurementOrFact">
    	<xsl:if
    		test="string(n1:MeasurementOrFactAtomised)">
    		<xsl:for-each
        select="n1:MeasurementOrFactAtomised">
        <xsl:call-template name="measurementatomised">
        	<xsl:with-param name="label">
        		LB_UnitMeasurement
        	</xsl:with-param>
        </xsl:call-template>
    		</xsl:for-each>
    		</xsl:if>
    <xsl:text>
    </xsl:text>
    		<xsl:if
        test="string(n1:MeasurementOrFactText)">
        
        <span class="label">LB_UnitMeasurement: </span>
        <xsl:value-of
        	select="string(n1:MeasurementOrFactText)" />
        <br />
    		</xsl:if>
    <xsl:text>
    </xsl:text>
    	
    	</xsl:for-each>
    	
    	</xsl:if>
    <xsl:text>
    </xsl:text>

    	<!-- ******************************** UNIT MEASUREMENTS ********************  -->
    	
    	
    	<!-- ************************* HerbariumUnit ************ -->
    	<xsl:for-each select="n1:HerbariumUnit">
    		<h3 class="background f">LB_HerbariumUnit</h3>
    		<table width="96%">
        <xsl:if test="string(n1:Exsiccatum)">
        <tr>
        	<td>
    <xsl:text>
    </xsl:text>
        		<span class="label">LB_Exsiccatum: </span>
        		<xsl:value-of select="n1:Exsiccatum"/>
        	</td>
        </tr>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <xsl:if test="string(n1:DuplicatesDistributedTo)">
        	<tr>
        		<td>
    <xsl:text>
    </xsl:text>
            <span class="label">LB_DuplicatesDistributedTo: </span>
            <xsl:value-of select="n1:DuplicatesDistributedTo"/>
        		</td>
        	</tr>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <xsl:if test="string(n1:LoanIdentifier)">
        	<tr>
        		<td>
    <xsl:text>
    </xsl:text>
            <span class="label">LB_LoanIdentifier: </span>
            <xsl:value-of select="n1:LoanIdentifier"/>
        		</td>
        	</tr>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <xsl:if test="string(n1:LoanSequenceNo)">
        	<tr>
        		<td>
    <xsl:text>
    </xsl:text>
            <span class="label">LB_LoanSequenceNo: </span>
            <xsl:value-of select="n1:LoanSequenceNo"/>
        		</td>
        	</tr>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <xsl:if test="string(n1:LoanDestination)">
        	<tr>
        		<td>
    <xsl:text>
    </xsl:text>
            <span class="label">LB_LoanDestination: </span>
            <xsl:value-of select="n1:LoanDestination"/>
        		</td>
        	</tr>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <xsl:if test="string(n1:LoanForBotanist)">
        	<tr>
        		<td>
    <xsl:text>
    </xsl:text>
            <span class="label">LB_LoanForBotanist: </span>
            <xsl:value-of select="n1:LoanForBotanist"/>
        		</td>
        	</tr>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <xsl:if test="string(n1:LoanDespatchMethod)">
        	<tr>
        		<td>
    <xsl:text>
    </xsl:text>
            <span class="label">LB_LoanDespatchMethod: </span>
            <xsl:value-of select="n1:LoanDespatchMethod"/>
        		</td>
        	</tr>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <xsl:if test="string(n1:LoanDate)">
        	<tr>
        		<td>
    <xsl:text>
    </xsl:text>
            <span class="label">LB_LoanDate: </span>
            <xsl:value-of select="n1:LoanDate"/>
        		</td>
        	</tr>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        <xsl:if test="string(n1:LoanReturnDate)">
        	<tr>
        		<td>
    <xsl:text>
    </xsl:text>
            <span class="label">LB_LoanReturnDate: </span>
            <xsl:value-of select="n1:LoanReturnDate "/>
        		</td>
        	</tr>
        </xsl:if>
    <xsl:text>
    </xsl:text>
        
    		</table>
    	</xsl:for-each>
    	<!--- ********************************* HerbariumUnit ***************** -->
    	<!--********************************** UNIT COLLECTION DOMAIN/ BOTANICAL GARDEN ***************************** -->
    	<xsl:for-each select="n1:UnitCollectionDomain">
    		<h3 class="background g">Informasjon spesifikk for botanisk hage</h3>
    		<table width="96%">
        <tr>
        	<xsl:if test="n1:BotanicalGardenUnit/n1:AccessionSpecimenNumbers">
        		<th>Aksesjonseksemplar antall</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:BotanicalGardenUnit/n1:AccessionStatus">
        		<th>Aksesjonsstatus</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:BotanicalGardenUnit/n1:LocationInGarden">
        		<th>Plassering i hage</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:BotanicalGardenUnit/n1:AccessionMaterialType">
        		<th>Type aksesjonsmaterial</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:BotanicalGardenUnit/n1:Hardiness">
        		<th>Hardf�rhet</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:BotanicalGardenUnit/n1:ProvenanceCategory">
        		<th>Herkomst kategori</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:BotanicalGardenUnit/n1:PropagationHistoryCode">
        		<th>Kode for produksjon av material</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:BotanicalGardenUnit/n1:AccessionLineage">
        		<th>Aksesjonslinje</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:BotanicalGardenUnit/n1:DonorCategory">
        		<th>Donorkategori</th>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<!--
        		Cultivation 0/1 smpl-type [String]
        		PlantingDate 0/1
        		Propagation 0/1 smpl-type [String]
        		Perennation 0/1
        		BreedingSystem 0/1
        		IPEN 0/1 smpl-type [String]-->
        </tr>
        <xsl:for-each select="n1:BotanicalGardenUnit">
        	<tr>
        		<xsl:for-each select="n1:AccessionSpecimenNumbers">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:apply-templates/>
            </td>
        		</xsl:for-each>
        		<xsl:for-each select="n1:AccessionStatus">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:apply-templates/>
            </td>
        		</xsl:for-each>
        		<xsl:for-each select="n1:LocationInGarden">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:apply-templates/>
            </td>
        		</xsl:for-each>
        		<xsl:for-each select="n1:AccessionMaterialType">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:apply-templates/>
            </td>
        		</xsl:for-each>
        		<xsl:for-each select="n1:Hardiness">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:apply-templates/>
            </td>
        		</xsl:for-each>
        		<xsl:for-each select="n1:ProvenanceCategory">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:apply-templates/>
            </td>
        		</xsl:for-each>
        		<xsl:for-each select="n1:PropagationHistoryCode">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:apply-templates/>
            </td>
        		</xsl:for-each>
        		<xsl:for-each select="n1:AccessionLineage">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:apply-templates/>
            </td>
        		</xsl:for-each>
        		<xsl:for-each select="n1:DonorCategory">
            <td>
    <xsl:text>
    </xsl:text>
            	<xsl:apply-templates/>
            </td>
        		</xsl:for-each>
        	</tr>
        </xsl:for-each>
    		</table>
    	</xsl:for-each>
    	<!-- ***********************************************************************-->
    	<!--
    	ZoologicalUnit 0/1 cmpl-type [ZoologicalUnit]
    	PhasesOrStages 0/1
    	PhaseOrStage 1/? cmpl-type [StringL]
    	language [optional]
    	--> 
    	<!-- ***********************************************************************-->
    	
    	<!-- *********************************OTHER DATA ************************************** 	-->
    	<xsl:if test="n1:LastEditor or n1:DateLastEdited or n1:CollectorsFieldNumber or n1:SpecimenUnit/n1:NomenclaturalTypeDesignations/n1:NomenclaturalTypeDesignation/n1:TypeStatus">
    	<xsl:text>
    </xsl:text>
    		<h3 class="background h">Annen informasjon</h3>
    		<table width="96%">
        <tbody>
        	<tr valign="top">
        		<td>
            <!-- Last editor -->
            <xsl:for-each select="n1:LastEditor">
            	<span class="label">Siste redakt�r: </span>
            	<xsl:value-of select="."/>
            	<br/>
            	<!-- <xsl:apply-templates/>-->
            </xsl:for-each>
            <!-- Last editor -->
            <xsl:for-each select="n1:DateLastEdited">
            	<span class="label">Dato for siste redigering: </span>
            	<xsl:value-of select="."/>
            	<br/>
            	<!-- <xsl:apply-templates/>-->
            </xsl:for-each>
            <xsl:for-each select="n1:CollectorsFieldNumber">
            	<span class="label">Innsamler_field_number: </span>
            	<xsl:value-of select="."/>
            	<br/>
            	<!--<xsl:apply-templates/>-->
            </xsl:for-each>
            <xsl:for-each select="n1:SpecimenUnit/n1:NomenclaturalTypeDesignations/n1:NomenclaturalTypeDesignation/n1:TypeStatus">
            	<span class="label">Typestatus: </span>
            	<xsl:value-of select="."/>
            	<br/>
            	<!--<xsl:apply-templates/>-->
            </xsl:for-each>
            <xsl:if test="string(n1:RecordURI)">
            	<span class="label">Datapost-URI: </span>
            	 <!--<xsl:value-of select="n1:RecordURI"/>-->
            	 <a href="{n1:RecordURI}" target ="_blank">URL</a>
            	
            	<br/>
            </xsl:if>
            <xsl:if test="string(n1:Age)">
            	<span class="label">Alder: </span>
            	<xsl:value-of select="n1:Age"/>
            	<br/>
            </xsl:if>
            <xsl:if test="string(n1:Sex)">
            	<span class="label">Kj�nn: </span>
            	<xsl:value-of select="n1:Sex"/>
            	<br/>
            </xsl:if>
        		</td>
        	</tr>
        </tbody>
    		</table>
    	</xsl:if>
    	<!-- *********************************OTHER DATA ************************************** 	-->
    	<!-- ********************************* IPR Specific for the Unit ************************************** 	-->
    	<!-- or n1:IPRStatements -->
    	<xsl:for-each select="n1:RecordRights">
    		<h3 class="background i">Spesifikke objektsrettigheter</h3>
    		<xsl:text>
 </xsl:text><xsl:call-template name="myRightsTable"/><xsl:text>
 </xsl:text>
    	</xsl:for-each>
    	<!-- *********************************IPR Specific for the Unit************************************** 	-->
    	<!-- ********************************* UnitStatements ************************************** 	-->
    	<xsl:for-each select="n1:UnitStatements">
    		<h3 class="background j">Objekterkl�ringer</h3>
    		<table width="96%">
        <tbody>
        	<tr valign="top">
        		<td>
            <xsl:apply-templates/>
        		</td>
        	</tr>
        </tbody>
    		</table>
    	</xsl:for-each>
    	<!-- ********************************* UnitStatements************************************** 	-->
    	<!-- *********************************NOTES ************************************** 	-->
    <xsl:if test="string(n1:UnitDescription)">
    	<xsl:for-each select="n1:UnitDescription">
    		<h3 class="background k">Kommentarer</h3>
    		<table width="96%">
        <tbody>
        	<tr valign="top">
        		<td>
            <xsl:apply-templates/>
        		</td>
        	</tr>
        </tbody>
    		</table>
    	</xsl:for-each>
    </xsl:if>
    	<!-- *********************************NOTES ************************************** 	-->
    	<br/>
    	<xsl:if test="string(n1:Notes)">
    	<xsl:for-each select="n1:Notes">
    		<h3 class="background l">Kommentarer </h3>
    		<table width="96%">
        <tbody>
        	<tr valign="top">
        		<td>
            <xsl:apply-templates/>
        		</td>
        	</tr>
        </tbody>
    		</table>
    	</xsl:for-each>
    </xsl:if>
    
     <xsl:text>
    </xsl:text>
    </div>
   <xsl:text>
    </xsl:text>
		</xsl:for-each>
		<span/> <xsl:text>
    </xsl:text>
		</xsl:for-each>	<xsl:text>
    </xsl:text>
		<!--      **************************************UNIT*********************************************  -->

		<h3 class="background m">Datasett sammendrag</h3>		
		 <xsl:for-each select="//n1:DataSets">
     <xsl:for-each select="n1:DataSet">
    	 <xsl:variable name="DataSetId" select="position()"/>
    		 <xsl:if test="n1:Metadata/n1:Description">
    		 <table width="96%"><tbody><tr><td>
    		 	<xsl:choose>
        <xsl:when test="n1:Metadata/n1:Description/n1:Representation/n1:Title">
        	<xsl:choose>
            	<xsl:when test="count(n1:Metadata/n1:Description/n1:Representation)=1">
            <xsl:for-each select="n1:Metadata/n1:Description/n1:Representation">
            	
        	     		<xsl:if test="n1:URI">
<xsl:variable name="URI" select="n1:URI"></xsl:variable>
<span class="label"><a  target="_blank" href="{$URI}">
<xsl:value-of select="n1:Title"/></a>
<br/></span>
</xsl:if>
    <xsl:text>
    </xsl:text>        		
<xsl:if test="not(n1:URI)">
<span class="label">
<xsl:value-of select="n1:Title"/>
<br/></span>
</xsl:if>
    <xsl:text>
    </xsl:text>

<xsl:variable name="lang_rep" select="n1:Metadata/n1:Description/*[@language=$PrefLang or @language=$PrefLang_cap]"></xsl:variable>
            <xsl:variable name="lang_rep_alt" select="n1:Metadata/n1:Description/*[@language=$AltLang or @language=$AltLang_cap]"></xsl:variable>
            <xsl:choose>
            <xsl:when test="$lang_rep/n1:Title">
            	<xsl:for-each select="$lang_rep">
            	 <span ><xsl:value-of select="$lang_rep/n1:Title"/><br/></span>        		
        	     		<xsl:if test="n1:Details">
                <span ><xsl:value-of select="$lang_rep/n1:Details"/><br/></span>
        	     </xsl:if>
    <xsl:text>
    </xsl:text>
        	     <xsl:if test="n1:Coverage">
            		<xsl:value-of select="$lang_rep/n1:Coverage"/><br/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            </xsl:for-each>
            </xsl:when>
            <xsl:when test="$lang_rep_alt/n1:Title">
            	<xsl:for-each select="$lang_rep_alt">
            	 <span ><xsl:value-of select="$lang_rep_alt/n1:Title"/><br/></span>        		
        	     		<xsl:if test="n1:Details">
                <span ><xsl:value-of select="$lang_rep_alt/n1:Details"/><br/></span>
        	     </xsl:if>
    <xsl:text>
    </xsl:text>
        	     <xsl:if test="n1:Coverage">
            		<xsl:value-of select="$lang_rep_alt/n1:Coverage"/><br/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            </xsl:for-each>
            </xsl:when>
            <xsl:otherwise>
            	<xsl:if test="n1:Details">
                <span ><xsl:value-of select="n1:Details"/><br/></span>
        	     </xsl:if>
    <xsl:text>
    </xsl:text>
        	     <xsl:if test="n1:Coverage">
            		<xsl:value-of select="n1:Coverage"/><br/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            </xsl:otherwise>
            </xsl:choose>

            </xsl:for-each>
        		</xsl:when>
        		<xsl:otherwise>
            <xsl:variable name="lang_rep" select="n1:Metadata/n1:Description/*[@language=$PrefLang or @language=$PrefLang_cap]"></xsl:variable>
            <xsl:variable name="lang_rep_alt" select="n1:Metadata/n1:Description/*[@language=$AltLang or @language=$AltLang_cap]"></xsl:variable>
            <xsl:choose>
            <xsl:when test="$lang_rep/n1:Title">
            	<xsl:for-each select="$lang_rep">
            	 <span class="label"><xsl:value-of select="$lang_rep/n1:Title"/><br/></span>        		
        	     		<xsl:if test="n1:Details">
                <span class="label"><xsl:value-of select="$lang_rep/n1:Details"/><br/></span>
        	     </xsl:if>
    <xsl:text>
    </xsl:text>
        	     <xsl:if test="n1:Coverage">
            		<xsl:value-of select="$lang_rep/n1:Coverage"/><br/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            </xsl:for-each>
            </xsl:when>
            <xsl:when test="$lang_rep_alt/n1:Title">
            	<xsl:for-each select="$lang_rep_alt">
            	 <span class="label"><xsl:value-of select="$lang_rep_alt/n1:Title"/><br/></span>        		
        	     		<xsl:if test="n1:Details">
                <span class="label"><xsl:value-of select="$lang_rep_alt/n1:Details"/><br/></span>
        	     </xsl:if>
    <xsl:text>
    </xsl:text>
        	     <xsl:if test="n1:Coverage">
            		<xsl:value-of select="$lang_rep_alt/n1:Coverage"/><br/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            </xsl:for-each>
            </xsl:when>
            <xsl:otherwise>
            	<xsl:for-each select="n1:Metadata/n1:Description/n1:Representation">
            	 <span class="label"><xsl:value-of select="n1:Title"/><br/></span>        		
        	     		<xsl:if test="n1:Details">
                <span class="label"><xsl:value-of select="n1:Details"/><br/></span>
        	     </xsl:if>
    <xsl:text>
    </xsl:text>
        	     <xsl:if test="n1:Coverage">
            		<xsl:value-of select="n1:Coverage"/><br/>
            	</xsl:if>
    <xsl:text>
    </xsl:text>
            </xsl:for-each>
            </xsl:otherwise>
            </xsl:choose>
        		</xsl:otherwise>
        	</xsl:choose>
        </xsl:when>
        <xsl:otherwise>
        	<li><a href="#{$DataSetId}">dataset <xsl:value-of select="$DataSetId"/></a><xsl:text>
            </xsl:text>
 </li>
            <xsl:text>
            </xsl:text>
        </xsl:otherwise>
    		</xsl:choose>
    		</td></tr></tbody></table> 	
    		</xsl:if>
    <xsl:text>
    </xsl:text>
    		<xsl:if test="n1:Metadata/n1:IconURI">
        <img border="0" src="{n1:Metadata/n1:IconURI}" align="right" height="45" class="marginRightBig"/>
    		</xsl:if>
    <xsl:text>
    </xsl:text>
    		<xsl:if test="n1:Metadata/n1:Scope">
    		<xsl:if test="n1:Metadata/n1:Scope/n1:GeoecologicalTerms">
        <xsl:choose>
        	<xsl:when test="count(n1:Metadata/n1:Scope/n1:GeoecologicalTerms/*[@language=$PrefLang or @language=$PrefLang_cap]) > 0">
        		<xsl:for-each select="n1:Metadata/n1:Scope/n1:GeoecologicalTerms/*[@language=$PrefLang or @language=$PrefLang_cap]">
            <xsl:value-of select="."/>
            <xsl:if test="position()!=last()">
            	, 
            </xsl:if>
    <xsl:text>
    </xsl:text>
        		</xsl:for-each>
        	</xsl:when>
        	<xsl:when test="count(n1:Metadata/n1:Scope/n1:GeoecologicalTerms/*[@language=$AltLang or @language=$AltLang_cap]) > 0">
        		<xsl:for-each select="n1:Metadata/n1:Scope/n1:GeoecologicalTerms/*[@language=$AltLang or @language=$AltLang_cap]">
            <xsl:value-of select="."/>
            <xsl:if test="position()!=last()">
            	, 
            </xsl:if>
    <xsl:text>
    </xsl:text>
        		</xsl:for-each>
        	</xsl:when>
        	<xsl:otherwise>
        		<xsl:for-each select="n1:Metadata/n1:Scope/n1:GeoecologicalTerms/n1:GeoEcologicalTerm">
            <xsl:value-of select="."/>
            <xsl:if test="position()!=last()">
            	, 
            </xsl:if>
    <xsl:text>
    </xsl:text>
        		</xsl:for-each>
        	</xsl:otherwise>
        </xsl:choose>
        <br/>
    		</xsl:if>
    <xsl:text>
    </xsl:text> 
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	<xsl:if test="n1:Metadata/n1:Scope/n1:TaxonomicTerms">
    		<xsl:choose>
        	<xsl:when test="count(n1:Metadata/n1:Scope/n1:TaxonomicTerms/*[@language=$PrefLang or @language=$PrefLang_cap]) > 0">
        		<xsl:for-each select="n1:Metadata/n1:Scope/n1:TaxonomicTerms/*[@language=$PrefLang or @language=$PrefLang_cap]">
            <xsl:value-of select="."/>
            <xsl:if test="position()!=last()">
            	, 
            </xsl:if>
    <xsl:text>
    </xsl:text>
        		</xsl:for-each>
        	</xsl:when>
        	<xsl:when test="count(n1:Metadata/n1:Scope/n1:TaxonomicTerms/*[@language=$AltLang or @language=$AltLang_cap]) > 0">
        		<xsl:for-each select="n1:Metadata/n1:Scope/n1:TaxonomicTerms/*[@language=$AltLang or @language=$AltLang_cap]">
            <xsl:value-of select="."/>
            <xsl:if test="position()!=last()">
            	, 
            </xsl:if>
    <xsl:text>
    </xsl:text>
        		</xsl:for-each>
        	</xsl:when>
        	<xsl:otherwise>
        		<xsl:for-each select="n1:Metadata/n1:Scope/n1:TaxonomicTerms/n1:TaxonomicTerm">
            <xsl:value-of select="."/>
            <xsl:if test="position()!=last()">
            	, 
            </xsl:if>
    <xsl:text>
    </xsl:text>
        		</xsl:for-each>
        	</xsl:otherwise>
        </xsl:choose>
        <br/>
    	</xsl:if>
    <xsl:text>
    </xsl:text> 
    	<xsl:if test="n1:Metadata/n1:Version">
    		<span class="label">Versjon: </span>  
    		<xsl:if test="n1:Metadata/n1:Version/n1:Major">
        <xsl:value-of select="n1:Metadata/n1:Version/n1:Major"/>
    		</xsl:if>
    <xsl:text>
    </xsl:text>
    		<xsl:if test="n1:Metadata/n1:Version/n1:Minor">
        .<xsl:value-of select="n1:Metadata/n1:Version/n1:Minor"/>
    		</xsl:if>
    <xsl:text>
    </xsl:text>
    		<xsl:if test="n1:Metadata/n1:Version/n1:Modifier">
        -<xsl:value-of select="n1:Metadata/n1:Version/n1:Modifier"/><br/>
    		</xsl:if>
    <xsl:text>
    </xsl:text>
    		<xsl:if test="n1:Metadata/n1:Version/n1:DateIssued">
        <span class="label">DatoIssued: </span>
        <xsl:value-of select="n1:Metadata/n1:Version/n1:DateIssued"/><br/>
    		</xsl:if>
    <xsl:text>
    </xsl:text>
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	
    	<xsl:if test="n1:Metadata/n1:Owners">
    		<h3 class="background n">Eier(e)</h3>
    		<table width="96%"><tbody><tr><td>
    <xsl:text>
    </xsl:text>
    		<!--<span class="label"></span>-->
    		<xsl:for-each select="n1:Metadata/n1:Owners/n1:Owner">
        <xsl:call-template name="myowner">
        </xsl:call-template>
    		</xsl:for-each>
    		</td></tr></tbody></table> 
    	</xsl:if>
    <xsl:text>
    </xsl:text>
		
     	<xsl:if test="n1:TechnicalContacts or n1:ContentContacts">
     		<h3 class="background o">Kontaktperson(er)</h3>
    		<table width="96%"><tbody><tr><td>
    <xsl:text>
    </xsl:text>
    		<xsl:if test="n1:TechnicalContacts">
        <span class="label">Teknisk(e) kontaktperson(er): </span><br/>
        	<xsl:for-each select="n1:TechnicalContacts/n1:TechnicalContact">
<!--         		<br/> -->
        		<xsl:call-template name="contact"></xsl:call-template>
        	</xsl:for-each>
    		</xsl:if>
    <xsl:text>
    </xsl:text>
    		
<!--     	<br/>	 -->
    	<xsl:if test="n1:ContentContacts">
    		<br/>
    		<span class="label">Innholdskontaktperson(er): </span><br/>
        	<xsl:for-each select="n1:ContentContacts/n1:ContentContact">
<!--         		<br/> -->
        		<xsl:call-template name="contact"></xsl:call-template>
        	</xsl:for-each>
    		</xsl:if>
    <xsl:text>
    </xsl:text>
<!--     	<br/> -->
    	</td></tr></tbody></table> 
    	</xsl:if>
    <xsl:text>
    </xsl:text>
	
    	<xsl:for-each select="n1:Metadata/n1:IPRStatements">
    	<h3 class="background p">LB_Rights</h3>
    		<xsl:text>
 </xsl:text><xsl:call-template name="myRightsTable"/><xsl:text>
 </xsl:text>
    	</xsl:for-each>
    </xsl:for-each>
<!--     <br/> -->
		</xsl:for-each>
	</xsl:template>

<xsl:template name="myowner">
		<xsl:for-each select=".">
    <xsl:if test="n1:Organisation">
    	<span class="label">Organisasjon: </span>
    		<xsl:choose>
        <xsl:when test="count(n1:Organisation/n1:Name/*[@language=$PrefLang or @language=$PrefLang_cap]) > 0">
        	<xsl:for-each select="n1:Organisation/n1:Name/*[@language=$PrefLang or @language=$PrefLang_cap]">
        		<xsl:value-of select="n1:Text"/>
        		<xsl:if test="n1:Abbreviation">
<!--             (<xsl:value-of select="n1:Abbreviation"/>) -->
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        	</xsl:for-each>
        </xsl:when>
        <xsl:when test="count(n1:Organisation/n1:Name/*[@language=$AltLang or @language=$AltLang_cap]) > 0">
        	<xsl:for-each select="n1:Organisation/n1:Name/*[@language=$AltLang or @language=$AltLang_cap]">
        		<xsl:value-of select="n1:Text"/>
        		<xsl:if test="n1:Abbreviation">
<!--             (<xsl:value-of select="n1:Abbreviation"/>) -->
        		</xsl:if>
    <xsl:text>
    </xsl:text>
<!--         		<br/> -->
        	</xsl:for-each>
        </xsl:when>
        <xsl:otherwise>
        	<xsl:for-each select="n1:Organisation/n1:Name/n1:Representation">
        		<xsl:value-of select="n1:Text"/>
        		<xsl:if test="n1:Abbreviation">
<!--             (<xsl:value-of select="n1:Abbreviation"/>) -->
        		</xsl:if>
    <xsl:text>
    </xsl:text>
<!--         		<br/> -->
        	</xsl:for-each>
        </xsl:otherwise>
    		</xsl:choose>
<!--     	<br/> -->
    	<xsl:if test="n1:Organisation/n1:OrgUnits">
    		<span class="label">OrganisasjonUnits: </span>
		<xsl:choose>
    <xsl:when test="count(n1:Organisation/n1:OrgUnits/*[@language=$PrefLang or @language=$PrefLang_cap]) > 0">
    	<xsl:for-each select="n1:Organisation/n1:OrgUnits/*[@language=$PrefLang or @language=$PrefLang_cap]">
    		<xsl:value-of select="."/><!--<br/>-->
    	</xsl:for-each>
    </xsl:when>
    <xsl:when test="count(n1:Organisation/n1:OrgUnits/*[@language=$AltLang or @language=$AltLang_cap]) > 0">
    	<xsl:for-each select="n1:Organisation/n1:OrgUnits/*[@language=$AltLang or @language=$AltLang_cap]">
    		<xsl:value-of select="."/><!--<br/>-->
    	</xsl:for-each>
    </xsl:when>
    <xsl:otherwise>
    	<xsl:for-each select="n1:Organisation/n1:OrgUnits">
    		<xsl:value-of select="."/><!--<br/>-->
    	</xsl:for-each>
    </xsl:otherwise>
		</xsl:choose>
<!-- 		<br/> -->
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    </xsl:if>
    <xsl:text>
    </xsl:text>
    	<xsl:if test="n1:Addresses">
    		<span  class="label"><br/>Adresse(r): </span>
    <xsl:choose>
    	<xsl:when test="count(n1:Addresses/n1:Address) = 1 or count(n1:Addresses/*[@preferred])=0">
    		<!--Only one identification, is shown as non prefered -->
    		<span class="preferedbig_xslt">
        <xsl:choose>
        	<xsl:when test="count(n1:Addresses/*[@language=$PrefLang or @language=$PrefLang_cap]) > 0">
        		<xsl:for-each select="n1:Addresses/*[@language=$PrefLang or @language=$PrefLang_cap]">
            <xsl:value-of select="."/><!--<br/>-->
        		</xsl:for-each>
        </xsl:when>
        <xsl:when test="count(n1:Addresses/*[@language=$AltLang or @language=$AltLang_cap])> 0">
        	<xsl:for-each select="n1:Addresses/*[@language=$AltLang or @language=$AltLang_cap]">
        		<xsl:value-of select="."/><!--<br/>-->
        	</xsl:for-each>
        </xsl:when>
        <xsl:otherwise>
        	<xsl:for-each select="n1:Addresses/n1:Address">
        		<xsl:value-of select="."/><!--<br/>-->
        	</xsl:for-each>
        </xsl:otherwise>
    </xsl:choose>        		
        </span>
        </xsl:when>
        <!-- more than 1 identifications -->
        <xsl:otherwise>
        	<!--Check if there is a preferedflag -->
        	<xsl:choose>
        		<xsl:when test="@preferred= '0' or not(@preferred)">
            <!-- Identification without prefered flag -->
            <xsl:value-of select="."/>
        		</xsl:when>
        		<xsl:otherwise>
            <xsl:choose>
            	<xsl:when test="@preferred= '1' or @preferred='true'">
            		<!--Multiple identifications, prefered one -->
            		<span class="preferedbig_xslt">
                <xsl:value-of select="."/>
                <xsl:choose>
        	<xsl:when test="count(n1:Addresses/n1:Address) = 1 or count(n1:Addresses/*[@preferred])=0">
        		<!--Only one identification, is shown as non prefered -->
        		<span class="preferedbig_xslt">
            <xsl:choose>
            	<xsl:when test="count(n1:Addresses/*[@language=$PrefLang]) > 0">
            		<xsl:for-each select="n1:Addresses/*[@language=$PrefLang]">
                <xsl:value-of select="."/><!--<br/>-->
            		</xsl:for-each>
            	</xsl:when>
            	<xsl:when test="count(n1:Addresses/*[@language=$AltLang]) > 0">
            		<xsl:for-each select="n1:Addresses/*[@language=$AltLang]">
                <xsl:value-of select="."/><!--<br/>-->
            		</xsl:for-each>
            	</xsl:when>
            	<xsl:otherwise>
            		<xsl:for-each select="n1:Addresses/n1:Address">
                <xsl:value-of select="."/><!--<br/>-->
            		</xsl:for-each>
            	</xsl:otherwise>
            </xsl:choose>
            </span>
        		</xsl:when>
        </xsl:choose>
    		</span>
    		</xsl:when>
    	<xsl:otherwise>
            		<!--Multiple identifications, non prefered one -->
            	</xsl:otherwise>
            </xsl:choose>
        		</xsl:otherwise>
        	</xsl:choose>
        </xsl:otherwise>
    		</xsl:choose>
<!--     		<br/> -->
    		
    	</xsl:if>
    <xsl:text>
    </xsl:text>
    	<xsl:if test="n1:URIs">
    		<xsl:for-each select="n1:URIs/n1:URL">
        <xsl:choose>
        	<xsl:when test="count(../n1:URL) = 1">
        		<!--Only one identification, is shown as non prefered -->
        		| <span class="preferedbig_xslt">
            <a href="{../n1:URL}" target ="_blank">URL</a>
        		</span>
        	</xsl:when>
        	<!-- more than 1 identifications -->
        	<xsl:otherwise>
        		<!--Check if there is a preferedflag -->
        		<xsl:choose>
            <xsl:when test="@preferred= '0' or not(@preferred)">
            	<!-- Identification without prefered flag -->
            	| <a href="{../n1:URL}" target ="_blank">URL</a>
            </xsl:when>
            <xsl:otherwise>
            	<xsl:choose>
            		<xsl:when test="@preferred= '1' or @preferred='true'">
                <!--Multiple identifications, prefered one -->
                | <span class="preferedbig_xslt">
                	<a href="{../n1:URL}" target ="_blank">URL</a>
                </span>
            		</xsl:when>
            		<xsl:otherwise>
                <!--Multiple identifications, non prefered one -->
            		</xsl:otherwise>
            	</xsl:choose>
            </xsl:otherwise>
        		</xsl:choose>
        	</xsl:otherwise>
        </xsl:choose>
    		</xsl:for-each>
    	</xsl:if>
    <xsl:text>
    </xsl:text>
		</xsl:for-each>
</xsl:template>
<xsl:template name="myRightsTable">
	<xsl:if test="string(.)">
		<table width="96%" >
    <xsl:if test="n1:IPRDeclarations">
    	<tr>
    		<td>
    <xsl:text>
    </xsl:text>
        <span class="label">IPR-erkl�ring: </span>
        <xsl:choose>
        	<xsl:when test="count(n1:IPRDeclarations/*[@language=$PrefLang or @language=$PrefLang_cap]) > 0">
        		<xsl:for-each select="n1:IPRDeclarations/*[@language=$PrefLang or @language=$PrefLang_cap]">
            <xsl:value-of select="n1:Text"/>
        		<xsl:if test="n1:Details">
            <xsl:value-of select="n1:Details"/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:URI">
            <a href="{n1:URI}" target ="_blank">URL</a>
            <!-- <xsl:value-of select="n1:URI"/>  -->
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		</xsl:for-each>
        	</xsl:when>
        <xsl:when test="count(n1:IPRDeclarations/*[@language=$AltLang or @language=$AltLang_cap]) > 0">
        	<xsl:for-each select="n1:IPRDeclarations/*[@language=$AltLang or @language=$AltLang_cap]">
        		<xsl:value-of select="n1:Text"/>
        	<xsl:if test="n1:Details">
        		<xsl:value-of select="n1:Details"/>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:URI">
        		<a href="{n1:URI}" target ="_blank">URL</a>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	</xsl:for-each>
        </xsl:when>
        <xsl:otherwise>
        	<xsl:for-each select="n1:IPRDeclarations/n1:IPRDeclaration">
        		<!--(<xsl:value-of select="@language"/>)-->
        		<xsl:value-of select="n1:Text"/>
        		<xsl:if test="n1:Details">
            <xsl:value-of select="n1:Details"/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:URI">
            <a href="{n1:URI}" target ="_blank">URL</a>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        	</xsl:for-each>
        </xsl:otherwise>
    		</xsl:choose>
    		</td>
    	</tr>
    </xsl:if>
    <xsl:text>
    </xsl:text>
    <xsl:if test="n1:Copyrights">
    	<tr>
    		<td>
    <xsl:text>
    </xsl:text>
        <span class="label">Opphavsrettserkl�ring: </span>
        <xsl:choose>
        	<xsl:when test="count(n1:Copyrights/*[@language=$PrefLang or @language=$PrefLang_cap]) > 0">
        		<xsl:for-each select="n1:Copyrights/*[@language=$PrefLang or @language=$PrefLang_cap]">
            <xsl:value-of select="n1:Text"/>
        		<xsl:if test="n1:Details">
            <xsl:value-of select="n1:Details"/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:URI">
            <a href="{n1:URI}" target ="_blank">URL</a>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		</xsl:for-each>
        	</xsl:when>
        <xsl:when test="count(n1:Copyrights/*[@language=$AltLang or @language=$AltLang_cap]) > 0">
        	<xsl:for-each select="n1:Copyrights/*[@language=$AltLang or @language=$AltLang_cap]">
        		<xsl:value-of select="n1:Text"/>
        	<xsl:if test="n1:Details">
        		<xsl:value-of select="n1:Details"/>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:URI">
        		<a href="{n1:URI}" target ="_blank">URL</a>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	</xsl:for-each>
        </xsl:when>
        <xsl:otherwise>
        	<xsl:for-each select="n1:Copyrights/n1:Copyright">
        		<!--(<xsl:value-of select="@language"/>)-->
        		<xsl:value-of select="n1:Text"/>
        		<xsl:if test="n1:Details">
            <xsl:value-of select="n1:Details"/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:URI">
            <a href="{n1:URI}" target ="_blank">URL</a>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        	</xsl:for-each>
        </xsl:otherwise>
    		</xsl:choose>
    		</td>
    	</tr>
    </xsl:if>
    <xsl:text>
    </xsl:text>
    <xsl:if test="n1:Licenses">
    	<tr>
    		<td>
    <xsl:text>
    </xsl:text>
        <span class="label">Lisens(er): </span>
        <xsl:choose>
        	<xsl:when test="count(n1:Licenses/*[@language=$PrefLang or @language=$PrefLang_cap]) > 0">
        		<xsl:for-each select="n1:Licenses/*[@language=$PrefLang or @language=$PrefLang_cap]">
            <xsl:value-of select="n1:Text"/>
        		<xsl:if test="n1:Details">
            <xsl:value-of select="n1:Details"/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:URI">
            <a href="{n1:URI}" target ="_blank">URL</a>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		</xsl:for-each>
        	</xsl:when>
        <xsl:when test="count(n1:Licenses/*[@language=$AltLang or @language=$AltLang_cap]) > 0">
        	<xsl:for-each select="n1:Licenses/*[@language=$AltLang or @language=$AltLang_cap]">
        		<xsl:value-of select="n1:Text"/>
        	<xsl:if test="n1:Details">
        		<xsl:value-of select="n1:Details"/>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:URI">
        		<a href="{n1:URI}" target ="_blank">URL</a>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	</xsl:for-each>
        </xsl:when>
        <xsl:otherwise>
        	<xsl:for-each select="n1:Licenses/n1:License">
        		<!--(<xsl:value-of select="@language"/>)-->
        		<xsl:value-of select="n1:Text"/>
        		<xsl:if test="n1:Details">
            <xsl:value-of select="n1:Details"/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:URI">
            <a href="{n1:URI}" target ="_blank">URL</a>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        	</xsl:for-each>
        </xsl:otherwise>
    		</xsl:choose>
    		</td>
    	</tr>
    </xsl:if>
    <xsl:text>
    </xsl:text>
    <xsl:if test="n1:TermsOfUseStatements">
    	<tr>
    		<td>
    <xsl:text>
    </xsl:text>
        <span class="label">Brukervilk�r: </span>
        <xsl:choose>
        	<xsl:when test="count(n1:TermsOfUseStatements/*[@language=$PrefLang or @language=$PrefLang_cap]) > 0">
        		<xsl:for-each select="n1:TermsOfUseStatements/*[@language=$PrefLang or @language=$PrefLang_cap]">
            <xsl:value-of select="n1:Text"/>
        		<xsl:if test="n1:Details">
            <xsl:value-of select="n1:Details"/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:URI">
            <a href="{n1:URI}" target ="_blank">URL</a>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		</xsl:for-each>
        	</xsl:when>
        <xsl:when test="count(n1:TermsOfUseStatements/*[@language=$AltLang or @language=$AltLang_cap]) > 0">
        	<xsl:for-each select="n1:TermsOfUseStatements/*[@language=$AltLang or @language=$AltLang_cap]">
        		<xsl:value-of select="n1:Text"/>
        	<xsl:if test="n1:Details">
        		<xsl:value-of select="n1:Details"/>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:URI">
        		<a href="{n1:URI}" target ="_blank">URL</a>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	</xsl:for-each>
        </xsl:when>
        <xsl:otherwise>
        	<xsl:for-each select="n1:TermsOfUseStatements/n1:TermsOfUse">
        		<!--(<xsl:value-of select="@language"/>)-->
        		<xsl:value-of select="n1:Text"/>
        		<xsl:if test="n1:Details">
            <xsl:value-of select="n1:Details"/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:URI">
            <a href="{n1:URI}" target ="_blank">URL</a>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        	</xsl:for-each>
        </xsl:otherwise>
    		</xsl:choose>
    		</td>
    	</tr>
    </xsl:if>
    <xsl:text>
    </xsl:text>
    <xsl:if test="n1:Disclaimers">
    	<tr>
    		<td>
    <xsl:text>
    </xsl:text>
        <span class="label">Ansvarsfraskrivelse�: </span>
        <xsl:choose>
        	<xsl:when test="count(n1:Disclaimers/*[@language=$PrefLang or @language=$PrefLang_cap]) > 0">
        		<xsl:for-each select="n1:Disclaimers/*[@language=$PrefLang or @language=$PrefLang_cap]">
            <xsl:value-of select="n1:Text"/>
        		<xsl:if test="n1:Details">
            <xsl:value-of select="n1:Details"/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:URI">
            <a href="{n1:URI}" target ="_blank">URL</a>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		</xsl:for-each>
        	</xsl:when>
        <xsl:when test="count(n1:Disclaimers/*[@language=$AltLang or @language=$AltLang_cap]) > 0">
        	<xsl:for-each select="n1:Disclaimers/*[@language=$AltLang or @language=$AltLang_cap]">
        		<xsl:value-of select="n1:Text"/>
        	<xsl:if test="n1:Details">
        		<xsl:value-of select="n1:Details"/>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:URI">
        		<a href="{n1:URI}" target ="_blank">URL</a>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	</xsl:for-each>
        </xsl:when>
        <xsl:otherwise>
        	<xsl:for-each select="n1:Disclaimers/n1:Disclaimer">
        		<!--(<xsl:value-of select="@language"/>)-->
        		<xsl:value-of select="n1:Text"/>
        		<xsl:if test="n1:Details">
            <xsl:value-of select="n1:Details"/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:URI">
            <a href="{n1:URI}" target ="_blank">URL</a>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        	</xsl:for-each>
        </xsl:otherwise>
    		</xsl:choose>
    		</td>
    	</tr>
    </xsl:if>
    <xsl:text>
    </xsl:text>
    <xsl:if test="n1:Acknowledgements">
    	<tr>
    		<td>
    <xsl:text>
    </xsl:text>
        <span class="label">Takk til: </span>
        <xsl:choose>
        	<xsl:when test="count(n1:Acknowledgements/*[@language=$PrefLang or @language=$PrefLang_cap]) > 0">
        		<xsl:for-each select="n1:Acknowledgements/*[@language=$PrefLang or @language=$PrefLang_cap]">
            <xsl:value-of select="n1:Text"/>
        		<xsl:if test="n1:Details">
            <xsl:value-of select="n1:Details"/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:URI">
            <a href="{n1:URI}" target ="_blank">URL</a>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		</xsl:for-each>
        	</xsl:when>
        <xsl:when test="count(n1:Acknowledgements/*[@language=$AltLang or @language=$AltLang_cap]) > 0">
        	<xsl:for-each select="n1:Acknowledgements/*[@language=$AltLang or @language=$AltLang_cap]">
        		<xsl:value-of select="n1:Text"/>
        	<xsl:if test="n1:Details">
        		<xsl:value-of select="n1:Details"/>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:URI">
        		<a href="{n1:URI}" target ="_blank">URL</a>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	</xsl:for-each>
        </xsl:when>
        <xsl:otherwise>
        	<xsl:for-each select="n1:Acknowledgements/n1:Acknowledgement">
        		<!--(<xsl:value-of select="@language"/>)-->
        		<xsl:value-of select="n1:Text"/>
        		<xsl:if test="n1:Details">
            <xsl:value-of select="n1:Details"/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:URI">
            <a href="{n1:URI}" target ="_blank">URL</a>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        	</xsl:for-each>
        </xsl:otherwise>
    		</xsl:choose>
    		</td>
    	</tr>
    </xsl:if>
    <xsl:text>
    </xsl:text>
    <xsl:if test="n1:Citations">
    	<tr>
    		<td>
    <xsl:text>
    </xsl:text>
        <span class="label">Sitering(er): </span>
        <xsl:choose>
        	<xsl:when test="count(n1:Citations/*[@language=$PrefLang or @language=$PrefLang_cap]) > 0">
        		<xsl:for-each select="n1:Citations/*[@language=$PrefLang or @language=$PrefLang_cap]">
            <xsl:value-of select="n1:Text"/>
        		<xsl:if test="n1:Details">
            <xsl:value-of select="n1:Details"/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:URI">
            <a href="{n1:URI}" target ="_blank">URL</a>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		</xsl:for-each>
        	</xsl:when>
        <xsl:when test="count(n1:Citations/*[@language=$AltLang or @language=$AltLang_cap]) > 0">
        	<xsl:for-each select="n1:Citations/*[@language=$AltLang or @language=$AltLang_cap]">
        		<xsl:value-of select="n1:Text"/>
        	<xsl:if test="n1:Details">
        		<xsl:value-of select="n1:Details"/>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	<xsl:if test="n1:URI">
        		<a href="{n1:URI}" target ="_blank">URL</a>
        	</xsl:if>
    <xsl:text>
    </xsl:text>
        	</xsl:for-each>
        </xsl:when>
        <xsl:otherwise>
        	<xsl:for-each select="n1:Citations/n1:Citation">
        		<!--(<xsl:value-of select="@language"/>)-->
        		<xsl:value-of select="n1:Text"/>
        		<xsl:if test="n1:Details">
            <xsl:value-of select="n1:Details"/>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        		<xsl:if test="n1:URI">
            <a href="{n1:URI}" target ="_blank">URL</a>
        		</xsl:if>
    <xsl:text>
    </xsl:text>
        	</xsl:for-each>
        </xsl:otherwise>
    		</xsl:choose>
    		</td>
    	</tr>
    </xsl:if>
    <xsl:text>
    </xsl:text>
		</table>
	</xsl:if>
    <xsl:text>
    </xsl:text>
</xsl:template>
</xsl:stylesheet>
